Class: DockerEngineRuby::Models::ConfigObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/config_object.rb

Overview

Defined Under Namespace

Classes: Version

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at: nil, id: nil, spec: nil, updated_at: nil, version: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::ConfigObject for more details.

Parameters:



# File 'lib/docker_engine_ruby/models/config_object.rb', line 41


Instance Attribute Details

#created_atTime?

Returns:

  • (Time, nil)


10
# File 'lib/docker_engine_ruby/models/config_object.rb', line 10

optional :created_at, Time, api_name: :CreatedAt

#idString?

Returns:

  • (String, nil)


15
# File 'lib/docker_engine_ruby/models/config_object.rb', line 15

optional :id, String, api_name: :ID

#specDockerEngineRuby::Models::ConfigSpec?



20
# File 'lib/docker_engine_ruby/models/config_object.rb', line 20

optional :spec, -> { DockerEngineRuby::ConfigSpec }, api_name: :Spec

#updated_atTime?

Returns:

  • (Time, nil)


25
# File 'lib/docker_engine_ruby/models/config_object.rb', line 25

optional :updated_at, Time, api_name: :UpdatedAt

#versionDockerEngineRuby::Models::ConfigObject::Version?

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.



39
# File 'lib/docker_engine_ruby/models/config_object.rb', line 39

optional :version, -> { DockerEngineRuby::ConfigObject::Version }, api_name: :Version