Class: DockerEngineRuby::Models::ConnectRequest::EndpointConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/connect_request.rb

Overview

See Also:

Defined Under Namespace

Classes: IpamConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::ConnectRequest::EndpointConfig for more details.

Configuration for a network endpoint.

Parameters:

  • aliases (Array<String>) (defaults to: nil)
  • dns_names (Array<String>) (defaults to: nil)

    List of all DNS names an endpoint has on a specific network. This

  • driver_opts (Hash{Symbol=>String}, nil) (defaults to: nil)

    DriverOpts is a mapping of driver options and values. These options

  • endpoint_id (String) (defaults to: nil)

    Unique ID for the service endpoint in a Sandbox.

  • gateway (String) (defaults to: nil)

    Gateway address for this network.

  • global_i_pv6_address (String) (defaults to: nil)

    Global IPv6 address.

  • global_i_pv6_prefix_len (Integer) (defaults to: nil)

    Mask length of the global IPv6 address.

  • gw_priority (Integer) (defaults to: nil)

    This property determines which endpoint will provide the default

  • ip_address (String) (defaults to: nil)

    IPv4 address.

  • ipam_config (DockerEngineRuby::Models::ConnectRequest::EndpointConfig::IpamConfig) (defaults to: nil)

    EndpointIPAMConfig represents an endpoint’s IPAM configuration.

  • ip_prefix_len (Integer) (defaults to: nil)

    Mask length of the IPv4 address.

  • i_pv6_gateway (String) (defaults to: nil)

    IPv6 gateway address.

  • links (Array<String>) (defaults to: nil)
  • mac_address (String) (defaults to: nil)

    MAC address for the endpoint on this network. The network driver might ignore th

  • network_id (String) (defaults to: nil)

    Unique ID of the network.



# File 'lib/docker_engine_ruby/models/connect_request.rb', line 135


Instance Attribute Details

#aliasesArray<String>?

Returns:

  • (Array<String>, nil)


34
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 34

optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases

#dns_namesArray<String>?

List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.

These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending ‘.<network-name>`. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.

Returns:

  • (Array<String>, nil)


46
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 46

optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames

#driver_optsHash{Symbol=>String}?

DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.

Returns:

  • (Hash{Symbol=>String}, nil)


53
54
55
56
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 53

optional :driver_opts,
DockerEngineRuby::Internal::Type::HashOf[String],
api_name: :DriverOpts,
nil?: true

#endpoint_idString?

Unique ID for the service endpoint in a Sandbox.

Returns:

  • (String, nil)


62
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 62

optional :endpoint_id, String, api_name: :EndpointID

#gatewayString?

Gateway address for this network.

Returns:

  • (String, nil)


68
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 68

optional :gateway, String, api_name: :Gateway

#global_i_pv6_addressString?

Global IPv6 address.

Returns:

  • (String, nil)


74
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 74

optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address

#global_i_pv6_prefix_lenInteger?

Mask length of the global IPv6 address.

Returns:

  • (Integer, nil)


80
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 80

optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen

#gw_priorityInteger?

This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.

Returns:

  • (Integer, nil)


89
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 89

optional :gw_priority, Integer, api_name: :GwPriority

#i_pv6_gatewayString?

IPv6 gateway address.

Returns:

  • (String, nil)


115
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 115

optional :i_pv6_gateway, String, api_name: :IPv6Gateway

#ip_addressString?

IPv4 address.

Returns:

  • (String, nil)


95
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 95

optional :ip_address, String, api_name: :IPAddress

#ip_prefix_lenInteger?

Mask length of the IPv4 address.

Returns:

  • (Integer, nil)


109
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 109

optional :ip_prefix_len, Integer, api_name: :IPPrefixLen

#ipam_configDockerEngineRuby::Models::ConnectRequest::EndpointConfig::IpamConfig?

EndpointIPAMConfig represents an endpoint’s IPAM configuration.



101
102
103
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 101

optional :ipam_config,
-> { DockerEngineRuby::ConnectRequest::EndpointConfig::IpamConfig },
api_name: :IPAMConfig

Returns:

  • (Array<String>, nil)


120
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 120

optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links

#mac_addressString?

MAC address for the endpoint on this network. The network driver might ignore this parameter.

Returns:

  • (String, nil)


127
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 127

optional :mac_address, String, api_name: :MacAddress

#network_idString?

Unique ID of the network.

Returns:

  • (String, nil)


133
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 133

optional :network_id, String, api_name: :NetworkID