Class: DockerEngineRuby::Models::Container::HostConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container.rb

Overview

See Also:

Defined Under Namespace

Modules: CgroupnsMode, Isolation Classes: BlkioDeviceReadBp, BlkioDeviceReadIOp, BlkioDeviceWriteBp, BlkioDeviceWriteIOp, BlkioWeightDevice, Device, DeviceRequest, LogConfig, Mount, PortBinding, RestartPolicy, Ulimit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(host_ip: nil, host_port: nil) ⇒ Object

PortBinding represents a binding between a host IP address and a host port.

Parameters:

  • host_ip (String) (defaults to: nil)

    Host IP address that the container’s port is mapped to.

  • host_port (String) (defaults to: nil)

    Host port number that the container’s port is mapped to.



# File 'lib/docker_engine_ruby/models/container.rb', line 1045


Instance Attribute Details

#annotationsHash{Symbol=>String}?

Arbitrary non-identifying metadata attached to container and provided to the runtime when the container is started.

Returns:

  • (Hash{Symbol=>String}, nil)


305
# File 'lib/docker_engine_ruby/models/container.rb', line 305

optional :annotations, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Annotations

#auto_removeBoolean?

Automatically remove the container when the container’s process exits. This has no effect if RestartPolicy is set.

Returns:

  • (Boolean, nil)


312
# File 'lib/docker_engine_ruby/models/container.rb', line 312

optional :auto_remove, DockerEngineRuby::Internal::Type::Boolean, api_name: :AutoRemove

#bindsArray<String>?

A list of volume bindings for this container. Each volume binding is a string in one of these forms:

  • host-src:container-dest[:options] to bind-mount a host path into the container. Both host-src, and container-dest must be an absolute path.

  • volume-name:container-dest[:options] to bind-mount a volume managed by a volume driver into the container. container-dest must be an absolute path.

options is an optional, comma-delimited list of:

  • nocopy disables automatic copying of data from the container path to the volume. The nocopy flag only applies to named volumes.

  • ‘[ro|rw]` mounts a volume read-only or read-write, respectively. If omitted or set to rw, volumes are mounted read-write.

  • ‘[z|Z]` applies SELinux labels to allow or deny multiple containers to read and write to the same volume.

  • z: a shared content label is applied to the content. This label indicates that multiple containers can share the volume content, for both reading and writing.

  • Z: a _private unshared_ label is applied to the content. This label indicates that only the current container can use a private volume. Labeling systems such as SELinux require proper labels to be placed on volume content that is mounted into a container. Without a label, the security system can prevent a container’s processes from using the content. By default, the labels set by the host operating system are not modified.

  • ‘[[r]shared|slave|private]` specifies mount [propagation behavior](www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt). This only applies to bind-mounted volumes, not internal volumes or named volumes. Mount propagation requires the source mount point (the location where the source directory is mounted in the host operating system) to have the correct propagation properties. For shared volumes, the source mount point must be set to shared. For slave volumes, the mount must be set to either shared or slave.

Returns:

  • (Array<String>, nil)


350
# File 'lib/docker_engine_ruby/models/container.rb', line 350

optional :binds, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Binds

#blkio_device_read_bpsArray<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceReadBp>?

Limit read rate (bytes per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



360
361
362
363
364
# File 'lib/docker_engine_ruby/models/container.rb', line 360

optional :blkio_device_read_bps,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::BlkioDeviceReadBp]
},
api_name: :BlkioDeviceReadBps

#blkio_device_read_i_opsArray<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceReadIOp>?

Limit read rate (IO per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



374
375
376
377
378
# File 'lib/docker_engine_ruby/models/container.rb', line 374

optional :blkio_device_read_i_ops,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::BlkioDeviceReadIOp]
},
api_name: :BlkioDeviceReadIOps

#blkio_device_write_bpsArray<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceWriteBp>?

Limit write rate (bytes per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



388
389
390
391
392
# File 'lib/docker_engine_ruby/models/container.rb', line 388

optional :blkio_device_write_bps,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::BlkioDeviceWriteBp]
},
api_name: :BlkioDeviceWriteBps

#blkio_device_write_i_opsArray<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceWriteIOp>?

Limit write rate (IO per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



402
403
404
405
406
# File 'lib/docker_engine_ruby/models/container.rb', line 402

optional :blkio_device_write_i_ops,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::BlkioDeviceWriteIOp]
},
api_name: :BlkioDeviceWriteIOps

#blkio_weightInteger?

Block IO weight (relative weight).

Returns:

  • (Integer, nil)


412
# File 'lib/docker_engine_ruby/models/container.rb', line 412

optional :blkio_weight, Integer, api_name: :BlkioWeight

#blkio_weight_deviceArray<DockerEngineRuby::Models::Container::HostConfig::BlkioWeightDevice>?

Block IO weight (relative device weight) in the form:

“‘

“device_path”, “Weight”: weight

“‘



422
423
424
425
426
# File 'lib/docker_engine_ruby/models/container.rb', line 422

optional :blkio_weight_device,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::BlkioWeightDevice]
},
api_name: :BlkioWeightDevice

#cap_addArray<String>?

A list of kernel capabilities to add to the container. Conflicts with option ‘Capabilities’.

Returns:

  • (Array<String>, nil)


433
# File 'lib/docker_engine_ruby/models/container.rb', line 433

optional :cap_add, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :CapAdd

#cap_dropArray<String>?

A list of kernel capabilities to drop from the container. Conflicts with option ‘Capabilities’.

Returns:

  • (Array<String>, nil)


440
# File 'lib/docker_engine_ruby/models/container.rb', line 440

optional :cap_drop, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :CapDrop

#cgroupString?

Cgroup to use for the container.

Returns:

  • (String, nil)


446
# File 'lib/docker_engine_ruby/models/container.rb', line 446

optional :cgroup, String, api_name: :Cgroup

#cgroup_parentString?

Path to cgroups under which the container’s cgroup is created. If the path is not absolute, the path is considered to be relative to the cgroups path of the init process. Cgroups are created if they do not already exist.

Returns:

  • (String, nil)


468
# File 'lib/docker_engine_ruby/models/container.rb', line 468

optional :cgroup_parent, String, api_name: :CgroupParent

#cgroupns_modeSymbol, ...

cgroup namespace mode for the container. Possible values are:

  • ‘“private”`: the container runs in its own private cgroup namespace

  • ‘“host”`: use the host system’s cgroup namespace

If not specified, the daemon default is used, which can either be ‘“private”` or `“host”`, depending on daemon version, kernel support and configuration.



458
459
460
# File 'lib/docker_engine_ruby/models/container.rb', line 458

optional :cgroupns_mode,
enum: -> { DockerEngineRuby::Container::HostConfig::CgroupnsMode },
api_name: :CgroupnsMode

#console_sizeArray<Integer>?

Initial console size, as an ‘[height, width]` array.

Returns:

  • (Array<Integer>, nil)


474
475
476
477
# File 'lib/docker_engine_ruby/models/container.rb', line 474

optional :console_size,
DockerEngineRuby::Internal::Type::ArrayOf[Integer],
api_name: :ConsoleSize,
nil?: true

#container_id_fileString?

Path to a file where the container ID is written

Returns:

  • (String, nil)


483
# File 'lib/docker_engine_ruby/models/container.rb', line 483

optional :container_id_file, String, api_name: :ContainerIDFile

#cpu_countInteger?

The number of usable CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


493
# File 'lib/docker_engine_ruby/models/container.rb', line 493

optional :cpu_count, Integer, api_name: :CpuCount

#cpu_percentInteger?

The usable percentage of the available CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


503
# File 'lib/docker_engine_ruby/models/container.rb', line 503

optional :cpu_percent, Integer, api_name: :CpuPercent

#cpu_periodInteger?

The length of a CPU period in microseconds.

Returns:

  • (Integer, nil)


509
# File 'lib/docker_engine_ruby/models/container.rb', line 509

optional :cpu_period, Integer, api_name: :CpuPeriod

#cpu_quotaInteger?

Microseconds of CPU time that the container can get in a CPU period.

Returns:

  • (Integer, nil)


515
# File 'lib/docker_engine_ruby/models/container.rb', line 515

optional :cpu_quota, Integer, api_name: :CpuQuota

#cpu_realtime_periodInteger?

The length of a CPU real-time period in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


522
# File 'lib/docker_engine_ruby/models/container.rb', line 522

optional :cpu_realtime_period, Integer, api_name: :CpuRealtimePeriod

#cpu_realtime_runtimeInteger?

The length of a CPU real-time runtime in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


529
# File 'lib/docker_engine_ruby/models/container.rb', line 529

optional :cpu_realtime_runtime, Integer, api_name: :CpuRealtimeRuntime

#cpu_sharesInteger?

An integer value representing this container’s relative CPU weight versus other containers.

Returns:

  • (Integer, nil)


549
# File 'lib/docker_engine_ruby/models/container.rb', line 549

optional :cpu_shares, Integer, api_name: :CpuShares

#cpuset_cpusString?

CPUs in which to allow execution (e.g., 0-3, ‘0,1`).

Returns:

  • (String, nil)


535
# File 'lib/docker_engine_ruby/models/container.rb', line 535

optional :cpuset_cpus, String, api_name: :CpusetCpus

#cpuset_memsString?

Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only effective on NUMA systems.

Returns:

  • (String, nil)


542
# File 'lib/docker_engine_ruby/models/container.rb', line 542

optional :cpuset_mems, String, api_name: :CpusetMems

#device_cgroup_rulesArray<String>?

a list of cgroup rules to apply to the container

Returns:

  • (Array<String>, nil)


555
556
557
# File 'lib/docker_engine_ruby/models/container.rb', line 555

optional :device_cgroup_rules,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :DeviceCgroupRules

#device_requestsArray<DockerEngineRuby::Models::Container::HostConfig::DeviceRequest>?

A list of requests for devices to be sent to device drivers.



563
564
565
566
567
# File 'lib/docker_engine_ruby/models/container.rb', line 563

optional :device_requests,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::DeviceRequest]
},
api_name: :DeviceRequests

#devicesArray<DockerEngineRuby::Models::Container::HostConfig::Device>?

A list of devices to add to the container.



573
574
575
576
577
# File 'lib/docker_engine_ruby/models/container.rb', line 573

optional :devices,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::Device]
},
api_name: :Devices

#dnsArray<String>?

A list of DNS servers for the container to use.

Returns:

  • (Array<String>, nil)


583
# File 'lib/docker_engine_ruby/models/container.rb', line 583

optional :dns, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Dns

#dns_optionsArray<String>?

A list of DNS options.

Returns:

  • (Array<String>, nil)


589
# File 'lib/docker_engine_ruby/models/container.rb', line 589

optional :dns_options, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DnsOptions

#dns_searchArray<String>?

A list of DNS search domains.

Returns:

  • (Array<String>, nil)


595
# File 'lib/docker_engine_ruby/models/container.rb', line 595

optional :dns_search, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DnsSearch

#extra_hostsArray<String>?

A list of hostnames/IP mappings to add to the container’s /etc/hosts file. Specified in the form ‘[“hostname:IP”]`.

Returns:

  • (Array<String>, nil)


602
# File 'lib/docker_engine_ruby/models/container.rb', line 602

optional :extra_hosts, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :ExtraHosts

#group_addArray<String>?

A list of additional groups that the container process will run as.

Returns:

  • (Array<String>, nil)


608
# File 'lib/docker_engine_ruby/models/container.rb', line 608

optional :group_add, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :GroupAdd

#initBoolean?

Run an init inside the container that forwards signals and reaps processes. This field is omitted if empty, and the default (as configured on the daemon) is used.

Returns:

  • (Boolean, nil)


616
# File 'lib/docker_engine_ruby/models/container.rb', line 616

optional :init, DockerEngineRuby::Internal::Type::Boolean, api_name: :Init, nil?: true

#io_maximum_bandwidthInteger?

Maximum IO in bytes per second for the container system drive (Windows only).

Returns:

  • (Integer, nil)


622
# File 'lib/docker_engine_ruby/models/container.rb', line 622

optional :io_maximum_bandwidth, Integer, api_name: :IOMaximumBandwidth

#io_maximum_i_opsInteger?

Maximum IOps for the container system drive (Windows only)

Returns:

  • (Integer, nil)


628
# File 'lib/docker_engine_ruby/models/container.rb', line 628

optional :io_maximum_i_ops, Integer, api_name: :IOMaximumIOps

#ipc_modeString?

IPC sharing mode for the container. Possible values are:

  • ‘“none”`: own private IPC namespace, with /dev/shm not mounted

  • ‘“private”`: own private IPC namespace

  • ‘“shareable”`: own private IPC namespace, with a possibility to share it with other containers

  • ‘“container:<name|id>”`: join another (shareable) container’s IPC namespace

  • ‘“host”`: use the host system’s IPC namespace

If not specified, daemon default is used, which can either be ‘“private”` or `“shareable”`, depending on daemon version and configuration.

Returns:

  • (String, nil)


644
# File 'lib/docker_engine_ruby/models/container.rb', line 644

optional :ipc_mode, String, api_name: :IpcMode

#isolationSymbol, ...

Isolation technology of the container. (Windows only)



650
651
652
653
654
# File 'lib/docker_engine_ruby/models/container.rb', line 650

optional :isolation,
enum: -> {
  DockerEngineRuby::Container::HostConfig::Isolation
},
api_name: :Isolation

A list of links for the container in the form container_name:alias.

Returns:

  • (Array<String>, nil)


660
# File 'lib/docker_engine_ruby/models/container.rb', line 660

optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links

#log_configDockerEngineRuby::Models::Container::HostConfig::LogConfig?

The logging configuration for this container



666
# File 'lib/docker_engine_ruby/models/container.rb', line 666

optional :log_config, -> { DockerEngineRuby::Container::HostConfig::LogConfig }, api_name: :LogConfig

#masked_pathsArray<String>?

The list of paths to be masked inside the container (this overrides the default set of paths).

Returns:

  • (Array<String>, nil)


673
# File 'lib/docker_engine_ruby/models/container.rb', line 673

optional :masked_paths, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :MaskedPaths

#memoryInteger?

Memory limit in bytes.

Returns:

  • (Integer, nil)


679
# File 'lib/docker_engine_ruby/models/container.rb', line 679

optional :memory, Integer, api_name: :Memory

#memory_reservationInteger?

Memory soft limit in bytes.

Returns:

  • (Integer, nil)


685
# File 'lib/docker_engine_ruby/models/container.rb', line 685

optional :memory_reservation, Integer, api_name: :MemoryReservation

#memory_swapInteger?

Total memory limit (memory + swap). Set as -1 to enable unlimited swap.

Returns:

  • (Integer, nil)


691
# File 'lib/docker_engine_ruby/models/container.rb', line 691

optional :memory_swap, Integer, api_name: :MemorySwap

#memory_swappinessInteger?

Tune a container’s memory swappiness behavior. Accepts an integer between 0 and 100.

Returns:

  • (Integer, nil)


698
# File 'lib/docker_engine_ruby/models/container.rb', line 698

optional :memory_swappiness, Integer, api_name: :MemorySwappiness

#mountsArray<DockerEngineRuby::Models::Container::HostConfig::Mount>?

Specification for mounts to be added to the container.



704
705
706
707
708
# File 'lib/docker_engine_ruby/models/container.rb', line 704

optional :mounts,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::Mount]
},
api_name: :Mounts

#nano_cpusInteger?

CPU quota in units of 10<sup>-9</sup> CPUs.

Returns:

  • (Integer, nil)


714
# File 'lib/docker_engine_ruby/models/container.rb', line 714

optional :nano_cpus, Integer, api_name: :NanoCpus

#network_modeString?

Network mode to use for this container. Supported standard values are: bridge, host, none, and ‘container:<name|id>`. Any other value is taken as a custom network’s name to which this container should connect to.

Returns:

  • (String, nil)


722
# File 'lib/docker_engine_ruby/models/container.rb', line 722

optional :network_mode, String, api_name: :NetworkMode

#oom_kill_disableBoolean?

Disable OOM Killer for the container.

Returns:

  • (Boolean, nil)


728
# File 'lib/docker_engine_ruby/models/container.rb', line 728

optional :oom_kill_disable, DockerEngineRuby::Internal::Type::Boolean, api_name: :OomKillDisable

#oom_score_adjInteger?

An integer value containing the score given to the container in order to tune OOM killer preferences.

Returns:

  • (Integer, nil)


735
# File 'lib/docker_engine_ruby/models/container.rb', line 735

optional :oom_score_adj, Integer, api_name: :OomScoreAdj

#pid_modeString?

Set the PID (Process) Namespace mode for the container. It can be either:

  • ‘“container:<name|id>”`: joins another container’s PID namespace

  • ‘“host”`: use the host’s PID namespace inside the container

Returns:

  • (String, nil)


744
# File 'lib/docker_engine_ruby/models/container.rb', line 744

optional :pid_mode, String, api_name: :PidMode

#pids_limitInteger?

Tune a container’s PIDs limit. Set 0 or -1 for unlimited, or null to not change.

Returns:

  • (Integer, nil)


751
# File 'lib/docker_engine_ruby/models/container.rb', line 751

optional :pids_limit, Integer, api_name: :PidsLimit, nil?: true

#port_bindingsHash{Symbol=>Array<DockerEngineRuby::Models::Container::HostConfig::PortBinding>}?



756
757
758
759
760
# File 'lib/docker_engine_ruby/models/container.rb', line 756

optional :port_bindings,
-> {
  DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::PortBinding]]
},
api_name: :PortBindings

#privilegedBoolean?

Gives the container full access to the host.

Returns:

  • (Boolean, nil)


766
# File 'lib/docker_engine_ruby/models/container.rb', line 766

optional :privileged, DockerEngineRuby::Internal::Type::Boolean, api_name: :Privileged

#publish_all_portsBoolean?

Allocates an ephemeral host port for all of a container’s exposed ports.

Ports are de-allocated when the container stops and allocated when the container starts. The allocated port might be changed when restarting the container.

The port is selected from the ephemeral port range that depends on the kernel. For example, on Linux the range is defined by /proc/sys/net/ipv4/ip_local_port_range.

Returns:

  • (Boolean, nil)


779
# File 'lib/docker_engine_ruby/models/container.rb', line 779

optional :publish_all_ports, DockerEngineRuby::Internal::Type::Boolean, api_name: :PublishAllPorts

#readonly_pathsArray<String>?

The list of paths to be set as read-only inside the container (this overrides the default set of paths).

Returns:

  • (Array<String>, nil)


786
# File 'lib/docker_engine_ruby/models/container.rb', line 786

optional :readonly_paths, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :ReadonlyPaths

#readonly_rootfsBoolean?

Mount the container’s root filesystem as read only.

Returns:

  • (Boolean, nil)


792
# File 'lib/docker_engine_ruby/models/container.rb', line 792

optional :readonly_rootfs, DockerEngineRuby::Internal::Type::Boolean, api_name: :ReadonlyRootfs

#restart_policyDockerEngineRuby::Models::Container::HostConfig::RestartPolicy?

The behavior to apply when the container exits. The default is not to restart.

An ever increasing delay (double the previous delay, starting at 100ms) is added before each restart to prevent flooding the server.



801
802
803
# File 'lib/docker_engine_ruby/models/container.rb', line 801

optional :restart_policy,
-> { DockerEngineRuby::Container::HostConfig::RestartPolicy },
api_name: :RestartPolicy

#runtimeString?

Runtime to use with this container.

Returns:

  • (String, nil)


809
# File 'lib/docker_engine_ruby/models/container.rb', line 809

optional :runtime, String, api_name: :Runtime, nil?: true

#security_optArray<String>?

A list of string values to customize labels for MLS systems, such as SELinux.

Returns:

  • (Array<String>, nil)


815
# File 'lib/docker_engine_ruby/models/container.rb', line 815

optional :security_opt, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :SecurityOpt

#shm_sizeInteger?

Size of /dev/shm in bytes. If omitted, the system uses 64MB.

Returns:

  • (Integer, nil)


821
# File 'lib/docker_engine_ruby/models/container.rb', line 821

optional :shm_size, Integer, api_name: :ShmSize

#storage_optHash{Symbol=>String}?

Storage driver options for this container, in the form ‘“120G”`.

Returns:

  • (Hash{Symbol=>String}, nil)


827
# File 'lib/docker_engine_ruby/models/container.rb', line 827

optional :storage_opt, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :StorageOpt

#sysctlsHash{Symbol=>String}?

A list of kernel parameters (sysctls) to set in the container.

This field is omitted if not set.

Returns:

  • (Hash{Symbol=>String}, nil)


835
# File 'lib/docker_engine_ruby/models/container.rb', line 835

optional :sysctls, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Sysctls, nil?: true

#tmpfsHash{Symbol=>String}?

A map of container directories which should be replaced by tmpfs mounts, and their corresponding mount options. For example:

“‘ { “/run”: “rw,noexec,nosuid,size=65536k” } “`

Returns:

  • (Hash{Symbol=>String}, nil)


846
# File 'lib/docker_engine_ruby/models/container.rb', line 846

optional :tmpfs, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Tmpfs

#ulimitsArray<DockerEngineRuby::Models::Container::HostConfig::Ulimit>?

A list of resource limits to set in the container. For example:

“‘ “nofile”, “Soft”: 1024, “Hard”: 2048 “`



856
857
858
859
860
# File 'lib/docker_engine_ruby/models/container.rb', line 856

optional :ulimits,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::HostConfig::Ulimit]
},
api_name: :Ulimits

#userns_modeString?

Sets the usernamespace mode for the container when usernamespace remapping option is enabled.

Returns:

  • (String, nil)


867
# File 'lib/docker_engine_ruby/models/container.rb', line 867

optional :userns_mode, String, api_name: :UsernsMode

#uts_modeString?

UTS namespace to use for the container.

Returns:

  • (String, nil)


873
# File 'lib/docker_engine_ruby/models/container.rb', line 873

optional :uts_mode, String, api_name: :UTSMode

#volume_driverString?

Driver that this container uses to mount volumes.

Returns:

  • (String, nil)


879
# File 'lib/docker_engine_ruby/models/container.rb', line 879

optional :volume_driver, String, api_name: :VolumeDriver

#volumes_fromArray<String>?

A list of volumes to inherit from another container, specified in the form ‘<container name>`.

Returns:

  • (Array<String>, nil)


886
# File 'lib/docker_engine_ruby/models/container.rb', line 886

optional :volumes_from, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :VolumesFrom

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/container.rb', line 1139