Class: DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceReadBp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(annotations: nil, auto_remove: nil, binds: nil, blkio_device_read_bps: nil, blkio_device_read_i_ops: nil, blkio_device_write_bps: nil, blkio_device_write_i_ops: nil, blkio_weight: nil, blkio_weight_device: nil, cap_add: nil, cap_drop: nil, cgroup: nil, cgroupns_mode: nil, cgroup_parent: nil, console_size: nil, container_id_file: nil, cpu_count: nil, cpu_percent: nil, cpu_period: nil, cpu_quota: nil, cpu_realtime_period: nil, cpu_realtime_runtime: nil, cpuset_cpus: nil, cpuset_mems: nil, cpu_shares: nil, device_cgroup_rules: nil, device_requests: nil, devices: nil, dns: nil, dns_options: nil, dns_search: nil, extra_hosts: nil, group_add: nil, init: nil, io_maximum_bandwidth: nil, io_maximum_i_ops: nil, ipc_mode: nil, isolation: nil, links: nil, log_config: nil, masked_paths: nil, memory: nil, memory_reservation: nil, memory_swap: nil, memory_swappiness: nil, mounts: nil, nano_cpus: nil, network_mode: nil, oom_kill_disable: nil, oom_score_adj: nil, pid_mode: nil, pids_limit: nil, port_bindings: nil, privileged: nil, publish_all_ports: nil, readonly_paths: nil, readonly_rootfs: nil, restart_policy: nil, runtime: nil, security_opt: nil, shm_size: nil, storage_opt: nil, sysctls: nil, tmpfs: nil, ulimits: nil, userns_mode: nil, uts_mode: nil, volume_driver: nil, volumes_from: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Container::HostConfig for more details.

Container configuration that depends on the host we are running on

Parameters:

  • annotations (Hash{Symbol=>String}) (defaults to: nil)

    Arbitrary non-identifying metadata attached to container and

  • auto_remove (Boolean) (defaults to: nil)

    Automatically remove the container when the container’s process

  • binds (Array<String>) (defaults to: nil)

    A list of volume bindings for this container. Each volume binding

  • blkio_device_read_bps (Array<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceReadBp>) (defaults to: nil)

    Limit read rate (bytes per second) from a device, in the form:

  • blkio_device_read_i_ops (Array<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceReadIOp>) (defaults to: nil)

    Limit read rate (IO per second) from a device, in the form:

  • blkio_device_write_bps (Array<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceWriteBp>) (defaults to: nil)

    Limit write rate (bytes per second) to a device, in the form:

  • blkio_device_write_i_ops (Array<DockerEngineRuby::Models::Container::HostConfig::BlkioDeviceWriteIOp>) (defaults to: nil)

    Limit write rate (IO per second) to a device, in the form:

  • blkio_weight (Integer) (defaults to: nil)

    Block IO weight (relative weight).

  • blkio_weight_device (Array<DockerEngineRuby::Models::Container::HostConfig::BlkioWeightDevice>) (defaults to: nil)

    Block IO weight (relative device weight) in the form:

  • cap_add (Array<String>) (defaults to: nil)

    A list of kernel capabilities to add to the container. Conflicts

  • cap_drop (Array<String>) (defaults to: nil)

    A list of kernel capabilities to drop from the container. Conflicts

  • cgroup (String) (defaults to: nil)

    Cgroup to use for the container.

  • cgroupns_mode (Symbol, DockerEngineRuby::Models::Container::HostConfig::CgroupnsMode) (defaults to: nil)

    cgroup namespace mode for the container. Possible values are:

  • cgroup_parent (String) (defaults to: nil)

    Path to cgroups under which the container’s cgroup is created. If

  • console_size (Array<Integer>, nil) (defaults to: nil)

    Initial console size, as an ‘[height, width]` array.

  • container_id_file (String) (defaults to: nil)

    Path to a file where the container ID is written

  • cpu_count (Integer) (defaults to: nil)

    The number of usable CPUs (Windows only).

  • cpu_percent (Integer) (defaults to: nil)

    The usable percentage of the available CPUs (Windows only).

  • cpu_period (Integer) (defaults to: nil)

    The length of a CPU period in microseconds.

  • cpu_quota (Integer) (defaults to: nil)

    Microseconds of CPU time that the container can get in a CPU period.

  • cpu_realtime_period (Integer) (defaults to: nil)

    The length of a CPU real-time period in microseconds. Set to 0 to

  • cpu_realtime_runtime (Integer) (defaults to: nil)

    The length of a CPU real-time runtime in microseconds. Set to 0 to

  • cpuset_cpus (String) (defaults to: nil)

    CPUs in which to allow execution (e.g., 0-3, ‘0,1`).

  • cpuset_mems (String) (defaults to: nil)

    Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only

  • cpu_shares (Integer) (defaults to: nil)

    An integer value representing this container’s relative CPU weight

  • device_cgroup_rules (Array<String>) (defaults to: nil)

    a list of cgroup rules to apply to the container

  • device_requests (Array<DockerEngineRuby::Models::Container::HostConfig::DeviceRequest>) (defaults to: nil)

    A list of requests for devices to be sent to device drivers.

  • devices (Array<DockerEngineRuby::Models::Container::HostConfig::Device>) (defaults to: nil)

    A list of devices to add to the container.

  • dns (Array<String>) (defaults to: nil)

    A list of DNS servers for the container to use.

  • dns_options (Array<String>) (defaults to: nil)

    A list of DNS options.

  • dns_search (Array<String>) (defaults to: nil)

    A list of DNS search domains.

  • extra_hosts (Array<String>) (defaults to: nil)

    A list of hostnames/IP mappings to add to the container’s /etc/hosts

  • group_add (Array<String>) (defaults to: nil)

    A list of additional groups that the container process will run as.

  • init (Boolean, nil) (defaults to: nil)

    Run an init inside the container that forwards signals and reaps

  • io_maximum_bandwidth (Integer) (defaults to: nil)

    Maximum IO in bytes per second for the container system drive

  • io_maximum_i_ops (Integer) (defaults to: nil)

    Maximum IOps for the container system drive (Windows only)

  • ipc_mode (String) (defaults to: nil)

    IPC sharing mode for the container. Possible values are:

  • isolation (Symbol, DockerEngineRuby::Models::Container::HostConfig::Isolation) (defaults to: nil)

    Isolation technology of the container. (Windows only)

  • links (Array<String>) (defaults to: nil)

    A list of links for the container in the form container_name:alias.

  • log_config (DockerEngineRuby::Models::Container::HostConfig::LogConfig) (defaults to: nil)

    The logging configuration for this container

  • masked_paths (Array<String>) (defaults to: nil)

    The list of paths to be masked inside the container (this overrides

  • memory (Integer) (defaults to: nil)

    Memory limit in bytes.

  • memory_reservation (Integer) (defaults to: nil)

    Memory soft limit in bytes.

  • memory_swap (Integer) (defaults to: nil)

    Total memory limit (memory + swap). Set as -1 to enable unlimited

  • memory_swappiness (Integer) (defaults to: nil)

    Tune a container’s memory swappiness behavior. Accepts an integer

  • mounts (Array<DockerEngineRuby::Models::Container::HostConfig::Mount>) (defaults to: nil)

    Specification for mounts to be added to the container.

  • nano_cpus (Integer) (defaults to: nil)

    CPU quota in units of 10<sup>-9</sup> CPUs.

  • network_mode (String) (defaults to: nil)

    Network mode to use for this container. Supported standard values

  • oom_kill_disable (Boolean) (defaults to: nil)

    Disable OOM Killer for the container.

  • oom_score_adj (Integer) (defaults to: nil)

    An integer value containing the score given to the container in

  • pid_mode (String) (defaults to: nil)

    Set the PID (Process) Namespace mode for the container. It can be

  • pids_limit (Integer, nil) (defaults to: nil)

    Tune a container’s PIDs limit. Set 0 or -1 for unlimited, or null

  • port_bindings (Hash{Symbol=>Array<DockerEngineRuby::Models::Container::HostConfig::PortBinding>}) (defaults to: nil)
  • privileged (Boolean) (defaults to: nil)

    Gives the container full access to the host.

  • publish_all_ports (Boolean) (defaults to: nil)

    Allocates an ephemeral host port for all of a container’s

  • readonly_paths (Array<String>) (defaults to: nil)

    The list of paths to be set as read-only inside the container

  • readonly_rootfs (Boolean) (defaults to: nil)

    Mount the container’s root filesystem as read only.

  • restart_policy (DockerEngineRuby::Models::Container::HostConfig::RestartPolicy) (defaults to: nil)

    The behavior to apply when the container exits. The default is not to

  • runtime (String, nil) (defaults to: nil)

    Runtime to use with this container.

  • security_opt (Array<String>) (defaults to: nil)

    A list of string values to customize labels for MLS systems, such

  • shm_size (Integer) (defaults to: nil)

    Size of /dev/shm in bytes. If omitted, the system uses 64MB.

  • storage_opt (Hash{Symbol=>String}) (defaults to: nil)

    Storage driver options for this container, in the form ‘“120G”`.

  • sysctls (Hash{Symbol=>String}, nil) (defaults to: nil)

    A list of kernel parameters (sysctls) to set in the container.

  • tmpfs (Hash{Symbol=>String}) (defaults to: nil)

    A map of container directories which should be replaced by tmpfs

  • ulimits (Array<DockerEngineRuby::Models::Container::HostConfig::Ulimit>) (defaults to: nil)

    A list of resource limits to set in the container. For example:

  • userns_mode (String) (defaults to: nil)

    Sets the usernamespace mode for the container when usernamespace

  • uts_mode (String) (defaults to: nil)

    UTS namespace to use for the container.

  • volume_driver (String) (defaults to: nil)

    Driver that this container uses to mount volumes.

  • volumes_from (Array<String>) (defaults to: nil)

    A list of volumes to inherit from another container, specified in



1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'lib/docker_engine_ruby/models/container.rb', line 1032

class BlkioDeviceReadBp < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute path
  #   Device path
  #
  #   @return [String, nil]
  optional :path, String, api_name: :Path

  # @!attribute rate
  #   Rate
  #
  #   @return [Integer, nil]
  optional :rate, Integer, api_name: :Rate

  # @!method initialize(path: nil, rate: nil)
  #   @param path [String] Device path
  #
  #   @param rate [Integer] Rate
end

Instance Attribute Details

#pathString?

Device path

Returns:

  • (String, nil)


1037
# File 'lib/docker_engine_ruby/models/container.rb', line 1037

optional :path, String, api_name: :Path

#rateInteger?

Rate

Returns:

  • (Integer, nil)


1043
# File 'lib/docker_engine_ruby/models/container.rb', line 1043

optional :rate, Integer, api_name: :Rate