Module: DockerEngineRuby::Models::Container::HostConfig::CgroupnsMode

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/container.rb,
sig/docker_engine_ruby/models/container.rbs

Overview

cgroup namespace mode for the container. Possible values are:

  • "private": the container runs in its own private cgroup namespace
  • "host": use the host system's cgroup namespace

If not specified, the daemon default is used, which can either be "private" or "host", depending on daemon version, kernel support and configuration.

See Also:

  • DockerEngineRuby::Models::Container::HostConfig#cgroupns_mode

Constant Summary collapse

PRIVATE =

Returns:

  • (:private)
:private
HOST =

Returns:

  • (:host)
:host

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[DockerEngineRuby::Models::Container::HostConfig::cgroupns_mode]

Returns:

  • (::Array[DockerEngineRuby::Models::Container::HostConfig::cgroupns_mode])


811
# File 'sig/docker_engine_ruby/models/container.rbs', line 811

def self?.values: -> ::Array[DockerEngineRuby::Models::Container::HostConfig::cgroupns_mode]