Module: DockerEngineRuby::Models::Container::HostConfig::Mount::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/container.rb,
sig/docker_engine_ruby/models/container.rbs

Overview

The mount type. Available types:

  • bind a mount of a file or directory from the host into the container.
  • cluster a Swarm cluster volume.
  • image an OCI image.
  • npipe a named pipe from the host into the container.
  • tmpfs a tmpfs.
  • volume a docker volume with the given Name.

See Also:

  • DockerEngineRuby::Models::Container::HostConfig::Mount#type

Constant Summary collapse

BIND =

Returns:

  • (:bind)
:bind
CLUSTER =

Returns:

  • (:cluster)
:cluster
IMAGE =

Returns:

  • (:image)
:image
NPIPE =

Returns:

  • (:npipe)
:npipe
TMPFS =

Returns:

  • (:tmpfs)
:tmpfs
VOLUME =

Returns:

  • (:volume)
:volume

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[DockerEngineRuby::Models::Container::HostConfig::Mount::type_]

Returns:

  • (::Array[DockerEngineRuby::Models::Container::HostConfig::Mount::type_])


1172
# File 'sig/docker_engine_ruby/models/container.rbs', line 1172

def self?.values: -> ::Array[DockerEngineRuby::Models::Container::HostConfig::Mount::type_]