Module: DockerEngineRuby::Models::Container::HostConfig::RestartPolicy::Name
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine_ruby/models/container.rb,
sig/docker_engine_ruby/models/container.rbs
Overview
- Empty string means not to restart
noDo not automatically restartalwaysAlways restartunless-stoppedRestart always except when the user has manually stopped the containeron-failureRestart only when the container exit code is non-zero
Constant Summary collapse
- EMPTY =
:""- NO =
:no- ALWAYS =
:always- UNLESS_STOPPED =
:"unless-stopped"- ON_FAILURE =
:"on-failure"
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[DockerEngineRuby::Models::Container::HostConfig::RestartPolicy::name_]
1292 |
# File 'sig/docker_engine_ruby/models/container.rbs', line 1292
def self?.values: -> ::Array[DockerEngineRuby::Models::Container::HostConfig::RestartPolicy::name_]
|