Class: DockerEngineRuby::Models::Container::Mount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destination: nil, driver: nil, mode: nil, name: nil, propagation: nil, rw: nil, source: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Container::Mount for more details.

MountPoint represents a mount point configuration inside the container. This is used for reporting the mountpoints in use by a container.

Parameters:

  • destination (String) (defaults to: nil)

    Destination is the path relative to the container root (/) where

  • driver (String) (defaults to: nil)

    Driver is the volume driver used to create the volume (if it is a volume).

  • mode (String) (defaults to: nil)

    Mode is a comma separated list of options supplied by the user when

  • name (String) (defaults to: nil)

    Name is the name reference to the underlying data defined by Source

  • propagation (String) (defaults to: nil)

    Propagation describes how mounts are propagated from the host into the

  • rw (Boolean) (defaults to: nil)

    Whether the mount is mounted writable (read-write).

  • source (String) (defaults to: nil)

    Source location of the mount.

  • type (Symbol, DockerEngineRuby::Models::Container::Mount::Type) (defaults to: nil)

    The mount type. Available types:



# File 'lib/docker_engine_ruby/models/container.rb', line 1861


Instance Attribute Details

#destinationString?

Destination is the path relative to the container root (/) where the Source is mounted inside the container.

Returns:

  • (String, nil)


1798
# File 'lib/docker_engine_ruby/models/container.rb', line 1798

optional :destination, String, api_name: :Destination

#driverString?

Driver is the volume driver used to create the volume (if it is a volume).

Returns:

  • (String, nil)


1804
# File 'lib/docker_engine_ruby/models/container.rb', line 1804

optional :driver, String, api_name: :Driver

#modeString?

Mode is a comma separated list of options supplied by the user when creating the bind/volume mount.

The default is platform-specific (‘“z”` on Linux, empty on Windows).

Returns:

  • (String, nil)


1813
# File 'lib/docker_engine_ruby/models/container.rb', line 1813

optional :mode, String, api_name: :Mode

#nameString?

Name is the name reference to the underlying data defined by Source e.g., the volume name.

Returns:

  • (String, nil)


1820
# File 'lib/docker_engine_ruby/models/container.rb', line 1820

optional :name, String, api_name: :Name

#propagationString?

Propagation describes how mounts are propagated from the host into the mount point, and vice-versa. Refer to the [Linux kernel documentation](www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt) for details. This field is not used on Windows.

Returns:

  • (String, nil)


1829
# File 'lib/docker_engine_ruby/models/container.rb', line 1829

optional :propagation, String, api_name: :Propagation

#rwBoolean?

Whether the mount is mounted writable (read-write).

Returns:

  • (Boolean, nil)


1835
# File 'lib/docker_engine_ruby/models/container.rb', line 1835

optional :rw, DockerEngineRuby::Internal::Type::Boolean, api_name: :RW

#sourceString?

Source location of the mount.

For volumes, this contains the storage location of the volume (within /var/lib/docker/volumes/). For bind-mounts, and npipe, this contains the source (host) part of the bind-mount. For tmpfs mount points, this field is empty.

Returns:

  • (String, nil)


1846
# File 'lib/docker_engine_ruby/models/container.rb', line 1846

optional :source, String, api_name: :Source

#typeSymbol, ...

The mount type. Available types:

  • bind a mount of a file or directory from the host into the container.

  • cluster a Swarm cluster volume.

  • image an OCI image.

  • npipe a named pipe from the host into the container.

  • tmpfs a tmpfs.

  • volume a docker volume with the given Name.



1859
# File 'lib/docker_engine_ruby/models/container.rb', line 1859

optional :type, enum: -> { DockerEngineRuby::Container::Mount::Type }, api_name: :Type