Class: DockerEngineRuby::Models::Container::NetworkSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Container::NetworkSettings
- Defined in:
- lib/docker_engine_ruby/models/container.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#networks ⇒ Hash{Symbol=>DockerEngineRuby::Models::Container::NetworkSettings::Network}?
Information about all networks that the container is connected to.
- #ports ⇒ Hash{Symbol=>Array<DockerEngineRuby::Models::Container::NetworkSettings::Port>}?
-
#sandbox_id ⇒ String?
SandboxID uniquely represents a container’s network stack.
-
#sandbox_key ⇒ String?
SandboxKey is the full path of the netns handle.
Instance Method Summary collapse
-
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
constructor
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
|
|
# File 'lib/docker_engine_ruby/models/container.rb', line 2114
|
Instance Attribute Details
#networks ⇒ Hash{Symbol=>DockerEngineRuby::Models::Container::NetworkSettings::Network}?
Information about all networks that the container is connected to.
1915 1916 1917 1918 1919 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1915 optional :networks, -> { DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Container::NetworkSettings::Network] }, api_name: :Networks |
#ports ⇒ Hash{Symbol=>Array<DockerEngineRuby::Models::Container::NetworkSettings::Port>}?
1924 1925 1926 1927 1928 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1924 optional :ports, -> { DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::NetworkSettings::Port]] }, api_name: :Ports |
#sandbox_id ⇒ String?
SandboxID uniquely represents a container’s network stack.
1934 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1934 optional :sandbox_id, String, api_name: :SandboxID |
#sandbox_key ⇒ String?
SandboxKey is the full path of the netns handle
1940 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1940 optional :sandbox_key, String, api_name: :SandboxKey |