Class: DockerEngineRuby::Models::Container::State::Health
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Container::State::Health
- Defined in:
- lib/docker_engine_ruby/models/container.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#failing_streak ⇒ Integer?
FailingStreak is the number of consecutive failures.
-
#log ⇒ Array<DockerEngineRuby::Models::Container::State::Health::Log>?
Log contains the last few results (oldest first).
-
#status ⇒ Symbol, ...
Status is one of
none,starting,healthyorunhealthy.
Instance Method Summary collapse
-
#initialize(end_: nil, exit_code: nil, output: nil, start: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Log for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, exit_code: nil, output: nil, start: nil) ⇒ Object
Some parameter documentations has been truncated, see Log for more details.
HealthcheckResult stores information about a single run of a healthcheck probe
|
|
# File 'lib/docker_engine_ruby/models/container.rb', line 2332
|
Instance Attribute Details
#failing_streak ⇒ Integer?
FailingStreak is the number of consecutive failures
2265 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2265 optional :failing_streak, Integer, api_name: :FailingStreak |
#log ⇒ Array<DockerEngineRuby::Models::Container::State::Health::Log>?
Log contains the last few results (oldest first)
2271 2272 2273 2274 2275 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2271 optional :log, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::State::Health::Log] }, api_name: :Log |
#status ⇒ Symbol, ...
Status is one of none, starting, healthy or unhealthy
-
“none” Indicates there is no healthcheck
-
“starting” Starting indicates that the container is not yet ready
-
“healthy” Healthy indicates that the container is running correctly
-
“unhealthy” Unhealthy indicates that the container has a problem
2286 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2286 optional :status, enum: -> { DockerEngineRuby::Container::State::Health::Status }, api_name: :Status |