Class: DockerEngineRuby::Models::Container::State::Health::Log

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(failing_streak: nil, log: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Container::State::Health for more details.

Health stores information about the container’s healthcheck results.

Parameters:



2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/docker_engine_ruby/models/container.rb', line 2300

class Log < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute end_
  #   Date and time at which this check ended in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [Time, nil]
  optional :end_, Time, api_name: :End

  # @!attribute exit_code
  #   ExitCode meanings:
  #
  #   - `0` healthy
  #   - `1` unhealthy
  #   - `2` reserved (considered unhealthy)
  #   - other values: error running probe
  #
  #   @return [Integer, nil]
  optional :exit_code, Integer, api_name: :ExitCode

  # @!attribute output
  #   Output from last check
  #
  #   @return [String, nil]
  optional :output, String, api_name: :Output

  # @!attribute start
  #   Date and time at which this check started in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [Time, nil]
  optional :start, Time, api_name: :Start

  # @!method initialize(end_: nil, exit_code: nil, output: nil, start: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineRuby::Models::Container::State::Health::Log} for more details.
  #
  #   HealthcheckResult stores information about a single run of a healthcheck probe
  #
  #   @param end_ [Time] Date and time at which this check ended in
  #
  #   @param exit_code [Integer] ExitCode meanings:
  #
  #   @param output [String] Output from last check
  #
  #   @param start [Time] Date and time at which this check started in
end

Instance Attribute Details

#end_Time?

Date and time at which this check ended in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (Time, nil)


2306
# File 'lib/docker_engine_ruby/models/container.rb', line 2306

optional :end_, Time, api_name: :End

#exit_codeInteger?

ExitCode meanings:

  • 0 healthy

  • 1 unhealthy

  • 2 reserved (considered unhealthy)

  • other values: error running probe

Returns:

  • (Integer, nil)


2317
# File 'lib/docker_engine_ruby/models/container.rb', line 2317

optional :exit_code, Integer, api_name: :ExitCode

#outputString?

Output from last check

Returns:

  • (String, nil)


2323
# File 'lib/docker_engine_ruby/models/container.rb', line 2323

optional :output, String, api_name: :Output

#startTime?

Date and time at which this check started in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (Time, nil)


2330
# File 'lib/docker_engine_ruby/models/container.rb', line 2330

optional :start, Time, api_name: :Start