Module: DockerEngineRuby::Models::Container::State::Health::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/container.rb,
sig/docker_engine_ruby/models/container.rbs

Overview

Status is one of none, starting, healthy or unhealthy

  • "none" Indicates there is no healthcheck
  • "starting" Starting indicates that the container is not yet ready
  • "healthy" Healthy indicates that the container is running correctly
  • "unhealthy" Unhealthy indicates that the container has a problem

See Also:

  • DockerEngineRuby::Models::Container::State::Health#status

Constant Summary collapse

NONE =

Returns:

  • (:none)
:none
STARTING =

Returns:

  • (:starting)
:starting
HEALTHY =

Returns:

  • (:healthy)
:healthy
UNHEALTHY =

Returns:

  • (:unhealthy)
:unhealthy

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[DockerEngineRuby::Models::Container::State::Health::status]

Returns:

  • (::Array[DockerEngineRuby::Models::Container::State::Health::status])


1905
# File 'sig/docker_engine_ruby/models/container.rbs', line 1905

def self?.values: -> ::Array[DockerEngineRuby::Models::Container::State::Health::status]