Class: DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadBp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(blkio_device_read_bps: nil, blkio_device_read_i_ops: nil, blkio_device_write_bps: nil, blkio_device_write_i_ops: nil, blkio_weight: nil, blkio_weight_device: nil, cgroup_parent: nil, cpu_count: nil, cpu_percent: nil, cpu_period: nil, cpu_quota: nil, cpu_realtime_period: nil, cpu_realtime_runtime: nil, cpuset_cpus: nil, cpuset_mems: nil, cpu_shares: nil, device_cgroup_rules: nil, device_requests: nil, devices: nil, init: nil, io_maximum_bandwidth: nil, io_maximum_i_ops: nil, memory: nil, memory_reservation: nil, memory_swap: nil, memory_swappiness: nil, nano_cpus: nil, oom_kill_disable: nil, pids_limit: nil, ulimits: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::ContainerUpdateParams for more details.

Parameters:

  • blkio_device_read_bps (Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadBp>) (defaults to: nil)

    Limit read rate (bytes per second) from a device, in the form:

  • blkio_device_read_i_ops (Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadIOp>) (defaults to: nil)

    Limit read rate (IO per second) from a device, in the form:

  • blkio_device_write_bps (Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteBp>) (defaults to: nil)

    Limit write rate (bytes per second) to a device, in the form:

  • blkio_device_write_i_ops (Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteIOp>) (defaults to: nil)

    Limit write rate (IO per second) to a device, in the form:

  • blkio_weight (Integer) (defaults to: nil)

    Block IO weight (relative weight).

  • blkio_weight_device (Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioWeightDevice>) (defaults to: nil)

    Block IO weight (relative device weight) in the form:

  • cgroup_parent (String) (defaults to: nil)

    Path to cgroups under which the container’s cgroup is created. If

  • cpu_count (Integer) (defaults to: nil)

    The number of usable CPUs (Windows only).

  • cpu_percent (Integer) (defaults to: nil)

    The usable percentage of the available CPUs (Windows only).

  • cpu_period (Integer) (defaults to: nil)

    The length of a CPU period in microseconds.

  • cpu_quota (Integer) (defaults to: nil)

    Microseconds of CPU time that the container can get in a CPU period.

  • cpu_realtime_period (Integer) (defaults to: nil)

    The length of a CPU real-time period in microseconds. Set to 0 to

  • cpu_realtime_runtime (Integer) (defaults to: nil)

    The length of a CPU real-time runtime in microseconds. Set to 0 to

  • cpuset_cpus (String) (defaults to: nil)

    CPUs in which to allow execution (e.g., 0-3, ‘0,1`).

  • cpuset_mems (String) (defaults to: nil)

    Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only

  • cpu_shares (Integer) (defaults to: nil)

    An integer value representing this container’s relative CPU weight

  • device_cgroup_rules (Array<String>) (defaults to: nil)

    a list of cgroup rules to apply to the container

  • device_requests (Array<DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest>) (defaults to: nil)

    A list of requests for devices to be sent to device drivers.

  • devices (Array<DockerEngineRuby::Models::ContainerUpdateParams::Device>) (defaults to: nil)

    A list of devices to add to the container.

  • init (Boolean, nil) (defaults to: nil)

    Run an init inside the container that forwards signals and reaps

  • io_maximum_bandwidth (Integer) (defaults to: nil)

    Maximum IO in bytes per second for the container system drive

  • io_maximum_i_ops (Integer) (defaults to: nil)

    Maximum IOps for the container system drive (Windows only)

  • memory (Integer) (defaults to: nil)

    Memory limit in bytes.

  • memory_reservation (Integer) (defaults to: nil)

    Memory soft limit in bytes.

  • memory_swap (Integer) (defaults to: nil)

    Total memory limit (memory + swap). Set as -1 to enable unlimited

  • memory_swappiness (Integer) (defaults to: nil)

    Tune a container’s memory swappiness behavior. Accepts an integer

  • nano_cpus (Integer) (defaults to: nil)

    CPU quota in units of 10<sup>-9</sup> CPUs.

  • oom_kill_disable (Boolean) (defaults to: nil)

    Disable OOM Killer for the container.

  • pids_limit (Integer, nil) (defaults to: nil)

    Tune a container’s PIDs limit. Set 0 or -1 for unlimited, or null

  • ulimits (Array<DockerEngineRuby::Models::ContainerUpdateParams::Ulimit>) (defaults to: nil)

    A list of resource limits to set in the container. For example:

  • request_options (DockerEngineRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 332

class BlkioDeviceReadBp < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute path
  #   Device path
  #
  #   @return [String, nil]
  optional :path, String, api_name: :Path

  # @!attribute rate
  #   Rate
  #
  #   @return [Integer, nil]
  optional :rate, Integer, api_name: :Rate

  # @!method initialize(path: nil, rate: nil)
  #   @param path [String] Device path
  #
  #   @param rate [Integer] Rate
end

Instance Attribute Details

#pathString?

Device path

Returns:

  • (String, nil)


337
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 337

optional :path, String, api_name: :Path

#rateInteger?

Rate

Returns:

  • (Integer, nil)


343
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 343

optional :rate, Integer, api_name: :Rate