Class: DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/container_update_params.rb,
sig/docker_engine_ruby/models/container_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



359
# File 'sig/docker_engine_ruby/models/container_update_params.rbs', line 359

def initialize: (

Instance Attribute Details

#capabilities ⇒ Array<Array<String>>?

A list of capabilities; an OR list of AND lists of capabilities.

Note that if a driver is specified the capabilities have no effect on selecting a driver as the driver name is used directly.

Note that if no driver is specified the capabilities are used to select a driver with the required capabilities.

Returns:

  • (Array<Array<String>>, nil)


442
443
444
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 442

optional :capabilities,
DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::ArrayOf[String]],
api_name: :Capabilities

#count ⇒ Integer?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


449
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 449

optional :count, Integer, api_name: :Count

#device_ids ⇒ Array<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


454
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 454

optional :device_ids, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DeviceIDs

#driver ⇒ String?

The name of the device driver to use for this request.

Note that if this is specified the capabilities are ignored when selecting a device driver.

Parameters:

  • (String)

Returns:

  • (String, nil)


463
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 463

optional :driver, String, api_name: :Driver

#options ⇒ Hash{Symbol=>String}?

Driver-specific options, specified as a key/value pairs. These options are passed directly to the driver.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


470
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 470

optional :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


367
# File 'sig/docker_engine_ruby/models/container_update_params.rbs', line 367

def to_hash: -> {