Class: DockerEngineRuby::Models::CreateRequest::ClusterVolumeSpec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::CreateRequest::ClusterVolumeSpec
- Defined in:
- lib/docker_engine_ruby/models/create_request.rb
Overview
Defined Under Namespace
Classes: AccessMode
Instance Attribute Summary collapse
-
#access_mode ⇒ DockerEngineRuby::Models::CreateRequest::ClusterVolumeSpec::AccessMode?
Defines how the volume is used by tasks.
-
#group ⇒ String?
Group defines the volume group of this volume.
Instance Method Summary collapse
-
#initialize(access_mode: nil, group: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ClusterVolumeSpec for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_mode: nil, group: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::CreateRequest::ClusterVolumeSpec for more details.
Cluster-specific options used to create the volume.
|
|
# File 'lib/docker_engine_ruby/models/create_request.rb', line 75
|
Instance Attribute Details
#access_mode ⇒ DockerEngineRuby::Models::CreateRequest::ClusterVolumeSpec::AccessMode?
Defines how the volume is used by tasks.
61 62 63 |
# File 'lib/docker_engine_ruby/models/create_request.rb', line 61 optional :access_mode, -> { DockerEngineRuby::CreateRequest::ClusterVolumeSpec::AccessMode }, api_name: :AccessMode |
#group ⇒ String?
Group defines the volume group of this volume. Volumes belonging to the same group can be referred to by group name when creating Services. Referring to a volume by group instructs Swarm to treat volumes in that group interchangeably for the purpose of scheduling. Volumes with an empty string for a group technically all belong to the same, emptystring group.
73 |
# File 'lib/docker_engine_ruby/models/create_request.rb', line 73 optional :group, String, api_name: :Group |