Class: DockerEngineRuby::Models::Image::Config

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Defined Under Namespace

Classes: Healthcheck

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(args_escaped: nil, cmd: nil, entrypoint: nil, env: nil, exposed_ports: nil, healthcheck: nil, labels: nil, on_build: nil, shell: nil, stop_signal: nil, user: nil, volumes: nil, working_dir: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Image::Config for more details.

Configuration of the image. These fields are used as defaults when starting a container from the image.

Parameters:

  • args_escaped (Boolean, nil) (defaults to: nil)

    Command is already escaped (Windows only)

  • cmd (Array<String>) (defaults to: nil)

    Command to run specified as a string or an array of strings.

  • entrypoint (Array<String>) (defaults to: nil)

    The entry point for the container as a string or an array of strings.

  • env (Array<String>) (defaults to: nil)

    A list of environment variables to set inside the container in the

  • exposed_ports (Hash{Symbol=>Hash{Symbol=>Object}}, nil) (defaults to: nil)

    An object mapping ports to an empty object in the form:

  • healthcheck (DockerEngineRuby::Models::Image::Config::Healthcheck) (defaults to: nil)

    A test to perform to check that the container is healthy.

  • labels (Hash{Symbol=>String}) (defaults to: nil)

    User-defined key/value metadata.

  • on_build (Array<String>, nil) (defaults to: nil)

    ONBUILD metadata that were defined in the image’s Dockerfile.

  • shell (Array<String>, nil) (defaults to: nil)

    Shell for when RUN, CMD, and ENTRYPOINT uses a shell.

  • stop_signal (String, nil) (defaults to: nil)

    Signal to stop a container as a string or unsigned integer.

  • user (String) (defaults to: nil)

    The user that commands are run as inside the container.

  • volumes (Hash{Symbol=>Hash{Symbol=>Object}}) (defaults to: nil)

    An object mapping mount point paths inside the container to empty

  • working_dir (String) (defaults to: nil)

    The working directory for commands to run in.



# File 'lib/docker_engine_ruby/models/image.rb', line 288


Instance Attribute Details

#args_escapedBoolean?

Command is already escaped (Windows only)

Returns:

  • (Boolean, nil)


200
# File 'lib/docker_engine_ruby/models/image.rb', line 200

optional :args_escaped, DockerEngineRuby::Internal::Type::Boolean, api_name: :ArgsEscaped, nil?: true

#cmdArray<String>?

Command to run specified as a string or an array of strings.

Returns:

  • (Array<String>, nil)


206
# File 'lib/docker_engine_ruby/models/image.rb', line 206

optional :cmd, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Cmd

#entrypointArray<String>?

The entry point for the container as a string or an array of strings.

If the array consists of exactly one empty string (‘[“”]`) then the entry point is reset to system default (i.e., the entry point used by docker when there is no ENTRYPOINT instruction in the Dockerfile).

Returns:

  • (Array<String>, nil)


216
# File 'lib/docker_engine_ruby/models/image.rb', line 216

optional :entrypoint, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Entrypoint

#envArray<String>?

A list of environment variables to set inside the container in the form ‘[“VAR=value”, …]`. A variable without `=` is removed from the environment, rather than to have an empty value.

Returns:

  • (Array<String>, nil)


224
# File 'lib/docker_engine_ruby/models/image.rb', line 224

optional :env, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Env

#exposed_portsHash{Symbol=>Hash{Symbol=>Object}}?

An object mapping ports to an empty object in the form:

‘{}`

Returns:

  • (Hash{Symbol=>Hash{Symbol=>Object}}, nil)


232
233
234
235
# File 'lib/docker_engine_ruby/models/image.rb', line 232

optional :exposed_ports,
DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]],
api_name: :ExposedPorts,
nil?: true

#healthcheckDockerEngineRuby::Models::Image::Config::Healthcheck?

A test to perform to check that the container is healthy. Healthcheck commands should be side-effect free.



242
# File 'lib/docker_engine_ruby/models/image.rb', line 242

optional :healthcheck, -> { DockerEngineRuby::Image::Config::Healthcheck }, api_name: :Healthcheck

#labelsHash{Symbol=>String}?

User-defined key/value metadata.

Returns:

  • (Hash{Symbol=>String}, nil)


248
# File 'lib/docker_engine_ruby/models/image.rb', line 248

optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels

#on_buildArray<String>?

ONBUILD metadata that were defined in the image’s Dockerfile.

Returns:

  • (Array<String>, nil)


254
# File 'lib/docker_engine_ruby/models/image.rb', line 254

optional :on_build, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :OnBuild, nil?: true

#shellArray<String>?

Shell for when RUN, CMD, and ENTRYPOINT uses a shell.

Returns:

  • (Array<String>, nil)


260
# File 'lib/docker_engine_ruby/models/image.rb', line 260

optional :shell, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Shell, nil?: true

#stop_signalString?

Signal to stop a container as a string or unsigned integer.

Returns:

  • (String, nil)


266
# File 'lib/docker_engine_ruby/models/image.rb', line 266

optional :stop_signal, String, api_name: :StopSignal, nil?: true

#userString?

The user that commands are run as inside the container.

Returns:

  • (String, nil)


272
# File 'lib/docker_engine_ruby/models/image.rb', line 272

optional :user, String, api_name: :User

#volumesHash{Symbol=>Hash{Symbol=>Object}}?

An object mapping mount point paths inside the container to empty objects.

Returns:

  • (Hash{Symbol=>Hash{Symbol=>Object}}, nil)


278
279
280
# File 'lib/docker_engine_ruby/models/image.rb', line 278

optional :volumes,
DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]],
api_name: :Volumes

#working_dirString?

The working directory for commands to run in.

Returns:

  • (String, nil)


286
# File 'lib/docker_engine_ruby/models/image.rb', line 286

optional :working_dir, String, api_name: :WorkingDir