Class: DockerEngineRuby::Models::Image::Config::Healthcheck

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel

Instance Attribute Details

#intervalInteger?

The time to wait between checks in nanoseconds. It should be 0 or at least 1000000 (1 ms). 0 means inherit.

Returns:

  • (Integer, nil)


328
# File 'lib/docker_engine_ruby/models/image.rb', line 328

optional :interval, Integer, api_name: :Interval

#retriesInteger?

The number of consecutive failures needed to consider a container as unhealthy. 0 means inherit.

Returns:

  • (Integer, nil)


335
# File 'lib/docker_engine_ruby/models/image.rb', line 335

optional :retries, Integer, api_name: :Retries

#start_intervalInteger?

The time to wait between checks in nanoseconds during the start period. It should be 0 or at least 1000000 (1 ms). 0 means inherit.

Returns:

  • (Integer, nil)


342
# File 'lib/docker_engine_ruby/models/image.rb', line 342

optional :start_interval, Integer, api_name: :StartInterval

#start_periodInteger?

Start period for the container to initialize before starting health-retries countdown in nanoseconds. It should be 0 or at least 1000000 (1 ms). 0 means inherit.

Returns:

  • (Integer, nil)


350
# File 'lib/docker_engine_ruby/models/image.rb', line 350

optional :start_period, Integer, api_name: :StartPeriod

#test_Array<String>?

The test to perform. Possible values are:

  • [] inherit healthcheck from image or parent image

  • ‘[“NONE”]` disable healthcheck

  • ‘[“CMD”, args…]` exec arguments directly

  • ‘[“CMD-SHELL”, command]` run command with system’s default shell

A non-zero exit code indicates a failed healthcheck:

  • 0 healthy

  • 1 unhealthy

  • 2 reserved (treated as unhealthy)

  • other values: error running probe

Returns:

  • (Array<String>, nil)


368
# File 'lib/docker_engine_ruby/models/image.rb', line 368

optional :test_, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Test

#timeoutInteger?

The time to wait before considering the check to have hung. It should be 0 or at least 1000000 (1 ms). 0 means inherit.

If the health check command does not complete within this timeout, the check is considered failed and the health check process is forcibly terminated without a graceful shutdown.

Returns:

  • (Integer, nil)


379
# File 'lib/docker_engine_ruby/models/image.rb', line 379

optional :timeout, Integer, api_name: :Timeout