Class: DockerEngineRuby::Models::Image::Descriptor::Platform

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel

Instance Attribute Details

#architectureString?

The CPU architecture, for example amd64 or ppc64.

Returns:

  • (String, nil)


485
# File 'lib/docker_engine_ruby/models/image.rb', line 485

optional :architecture, String

#osString?

The operating system, for example linux or windows.

Returns:

  • (String, nil)


491
# File 'lib/docker_engine_ruby/models/image.rb', line 491

optional :os, String

#os_featuresArray<String>?

Optional field specifying an array of strings, each listing a required OS feature (for example on Windows win32k).

Returns:

  • (Array<String>, nil)


498
# File 'lib/docker_engine_ruby/models/image.rb', line 498

optional :os_features, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :"os.features"

#os_versionString?

Optional field specifying the operating system version, for example on Windows 10.0.19041.1165.

Returns:

  • (String, nil)


505
# File 'lib/docker_engine_ruby/models/image.rb', line 505

optional :os_version, String, api_name: :"os.version"

#variantString?

Optional field specifying a variant of the CPU, for example v7 to specify ARMv7 when architecture is arm.

Returns:

  • (String, nil)


512
# File 'lib/docker_engine_ruby/models/image.rb', line 512

optional :variant, String