Class: DockerEngineRuby::Models::Image::Identity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Defined Under Namespace

Classes: Build, Pull, Signature

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(repository: nil) ⇒ Object

PullIdentity contains remote location information if image was created via pull. If image was pulled via mirror, this contains the original repository location.

Parameters:

  • repository (String) (defaults to: nil)

    Repository is the remote repository location the image was pulled from.



# File 'lib/docker_engine_ruby/models/image.rb', line 621


Instance Attribute Details

#buildArray<DockerEngineRuby::Models::Image::Identity::Build>?

Build contains build reference information if image was created via build.



569
570
571
# File 'lib/docker_engine_ruby/models/image.rb', line 569

optional :build,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Identity::Build] },
api_name: :Build

#pullArray<DockerEngineRuby::Models::Image::Identity::Pull>?

Pull contains remote location information if image was created via pull. If image was pulled via mirror, this contains the original repository location. After successful push this images also contains the pushed repository location.



579
580
581
# File 'lib/docker_engine_ruby/models/image.rb', line 579

optional :pull,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Identity::Pull] },
api_name: :Pull

#signatureArray<DockerEngineRuby::Models::Image::Identity::Signature>?

Signature contains the properties of verified signatures for the image.



587
588
589
590
591
# File 'lib/docker_engine_ruby/models/image.rb', line 587

optional :signature,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Identity::Signature]
},
api_name: :Signature