Class: DockerEngineRuby::Models::Image::Identity::Build

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(build: nil, pull: nil, signature: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Image::Identity for more details.

Identity holds information about the identity and origin of the image. This is trusted information verified by the daemon and cannot be modified by tagging an image to a different name.

Parameters:



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/docker_engine_ruby/models/image.rb', line 607

class Build < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute created_at
  #   CreatedAt is the time when the build ran.
  #
  #   @return [Time, nil]
  optional :created_at, Time, api_name: :CreatedAt

  # @!attribute ref
  #   Ref is the identifier for the build request. This reference can be used to look
  #   up the build details in BuildKit history API.
  #
  #   @return [String, nil]
  optional :ref, String, api_name: :Ref

  # @!method initialize(created_at: nil, ref: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineRuby::Models::Image::Identity::Build} for more details.
  #
  #   BuildIdentity contains build reference information if image was created via
  #   build.
  #
  #   @param created_at [Time] CreatedAt is the time when the build ran.
  #
  #   @param ref [String] Ref is the identifier for the build request. This reference can be used to
end

Instance Attribute Details

#created_atTime?

CreatedAt is the time when the build ran.

Returns:

  • (Time, nil)


612
# File 'lib/docker_engine_ruby/models/image.rb', line 612

optional :created_at, Time, api_name: :CreatedAt

#refString?

Ref is the identifier for the build request. This reference can be used to look up the build details in BuildKit history API.

Returns:

  • (String, nil)


619
# File 'lib/docker_engine_ruby/models/image.rb', line 619

optional :ref, String, api_name: :Ref