Class: DockerEngineRuby::Models::Image::Identity::Pull
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Identity::Pull
- Defined in:
- lib/docker_engine_ruby/models/image.rb,
sig/docker_engine_ruby/models/image.rbs
Instance Attribute Summary collapse
-
#repository ⇒ String?
Repository is the remote repository location the image was pulled from.
Instance Method Summary collapse
-
#initialize ⇒ Pull
constructor
A new instance of Pull.
- #to_hash ⇒ { repository: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Pull
Returns a new instance of Pull.
461 |
# File 'sig/docker_engine_ruby/models/image.rbs', line 461
def initialize: (?repository: String) -> void
|
Instance Attribute Details
#repository ⇒ String?
Repository is the remote repository location the image was pulled from.
638 |
# File 'lib/docker_engine_ruby/models/image.rb', line 638 optional :repository, String, api_name: :Repository |
Instance Method Details
#to_hash ⇒ { repository: String }
463 |
# File 'sig/docker_engine_ruby/models/image.rbs', line 463
def to_hash: -> { repository: String }
|