Class: DockerEngineRuby::Models::Image::Identity::Signature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Defined Under Namespace

Modules: KnownSigner, SignatureType Classes: Signer, Timestamp

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(build_config_digest: nil, build_config_uri: nil, build_signer_digest: nil, build_signer_uri: nil, build_trigger: nil, certificate_issuer: nil, issuer: nil, run_invocation_uri: nil, runner_environment: nil, source_repository_digest: nil, source_repository_identifier: nil, source_repository_owner_identifier: nil, source_repository_owner_uri: nil, source_repository_ref: nil, source_repository_uri: nil, source_repository_visibility_at_signing: nil, subject_alternative_name: nil) ⇒ Object

Some parameter documentations has been truncated, see Signer for more details.

SignerIdentity contains information about the signer certificate used to sign the image.

Parameters:

  • build_config_digest (String) (defaults to: nil)

    Immutable reference to the specific version of the top-level/initiating build in

  • build_config_uri (String) (defaults to: nil)

    Build Config URL to the top-level/initiating build instructions.

  • build_signer_digest (String) (defaults to: nil)

    Immutable reference to the specific version of the build instructions that is re

  • build_signer_uri (String) (defaults to: nil)

    Reference to specific build instructions that are responsible for signing.

  • build_trigger (String) (defaults to: nil)

    Event or action that initiated the build.

  • certificate_issuer (String) (defaults to: nil)

    CertificateIssuer is the certificate issuer.

  • issuer (String) (defaults to: nil)

    The OIDC issuer. Should match iss claim of ID token or, in the case of

  • run_invocation_uri (String) (defaults to: nil)

    Run Invocation URL to uniquely identify the build execution.

  • runner_environment (String) (defaults to: nil)

    Specifies whether the build took place in platform-hosted cloud infrastructure o

  • source_repository_digest (String) (defaults to: nil)

    Immutable reference to a specific version of the source code that the build was

  • source_repository_identifier (String) (defaults to: nil)

    Immutable identifier for the source repository the workflow was based upon.

  • source_repository_owner_identifier (String) (defaults to: nil)

    Immutable identifier for the owner of the source repository that the workflow wa

  • source_repository_owner_uri (String) (defaults to: nil)

    Source repository owner URL of the owner of the source repository that the build

  • source_repository_ref (String) (defaults to: nil)

    Source Repository Ref that the build run was based upon.

  • source_repository_uri (String) (defaults to: nil)

    Source repository URL that the build was based on.

  • source_repository_visibility_at_signing (String) (defaults to: nil)

    Source repository visibility at the time of signing the certificate.

  • subject_alternative_name (String) (defaults to: nil)

    SubjectAlternativeName is the certificate subject alternative name.



# File 'lib/docker_engine_ruby/models/image.rb', line 711


Instance Attribute Details

#docker_referenceString?

DockerReference is the Docker image reference associated with the signature. This is an optional field only present in older hashedrecord signatures.

Returns:

  • (String, nil)


653
# File 'lib/docker_engine_ruby/models/image.rb', line 653

optional :docker_reference, String, api_name: :DockerReference

#errorString?

Error contains error information if signature verification failed. Other fields will be empty in this case.

Returns:

  • (String, nil)


660
# File 'lib/docker_engine_ruby/models/image.rb', line 660

optional :error, String, api_name: :Error

#known_signerSymbol, ...

KnownSignerIdentity is an identifier for a special signer identity that is known to the implementation.



667
668
669
# File 'lib/docker_engine_ruby/models/image.rb', line 667

optional :known_signer,
enum: -> { DockerEngineRuby::Image::Identity::Signature::KnownSigner },
api_name: :KnownSigner

#nameString?

Name is a textual description summarizing the type of signature.

Returns:

  • (String, nil)


675
# File 'lib/docker_engine_ruby/models/image.rb', line 675

optional :name, String, api_name: :Name

#signature_typeSymbol, ...

SignatureType is the type of signature format.



681
682
683
# File 'lib/docker_engine_ruby/models/image.rb', line 681

optional :signature_type,
enum: -> { DockerEngineRuby::Image::Identity::Signature::SignatureType },
api_name: :SignatureType

#signerDockerEngineRuby::Models::Image::Identity::Signature::Signer?

SignerIdentity contains information about the signer certificate used to sign the image.



690
# File 'lib/docker_engine_ruby/models/image.rb', line 690

optional :signer, -> { DockerEngineRuby::Image::Identity::Signature::Signer }, api_name: :Signer

#timestampsArray<DockerEngineRuby::Models::Image::Identity::Signature::Timestamp>?

Timestamps contains a list of verified signed timestamps for the signature.



696
697
698
699
700
# File 'lib/docker_engine_ruby/models/image.rb', line 696

optional :timestamps,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Identity::Signature::Timestamp]
},
api_name: :Timestamps

#warningsArray<String>?

Warnings contains any warnings that occurred during signature verification. For example, if there was no internet connectivity and cached trust roots were used. Warning does not indicate a failed verification but may point to configuration issues.

Returns:

  • (Array<String>, nil)


709
# File 'lib/docker_engine_ruby/models/image.rb', line 709

optional :warnings, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Warnings

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/image.rb', line 742