Class: DockerEngineRuby::Models::Image::Identity::Signature::Signer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel

Instance Attribute Details

#build_config_digestString?

Immutable reference to the specific version of the top-level/initiating build instructions.

Returns:

  • (String, nil)


766
# File 'lib/docker_engine_ruby/models/image.rb', line 766

optional :build_config_digest, String, api_name: :BuildConfigDigest

#build_config_uriString?

Build Config URL to the top-level/initiating build instructions.

Returns:

  • (String, nil)


772
# File 'lib/docker_engine_ruby/models/image.rb', line 772

optional :build_config_uri, String, api_name: :BuildConfigURI

#build_signer_digestString?

Immutable reference to the specific version of the build instructions that is responsible for signing.

Returns:

  • (String, nil)


779
# File 'lib/docker_engine_ruby/models/image.rb', line 779

optional :build_signer_digest, String, api_name: :BuildSignerDigest

#build_signer_uriString?

Reference to specific build instructions that are responsible for signing.

Returns:

  • (String, nil)


785
# File 'lib/docker_engine_ruby/models/image.rb', line 785

optional :build_signer_uri, String, api_name: :BuildSignerURI

#build_triggerString?

Event or action that initiated the build.

Returns:

  • (String, nil)


791
# File 'lib/docker_engine_ruby/models/image.rb', line 791

optional :build_trigger, String, api_name: :BuildTrigger

#certificate_issuerString?

CertificateIssuer is the certificate issuer.

Returns:

  • (String, nil)


797
# File 'lib/docker_engine_ruby/models/image.rb', line 797

optional :certificate_issuer, String, api_name: :CertificateIssuer

#issuerString?

The OIDC issuer. Should match iss claim of ID token or, in the case of a federated login like Dex it should match the issuer URL of the upstream issuer. The issuer is not set the extensions are invalid and will fail to render.

Returns:

  • (String, nil)


805
# File 'lib/docker_engine_ruby/models/image.rb', line 805

optional :issuer, String, api_name: :Issuer

#run_invocation_uriString?

Run Invocation URL to uniquely identify the build execution.

Returns:

  • (String, nil)


811
# File 'lib/docker_engine_ruby/models/image.rb', line 811

optional :run_invocation_uri, String, api_name: :RunInvocationURI

#runner_environmentString?

Specifies whether the build took place in platform-hosted cloud infrastructure or customer/self-hosted infrastructure.

Returns:

  • (String, nil)


818
# File 'lib/docker_engine_ruby/models/image.rb', line 818

optional :runner_environment, String, api_name: :RunnerEnvironment

#source_repository_digestString?

Immutable reference to a specific version of the source code that the build was based upon.

Returns:

  • (String, nil)


825
# File 'lib/docker_engine_ruby/models/image.rb', line 825

optional :source_repository_digest, String, api_name: :SourceRepositoryDigest

#source_repository_identifierString?

Immutable identifier for the source repository the workflow was based upon.

Returns:

  • (String, nil)


831
# File 'lib/docker_engine_ruby/models/image.rb', line 831

optional :source_repository_identifier, String, api_name: :SourceRepositoryIdentifier

#source_repository_owner_identifierString?

Immutable identifier for the owner of the source repository that the workflow was based upon.

Returns:

  • (String, nil)


838
# File 'lib/docker_engine_ruby/models/image.rb', line 838

optional :source_repository_owner_identifier, String, api_name: :SourceRepositoryOwnerIdentifier

#source_repository_owner_uriString?

Source repository owner URL of the owner of the source repository that the build was based on.

Returns:

  • (String, nil)


845
# File 'lib/docker_engine_ruby/models/image.rb', line 845

optional :source_repository_owner_uri, String, api_name: :SourceRepositoryOwnerURI

#source_repository_refString?

Source Repository Ref that the build run was based upon.

Returns:

  • (String, nil)


851
# File 'lib/docker_engine_ruby/models/image.rb', line 851

optional :source_repository_ref, String, api_name: :SourceRepositoryRef

#source_repository_uriString?

Source repository URL that the build was based on.

Returns:

  • (String, nil)


857
# File 'lib/docker_engine_ruby/models/image.rb', line 857

optional :source_repository_uri, String, api_name: :SourceRepositoryURI

#source_repository_visibility_at_signingString?

Source repository visibility at the time of signing the certificate.

Returns:

  • (String, nil)


863
864
865
# File 'lib/docker_engine_ruby/models/image.rb', line 863

optional :source_repository_visibility_at_signing,
String,
api_name: :SourceRepositoryVisibilityAtSigning

#subject_alternative_nameString?

SubjectAlternativeName is the certificate subject alternative name.

Returns:

  • (String, nil)


871
# File 'lib/docker_engine_ruby/models/image.rb', line 871

optional :subject_alternative_name, String, api_name: :SubjectAlternativeName