Class: DockerEngineRuby::Models::Image::Manifest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Manifest
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Defined Under Namespace
Modules: Kind Classes: AttestationData, Descriptor, ImageData, Size
Instance Attribute Summary collapse
-
#attestation_data ⇒ DockerEngineRuby::Models::Image::Manifest::AttestationData?
The image data for the attestation manifest.
-
#available ⇒ Boolean
Indicates whether all the child content (image config, layers) is fully available locally.
-
#descriptor ⇒ DockerEngineRuby::Models::Image::Manifest::Descriptor
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
-
#id ⇒ String
ID is the content-addressable ID of an image and is the same as the digest of the image manifest.
-
#image_data ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData?
The image data for the image manifest.
-
#kind ⇒ Symbol, DockerEngineRuby::Models::Image::Manifest::Kind
The kind of the manifest.
- #size ⇒ DockerEngineRuby::Models::Image::Manifest::Size
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(for_:) ⇒ Object
constructor
The image data for the attestation manifest.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(for_:) ⇒ Object
The image data for the attestation manifest. This field is only populated when Kind is “attestation”.
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 1018
|
Instance Attribute Details
#attestation_data ⇒ DockerEngineRuby::Models::Image::Manifest::AttestationData?
The image data for the attestation manifest. This field is only populated when Kind is “attestation”.
1003 1004 1005 1006 |
# File 'lib/docker_engine_ruby/models/image.rb', line 1003 optional :attestation_data, -> { DockerEngineRuby::Image::Manifest::AttestationData }, api_name: :AttestationData, nil?: true |
#available ⇒ Boolean
Indicates whether all the child content (image config, layers) is fully available locally.
966 |
# File 'lib/docker_engine_ruby/models/image.rb', line 966 required :available, DockerEngineRuby::Internal::Type::Boolean, api_name: :Available |
#descriptor ⇒ DockerEngineRuby::Models::Image::Manifest::Descriptor
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
973 |
# File 'lib/docker_engine_ruby/models/image.rb', line 973 required :descriptor, -> { DockerEngineRuby::Image::Manifest::Descriptor }, api_name: :Descriptor |
#id ⇒ String
ID is the content-addressable ID of an image and is the same as the digest of the image manifest.
980 |
# File 'lib/docker_engine_ruby/models/image.rb', line 980 required :id, String, api_name: :ID |
#image_data ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData?
The image data for the image manifest. This field is only populated when Kind is “image”.
1013 1014 1015 1016 |
# File 'lib/docker_engine_ruby/models/image.rb', line 1013 optional :image_data, -> { DockerEngineRuby::Image::Manifest::ImageData }, api_name: :ImageData, nil?: true |
#kind ⇒ Symbol, DockerEngineRuby::Models::Image::Manifest::Kind
The kind of the manifest.
| kind | description | | ———– | ———————————————————————————— | | image | Image manifest that can be used to start a container. | | attestation | Attestation manifest produced by the Buildkit builder for a specific image manifest. |
991 |
# File 'lib/docker_engine_ruby/models/image.rb', line 991 required :kind, enum: -> { DockerEngineRuby::Image::Manifest::Kind }, api_name: :Kind |
#size ⇒ DockerEngineRuby::Models::Image::Manifest::Size
996 |
# File 'lib/docker_engine_ruby/models/image.rb', line 996 required :size, -> { DockerEngineRuby::Image::Manifest::Size }, api_name: :Size |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 1186
|