Class: DockerEngineRuby::Models::Image::Manifest::Descriptor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image.rb

Overview

See Also:

Defined Under Namespace

Classes: Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(annotations: nil, artifact_type: nil, data: nil, digest: nil, media_type: nil, platform: nil, size: nil, urls: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Image::Manifest::Descriptor for more details.

A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).

Parameters:

  • annotations (Hash{Symbol=>String}, nil) (defaults to: nil)

    Arbitrary metadata relating to the targeted content.

  • artifact_type (String, nil) (defaults to: nil)

    ArtifactType is the IANA media type of this artifact.

  • data (String, nil) (defaults to: nil)

    Data is an embedding of the targeted content. This is encoded as a base64

  • digest (String) (defaults to: nil)

    The digest of the targeted content.

  • media_type (String) (defaults to: nil)

    The media type of the object this schema refers to.

  • platform (DockerEngineRuby::Models::Image::Manifest::Descriptor::Platform) (defaults to: nil)

    Describes the platform which the image in the manifest runs on, as defined

  • size (Integer) (defaults to: nil)

    The size in bytes of the blob.

  • urls (Array<String>, nil) (defaults to: nil)

    List of URLs from which this object MAY be downloaded.



# File 'lib/docker_engine_ruby/models/image.rb', line 1092


Instance Attribute Details

#annotationsHash{Symbol=>String}?

Arbitrary metadata relating to the targeted content.

Returns:

  • (Hash{Symbol=>String}, nil)


1044
# File 'lib/docker_engine_ruby/models/image.rb', line 1044

optional :annotations, DockerEngineRuby::Internal::Type::HashOf[String], nil?: true

#artifact_typeString?

ArtifactType is the IANA media type of this artifact.

Returns:

  • (String, nil)


1050
# File 'lib/docker_engine_ruby/models/image.rb', line 1050

optional :artifact_type, String, api_name: :artifactType, nil?: true

#dataString?

Data is an embedding of the targeted content. This is encoded as a base64 string when marshalled to JSON (automatically, by encoding/json). If present, Data can be used directly to avoid fetching the targeted content.

Returns:

  • (String, nil)


1058
# File 'lib/docker_engine_ruby/models/image.rb', line 1058

optional :data, String, nil?: true

#digestString?

The digest of the targeted content.

Returns:

  • (String, nil)


1064
# File 'lib/docker_engine_ruby/models/image.rb', line 1064

optional :digest, String

#media_typeString?

The media type of the object this schema refers to.

Returns:

  • (String, nil)


1070
# File 'lib/docker_engine_ruby/models/image.rb', line 1070

optional :media_type, String, api_name: :mediaType

#platformDockerEngineRuby::Models::Image::Manifest::Descriptor::Platform?

Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).



1078
# File 'lib/docker_engine_ruby/models/image.rb', line 1078

optional :platform, -> { DockerEngineRuby::Image::Manifest::Descriptor::Platform }

#sizeInteger?

The size in bytes of the blob.

Returns:

  • (Integer, nil)


1084
# File 'lib/docker_engine_ruby/models/image.rb', line 1084

optional :size, Integer

#urlsArray<String>?

List of URLs from which this object MAY be downloaded.

Returns:

  • (Array<String>, nil)


1090
# File 'lib/docker_engine_ruby/models/image.rb', line 1090

optional :urls, DockerEngineRuby::Internal::Type::ArrayOf[String], nil?: true