Class: DockerEngineRuby::Models::ImageSummary::Descriptor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image_summary.rb,
sig/docker_engine_ruby/models/image_summary.rbs

Overview

See Also:

  • DockerEngineRuby::Models::ImageSummary#descriptor

Defined Under Namespace

Classes: Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(annotations: nil, artifact_type: nil, data: nil, digest: nil, media_type: nil, platform: nil, size: nil, urls: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::ImageSummary::Descriptor for more details.

A descriptor struct containing digest, media type, and size, as defined in the OCI Content Descriptors Specification.

Parameters:

  • annotations (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Arbitrary metadata relating to the targeted content.

  • artifact_type (String, nil) (defaults to: nil) —

    ArtifactType is the IANA media type of this artifact.

  • data (String, nil) (defaults to: nil) —

    Data is an embedding of the targeted content. This is encoded as a base64

  • digest (String) (defaults to: nil) —

    The digest of the targeted content.

  • media_type (String) (defaults to: nil) —

    The media type of the object this schema refers to.

  • platform (DockerEngineRuby::Models::ImageSummary::Descriptor::Platform) (defaults to: nil) —

    Describes the platform which the image in the manifest runs on, as defined

  • size (Integer) (defaults to: nil) —

    The size in bytes of the blob.

  • urls (Array<String>, nil) (defaults to: nil) —

    List of URLs from which this object MAY be downloaded.



# File 'lib/docker_engine_ruby/models/image_summary.rb', line 191


Instance Attribute Details

#annotations ⇒ Hash{Symbol=>String}?

Arbitrary metadata relating to the targeted content.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


143
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 143

optional :annotations, DockerEngineRuby::Internal::Type::HashOf[String], nil?: true

#artifact_type ⇒ String?

ArtifactType is the IANA media type of this artifact.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


149
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 149

optional :artifact_type, String, api_name: :artifactType, nil?: true

#data ⇒ String?

Data is an embedding of the targeted content. This is encoded as a base64 string when marshalled to JSON (automatically, by encoding/json). If present, Data can be used directly to avoid fetching the targeted content.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


157
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 157

optional :data, String, nil?: true

#digest ⇒ String?

The digest of the targeted content.

Parameters:

  • (String)

Returns:

  • (String, nil)


163
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 163

optional :digest, String

#media_type ⇒ String?

The media type of the object this schema refers to.

Parameters:

  • (String)

Returns:

  • (String, nil)


169
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 169

optional :media_type, String, api_name: :mediaType

#platform ⇒ DockerEngineRuby::Models::ImageSummary::Descriptor::Platform?

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.



177
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 177

optional :platform, -> { DockerEngineRuby::ImageSummary::Descriptor::Platform }

#size ⇒ Integer?

The size in bytes of the blob.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


183
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 183

optional :size, Integer

#urls ⇒ Array<String>?

List of URLs from which this object MAY be downloaded.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


189
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 189

optional :urls, DockerEngineRuby::Internal::Type::ArrayOf[String], nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


123
# File 'sig/docker_engine_ruby/models/image_summary.rbs', line 123

def to_hash: -> {