Class: DockerEngineRuby::Models::ImageSummary::Manifest::ImageData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/image_summary.rb,
sig/docker_engine_ruby/models/image_summary.rbs

Overview

See Also:

  • DockerEngineRuby::Models::ImageSummary::Manifest#image_data

Defined Under Namespace

Classes: Platform, Size

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object

Some parameter documentations has been truncated, see Platform for more details.

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.

Parameters:

  • architecture (String) (defaults to: nil) —

    The CPU architecture, for example amd64 or ppc64.

  • os (String) (defaults to: nil) —

    The operating system, for example linux or windows.

  • os_features (Array<String>) (defaults to: nil) —

    Optional field specifying an array of strings, each listing a required

  • os_version (String) (defaults to: nil) —

    Optional field specifying the operating system version, for example on

  • variant (String) (defaults to: nil) —

    Optional field specifying a variant of the CPU, for example v7 to



# File 'lib/docker_engine_ruby/models/image_summary.rb', line 556

Instance Attribute Details

#containers ⇒ Array<String>

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


539
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 539

required :containers, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Containers

#platform ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Platform

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.

Parameters:

  • value (DockerEngineRuby::ImageSummary::Manifest::ImageData::Platform)

Returns:



547
548
549
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 547

required :platform,
-> { DockerEngineRuby::ImageSummary::Manifest::ImageData::Platform },
api_name: :Platform

#size ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Size

Parameters:

  • value (DockerEngineRuby::ImageSummary::Manifest::ImageData::Size)

Returns:



554
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 554

required :size, -> { DockerEngineRuby::ImageSummary::Manifest::ImageData::Size }, api_name: :Size

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


391
# File 'sig/docker_engine_ruby/models/image_summary.rbs', line 391

def to_hash: -> {