Class: DockerEngineRuby::Models::Info

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb

Overview

Defined Under Namespace

Modules: CgroupDriver, CgroupVersion, Isolation Classes: Containerd, ContainerdCommit, DefaultAddressPool, DiscoveredDevice, FirewallBackend, GenericResource, InitCommit, Nri, Plugins, RegistryConfig, RuncCommit, Runtime, Swarm

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(path: nil, runtime_args: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see Runtime for more details.

Runtime describes an [OCI compliant](github.com/opencontainers/runtime-spec) runtime.

The runtime is invoked by the daemon via the containerd daemon. OCI runtimes act as an interface to the Linux kernel namespaces, cgroups, and SELinux.

Parameters:

  • (defaults to: nil)

    Name and, optional, path, of the OCI executable binary.

  • (defaults to: nil)

    List of command-line arguments to pass to the runtime when invoked.

  • (defaults to: nil)

    Information specific to the runtime.



# File 'lib/docker_engine_ruby/models/info.rb', line 535


Instance Attribute Details

#architectureString?

Hardware architecture of the host, as returned by the operating system. This is equivalent to the output of ‘uname -m` on Linux.

Unlike Arch (from /version), this reports the machine’s native architecture, which can differ from the Go runtime architecture when running a binary compiled for a different architecture (for example, a 32-bit binary running on 64-bit hardware).

Returns:



17
# File 'lib/docker_engine_ruby/models/info.rb', line 17

optional :architecture, String, api_name: :Architecture

#cdi_spec_dirsArray<String>?

List of directories where (Container Device Interface) CDI specifications are located.

These specifications define vendor-specific modifications to an OCI runtime specification for a container being created.

An empty list indicates that CDI device injection is disabled.

Note that since using CDI device injection requires the daemon to have experimental enabled. For non-experimental daemons an empty list will always be returned.

Returns:



33
# File 'lib/docker_engine_ruby/models/info.rb', line 33

optional :cdi_spec_dirs, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :CDISpecDirs

#cgroup_driverSymbol, ...

The driver to use for managing cgroups.

Returns:



39
# File 'lib/docker_engine_ruby/models/info.rb', line 39

optional :cgroup_driver, enum: -> { DockerEngineRuby::Info::CgroupDriver }, api_name: :CgroupDriver

#cgroup_versionSymbol, ...

The version of the cgroup.

Returns:



45
# File 'lib/docker_engine_ruby/models/info.rb', line 45

optional :cgroup_version, enum: -> { DockerEngineRuby::Info::CgroupVersion }, api_name: :CgroupVersion

#containerdDockerEngineRuby::Models::Info::Containerd?

Information for connecting to the containerd instance that is used by the daemon. This is included for debugging purposes only.

Returns:



52
# File 'lib/docker_engine_ruby/models/info.rb', line 52

optional :containerd, -> { DockerEngineRuby::Info::Containerd }, api_name: :Containerd

#containerd_commitDockerEngineRuby::Models::Info::ContainerdCommit?

Commit holds the Git-commit (SHA1) that a binary was built from, as reported in the version-string of external tools, such as containerd, or runC.

Returns:



59
60
61
62
63
# File 'lib/docker_engine_ruby/models/info.rb', line 59

optional :containerd_commit,
-> {
  DockerEngineRuby::Info::ContainerdCommit
},
api_name: :ContainerdCommit

#containersInteger?

Total number of containers on the host.

Returns:



69
# File 'lib/docker_engine_ruby/models/info.rb', line 69

optional :containers, Integer, api_name: :Containers

#containers_pausedInteger?

Number of containers with status ‘“paused”`.

Returns:



75
# File 'lib/docker_engine_ruby/models/info.rb', line 75

optional :containers_paused, Integer, api_name: :ContainersPaused

#containers_runningInteger?

Number of containers with status ‘“running”`.

Returns:



81
# File 'lib/docker_engine_ruby/models/info.rb', line 81

optional :containers_running, Integer, api_name: :ContainersRunning

#containers_stoppedInteger?

Number of containers with status ‘“stopped”`.

Returns:



87
# File 'lib/docker_engine_ruby/models/info.rb', line 87

optional :containers_stopped, Integer, api_name: :ContainersStopped

#cpu_cfs_periodBoolean?

Indicates if CPU CFS(Completely Fair Scheduler) period is supported by the host.

Returns:



93
# File 'lib/docker_engine_ruby/models/info.rb', line 93

optional :cpu_cfs_period, DockerEngineRuby::Internal::Type::Boolean, api_name: :CpuCfsPeriod

#cpu_cfs_quotaBoolean?

Indicates if CPU CFS(Completely Fair Scheduler) quota is supported by the host.

Returns:



99
# File 'lib/docker_engine_ruby/models/info.rb', line 99

optional :cpu_cfs_quota, DockerEngineRuby::Internal::Type::Boolean, api_name: :CpuCfsQuota

#cpu_setBoolean?

Indicates if CPUsets (cpuset.cpus, cpuset.mems) are supported by the host.

See [cpuset(7)](www.kernel.org/doc/Documentation/cgroup-v1/cpusets.txt)

Returns:



107
# File 'lib/docker_engine_ruby/models/info.rb', line 107

optional :cpu_set, DockerEngineRuby::Internal::Type::Boolean, api_name: :CPUSet

#cpu_sharesBoolean?

Indicates if CPU Shares limiting is supported by the host.

Returns:



113
# File 'lib/docker_engine_ruby/models/info.rb', line 113

optional :cpu_shares, DockerEngineRuby::Internal::Type::Boolean, api_name: :CPUShares

#debugBoolean?

Indicates if the daemon is running in debug-mode / with debug-level logging enabled.

Returns:



120
# File 'lib/docker_engine_ruby/models/info.rb', line 120

optional :debug, DockerEngineRuby::Internal::Type::Boolean, api_name: :Debug

#default_address_poolsArray<DockerEngineRuby::Models::Info::DefaultAddressPool>?

List of custom default address pools for local networks, which can be specified in the daemon.json file or dockerd option.

Example: a Base “10.10.0.0/16” with Size 24 will define the set of 256 10.10..0/24 address pools.

Returns:



130
131
132
# File 'lib/docker_engine_ruby/models/info.rb', line 130

optional :default_address_pools,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Info::DefaultAddressPool] },
api_name: :DefaultAddressPools

#default_runtimeString?

Name of the default OCI runtime that is used when starting containers.

The default can be overridden per-container at create time.

Returns:



140
# File 'lib/docker_engine_ruby/models/info.rb', line 140

optional :default_runtime, String, api_name: :DefaultRuntime

#discovered_devicesArray<DockerEngineRuby::Models::Info::DiscoveredDevice>?

List of devices discovered by device drivers.

Each device includes information about its source driver, kind, name, and additional driver-specific attributes.

Returns:



149
150
151
# File 'lib/docker_engine_ruby/models/info.rb', line 149

optional :discovered_devices,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Info::DiscoveredDevice] },
api_name: :DiscoveredDevices

#docker_root_dirString?

Root directory of persistent Docker state.

Defaults to /var/lib/docker on Linux, and ‘C:ProgramDatadocker` on Windows.

Returns:



159
# File 'lib/docker_engine_ruby/models/info.rb', line 159

optional :docker_root_dir, String, api_name: :DockerRootDir

#driverString?

Name of the storage driver in use.

Returns:



165
# File 'lib/docker_engine_ruby/models/info.rb', line 165

optional :driver, String, api_name: :Driver

#driver_statusArray<Array<String>>?

Information specific to the storage driver, provided as “label” / “value” pairs.

This information is provided by the storage driver, and formatted in a way consistent with the output of ‘docker info` on the command line.

<p><br /></p>

> Note: The information returned in this field, including the formatting of > values and labels, should not be considered stable, and may change without > notice.

Returns:



180
181
182
# File 'lib/docker_engine_ruby/models/info.rb', line 180

optional :driver_status,
DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::ArrayOf[String]],
api_name: :DriverStatus

#experimental_buildBoolean?

Indicates if experimental features are enabled on the daemon.

Returns:



188
# File 'lib/docker_engine_ruby/models/info.rb', line 188

optional :experimental_build, DockerEngineRuby::Internal::Type::Boolean, api_name: :ExperimentalBuild

#firewall_backendDockerEngineRuby::Models::Info::FirewallBackend?

Information about the daemon’s firewalling configuration.

This field is currently only used on Linux, and omitted on other platforms.

Returns:



196
# File 'lib/docker_engine_ruby/models/info.rb', line 196

optional :firewall_backend, -> { DockerEngineRuby::Info::FirewallBackend }, api_name: :FirewallBackend

#generic_resourcesArray<DockerEngineRuby::Models::Info::GenericResource>?

Returns:



201
202
203
# File 'lib/docker_engine_ruby/models/info.rb', line 201

optional :generic_resources,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Info::GenericResource] },
api_name: :GenericResources

#http_proxyString?

HTTP-proxy configured for the daemon. This value is obtained from the [HTTP_PROXY](www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable. Credentials ([user info component](tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL are masked in the API response.

Containers do not automatically inherit this configuration.

Returns:



215
# File 'lib/docker_engine_ruby/models/info.rb', line 215

optional :http_proxy, String, api_name: :HttpProxy

#https_proxyString?

HTTPS-proxy configured for the daemon. This value is obtained from the [HTTPS_PROXY](www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable. Credentials ([user info component](tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL are masked in the API response.

Containers do not automatically inherit this configuration.

Returns:



227
# File 'lib/docker_engine_ruby/models/info.rb', line 227

optional :https_proxy, String, api_name: :HttpsProxy

#i_pv4_forwardingBoolean?

Indicates IPv4 forwarding is enabled.

Returns:



275
# File 'lib/docker_engine_ruby/models/info.rb', line 275

optional :i_pv4_forwarding, DockerEngineRuby::Internal::Type::Boolean, api_name: :IPv4Forwarding

#idString?

Unique identifier of the daemon.

<p><br /></p>

> Note: The format of the ID itself is not part of the API, and should not > be considered stable.

Returns:



238
# File 'lib/docker_engine_ruby/models/info.rb', line 238

optional :id, String, api_name: :ID

#imagesInteger?

Total number of images on the host.

Both tagged and untagged (dangling) images are counted.

Returns:



246
# File 'lib/docker_engine_ruby/models/info.rb', line 246

optional :images, Integer, api_name: :Images

#index_server_addressString?

Address / URL of the index server that is used for image search, and as a default for user authentication for Docker Hub and Docker Cloud.

Returns:



253
# File 'lib/docker_engine_ruby/models/info.rb', line 253

optional :index_server_address, String, api_name: :IndexServerAddress

#init_binaryString?

Name and, optional, path of the docker-init binary.

If the path is omitted, the daemon searches the host’s ‘$PATH` for the binary and uses the first result.

Returns:



262
# File 'lib/docker_engine_ruby/models/info.rb', line 262

optional :init_binary, String, api_name: :InitBinary

#init_commitDockerEngineRuby::Models::Info::InitCommit?

Commit holds the Git-commit (SHA1) that a binary was built from, as reported in the version-string of external tools, such as containerd, or runC.

Returns:



269
# File 'lib/docker_engine_ruby/models/info.rb', line 269

optional :init_commit, -> { DockerEngineRuby::Info::InitCommit }, api_name: :InitCommit

#isolationSymbol, ...

Represents the isolation technology to use as a default for containers. The supported values are platform-specific.

If no isolation value is specified on daemon start, on Windows client, the default is hyperv, and on Windows server, the default is process.

This option is currently not used on other platforms.

Returns:



287
# File 'lib/docker_engine_ruby/models/info.rb', line 287

optional :isolation, enum: -> { DockerEngineRuby::Info::Isolation }, api_name: :Isolation

#kernel_versionString?

Kernel version of the host.

On Linux, this information obtained from uname. On Windows this information is queried from the <kbd>HKEY*LOCAL_MACHINE\SOFTWARE\Microsoft\Windows NT\CurrentVersion</kbd> registry value, for example *“10.0 14393 (14393.1198.amd64fre.rs1*release_sec.170427-1353)”*.

Returns:



298
# File 'lib/docker_engine_ruby/models/info.rb', line 298

optional :kernel_version, String, api_name: :KernelVersion

#labelsArray<String>?

User-defined labels (key/value metadata) as set on the daemon.

<p><br /></p>

> Note: When part of a Swarm, nodes can both have daemon labels, set > through the daemon configuration, and node labels, set from a manager node > in the Swarm. Node labels are not included in this field. Node labels can be > retrieved using the ‘/nodes/(id)` endpoint on a manager node in the Swarm.

Returns:



311
# File 'lib/docker_engine_ruby/models/info.rb', line 311

optional :labels, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Labels

#live_restore_enabledBoolean?

Indicates if live restore is enabled.

If enabled, containers are kept running when the daemon is shutdown or upon daemon start if running containers are detected.

Returns:



320
# File 'lib/docker_engine_ruby/models/info.rb', line 320

optional :live_restore_enabled, DockerEngineRuby::Internal::Type::Boolean, api_name: :LiveRestoreEnabled

#logging_driverString?

The logging driver to use as a default for new containers.

Returns:



326
# File 'lib/docker_engine_ruby/models/info.rb', line 326

optional :logging_driver, String, api_name: :LoggingDriver

#mem_totalInteger?

Total amount of physical memory available on the host, in bytes.

Returns:



338
# File 'lib/docker_engine_ruby/models/info.rb', line 338

optional :mem_total, Integer, api_name: :MemTotal

#memory_limitBoolean?

Indicates if the host has memory limit support enabled.

Returns:



332
# File 'lib/docker_engine_ruby/models/info.rb', line 332

optional :memory_limit, DockerEngineRuby::Internal::Type::Boolean, api_name: :MemoryLimit

#n_events_listenerInteger?

Number of event listeners subscribed.

Returns:



360
# File 'lib/docker_engine_ruby/models/info.rb', line 360

optional :n_events_listener, Integer, api_name: :NEventsListener

#n_fdInteger?

The total number of file Descriptors in use by the daemon process.

This information is only returned if debug-mode is enabled.

Returns:



368
# File 'lib/docker_engine_ruby/models/info.rb', line 368

optional :n_fd, Integer, api_name: :NFd

#n_goroutinesInteger?

The number of goroutines that currently exist.

This information is only returned if debug-mode is enabled.

Returns:



376
# File 'lib/docker_engine_ruby/models/info.rb', line 376

optional :n_goroutines, Integer, api_name: :NGoroutines

#nameString?

Hostname of the host.

Returns:



344
# File 'lib/docker_engine_ruby/models/info.rb', line 344

optional :name, String, api_name: :Name

#ncpuInteger?

The number of logical CPUs usable by the daemon.

The number of available CPUs is checked by querying the operating system when the daemon starts. Changes to operating system CPU allocation after the daemon is started are not reflected.

Returns:



354
# File 'lib/docker_engine_ruby/models/info.rb', line 354

optional :ncpu, Integer, api_name: :NCPU

#no_proxyString?

Comma-separated list of domain extensions for which no proxy should be used. This value is obtained from the [NO_PROXY](www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.

Containers do not automatically inherit this configuration.

Returns:



387
# File 'lib/docker_engine_ruby/models/info.rb', line 387

optional :no_proxy, String, api_name: :NoProxy

#nriDockerEngineRuby::Models::Info::Nri?

Information about the Node Resource Interface (NRI).

This field is only present if NRI is enabled.

Returns:



395
# File 'lib/docker_engine_ruby/models/info.rb', line 395

optional :nri, -> { DockerEngineRuby::Info::Nri }, api_name: :NRI

#oom_kill_disableBoolean?

Indicates if OOM killer disable is supported on the host.

Returns:



401
# File 'lib/docker_engine_ruby/models/info.rb', line 401

optional :oom_kill_disable, DockerEngineRuby::Internal::Type::Boolean, api_name: :OomKillDisable

#operating_systemString?

Name of the host’s operating system, for example: “Ubuntu 24.04 LTS” or “Windows Server 2016 Datacenter”

Returns:



408
# File 'lib/docker_engine_ruby/models/info.rb', line 408

optional :operating_system, String, api_name: :OperatingSystem

#os_typeString?

Generic type of the operating system of the host, as returned by the Go runtime (GOOS).

Currently returned values are “linux” and “windows”. A full list of possible values can be found in the [Go documentation](go.dev/doc/install/source#environment).

Returns:



419
# File 'lib/docker_engine_ruby/models/info.rb', line 419

optional :os_type, String, api_name: :OSType

#os_versionString?

Version of the host’s operating system

<p><br /></p>

> Note: The information returned in this field, including its very > existence, and the formatting of values, should not be considered stable, and > may change without notice.

Returns:



431
# File 'lib/docker_engine_ruby/models/info.rb', line 431

optional :os_version, String, api_name: :OSVersion

#pids_limitBoolean?

Indicates if the host kernel has PID limit support enabled.

Returns:



437
# File 'lib/docker_engine_ruby/models/info.rb', line 437

optional :pids_limit, DockerEngineRuby::Internal::Type::Boolean, api_name: :PidsLimit

#pluginsDockerEngineRuby::Models::Info::Plugins?

Available plugins per type.

<p><br /></p>

> Note: Only unmanaged (V1) plugins are included in this list. V1 plugins > are “lazily” loaded, and are not returned in this list if there is no resource > using the plugin.

Returns:



449
# File 'lib/docker_engine_ruby/models/info.rb', line 449

optional :plugins, -> { DockerEngineRuby::Info::Plugins }, api_name: :Plugins

#product_licenseString?

Reports a summary of the product license on the daemon.

If a commercial license has been applied to the daemon, information such as number of nodes, and expiration are included.

Returns:



458
# File 'lib/docker_engine_ruby/models/info.rb', line 458

optional :product_license, String, api_name: :ProductLicense

#registry_configDockerEngineRuby::Models::Info::RegistryConfig?

RegistryServiceConfig stores daemon registry services configuration.

Returns:



464
# File 'lib/docker_engine_ruby/models/info.rb', line 464

optional :registry_config, -> { DockerEngineRuby::Info::RegistryConfig }, api_name: :RegistryConfig

#runc_commitDockerEngineRuby::Models::Info::RuncCommit?

Commit holds the Git-commit (SHA1) that a binary was built from, as reported in the version-string of external tools, such as containerd, or runC.

Returns:



471
# File 'lib/docker_engine_ruby/models/info.rb', line 471

optional :runc_commit, -> { DockerEngineRuby::Info::RuncCommit }, api_name: :RuncCommit

#runtimesHash{Symbol=>DockerEngineRuby::Models::Info::Runtime}?

List of [OCI compliant](github.com/opencontainers/runtime-spec) runtimes configured on the daemon. Keys hold the “name” used to reference the runtime.

The Docker daemon relies on an OCI compliant runtime (invoked via the containerd daemon) as its interface to the Linux kernel namespaces, cgroups, and SELinux.

The default runtime is runc, and automatically configured. Additional runtimes can be configured by the user and will be listed here.

Returns:



485
486
487
# File 'lib/docker_engine_ruby/models/info.rb', line 485

optional :runtimes,
-> { DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Info::Runtime] },
api_name: :Runtimes

#security_optionsArray<String>?

List of security features that are enabled on the daemon, such as apparmor, seccomp, SELinux, user-namespaces (userns), rootless and no-new-privileges.

Additional configuration options for each security feature may be present, and are included as a comma-separated list of key/value pairs.

Returns:



497
498
499
# File 'lib/docker_engine_ruby/models/info.rb', line 497

optional :security_options,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :SecurityOptions

#server_versionString?

Version string of the daemon.

Returns:



505
# File 'lib/docker_engine_ruby/models/info.rb', line 505

optional :server_version, String, api_name: :ServerVersion

#swap_limitBoolean?

Indicates if the host has memory swap limit support enabled.

Returns:



511
# File 'lib/docker_engine_ruby/models/info.rb', line 511

optional :swap_limit, DockerEngineRuby::Internal::Type::Boolean, api_name: :SwapLimit

#swarmDockerEngineRuby::Models::Info::Swarm?

Represents generic information about swarm.

Returns:



517
# File 'lib/docker_engine_ruby/models/info.rb', line 517

optional :swarm, -> { DockerEngineRuby::Info::Swarm }, api_name: :Swarm

#system_timeString?

Current system-time in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:



524
# File 'lib/docker_engine_ruby/models/info.rb', line 524

optional :system_time, String, api_name: :SystemTime

#warningsArray<String>?

List of warnings / informational messages about missing features, or issues related to the daemon configuration.

These messages can be printed by the client as information to the user.

Returns:



533
# File 'lib/docker_engine_ruby/models/info.rb', line 533

optional :warnings, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Warnings

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/docker_engine_ruby/models/info.rb', line 673