Class: DockerEngineRuby::Models::Info::Containerd

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb

Overview

See Also:

Defined Under Namespace

Classes: Namespaces

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address: nil, namespaces: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Info::Containerd for more details.

Information for connecting to the containerd instance that is used by the daemon. This is included for debugging purposes only.

Parameters:



# File 'lib/docker_engine_ruby/models/info.rb', line 711


Instance Attribute Details

#addressString?

The address of the containerd socket.

Returns:

  • (String, nil)


696
# File 'lib/docker_engine_ruby/models/info.rb', line 696

optional :address, String, api_name: :Address

#namespacesDockerEngineRuby::Models::Info::Containerd::Namespaces?

The namespaces that the daemon uses for running containers and plugins in containerd. These namespaces can be configured in the daemon configuration, and are considered to be used exclusively by the daemon, Tampering with the containerd instance may cause unexpected behavior.

As these namespaces are considered to be exclusively accessed by the daemon, it is not recommended to change these values, or to change them to a value that is used by other systems, such as cri-containerd.



709
# File 'lib/docker_engine_ruby/models/info.rb', line 709

optional :namespaces, -> { DockerEngineRuby::Info::Containerd::Namespaces }, api_name: :Namespaces