Class: DockerEngineRuby::Models::Info::RegistryConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb

Overview

See Also:

Defined Under Namespace

Classes: IndexConfig

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel

Instance Attribute Details

#index_configsHash{Symbol=>DockerEngineRuby::Models::Info::RegistryConfig::IndexConfig}?



1006
1007
1008
1009
1010
# File 'lib/docker_engine_ruby/models/info.rb', line 1006

optional :index_configs,
-> {
  DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Info::RegistryConfig::IndexConfig]
},
api_name: :IndexConfigs

#insecure_registry_cid_rsArray<String>?

List of IP ranges of insecure registries, using the CIDR syntax ([RFC 4632](tools.ietf.org/html/4632)). Insecure registries accept un-encrypted (HTTP) and/or untrusted (HTTPS with certificates from unknown CAs) communication.

By default, local registries (::1/128 and 127.0.0.0/8) are configured as insecure. All other registries are secure. Communicating with an insecure registry is not possible if the daemon assumes that registry is secure.

This configuration override this behavior, insecure communication with registries whose resolved IP address is within the subnet described by the CIDR syntax.

Registries can also be marked insecure by hostname. Those registries are listed under IndexConfigs and have their Secure field set to false.

> Warning: Using this option can be useful when running a local registry, > but introduces security vulnerabilities. This option should therefore ONLY be > used for testing purposes. For increased security, users should add their CA > to their system’s list of trusted CAs instead of enabling this option.

Returns:

  • (Array<String>, nil)


1035
1036
1037
# File 'lib/docker_engine_ruby/models/info.rb', line 1035

optional :insecure_registry_cid_rs,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :InsecureRegistryCIDRs

#mirrorsArray<String>?

List of registry URLs that act as a mirror for the official (docker.io) registry.

Returns:

  • (Array<String>, nil)


1044
# File 'lib/docker_engine_ruby/models/info.rb', line 1044

optional :mirrors, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Mirrors