Class: DockerEngineRuby::Models::Info::RegistryConfig::IndexConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index_configs: nil, insecure_registry_cid_rs: nil, mirrors: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Info::RegistryConfig for more details.

RegistryServiceConfig stores daemon registry services configuration.

Parameters:

  • index_configs (Hash{Symbol=>DockerEngineRuby::Models::Info::RegistryConfig::IndexConfig}) (defaults to: nil)
  • insecure_registry_cid_rs (Array<String>) (defaults to: nil)

    List of IP ranges of insecure registries, using the CIDR syntax

  • mirrors (Array<String>) (defaults to: nil)

    List of registry URLs that act as a mirror for the official



1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/docker_engine_ruby/models/info.rb', line 1058

class IndexConfig < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute mirrors
  #   List of mirrors, expressed as URIs.
  #
  #   @return [Array<String>, nil]
  optional :mirrors, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Mirrors

  # @!attribute name
  #   Name of the registry, such as "docker.io".
  #
  #   @return [String, nil]
  optional :name, String, api_name: :Name

  # @!attribute official
  #   Indicates whether this is an official registry (i.e., Docker Hub / docker.io)
  #
  #   @return [Boolean, nil]
  optional :official, DockerEngineRuby::Internal::Type::Boolean, api_name: :Official

  # @!attribute secure
  #   Indicates if the registry is part of the list of insecure registries.
  #
  #   If `false`, the registry is insecure. Insecure registries accept un-encrypted
  #   (HTTP) and/or untrusted (HTTPS with certificates from unknown CAs)
  #   communication.
  #
  #   > **Warning**: Insecure registries can be useful when running a local registry.
  #   > However, because its use creates security vulnerabilities it should ONLY be
  #   > enabled for testing purposes. For increased security, users should add their
  #   > CA to their system's list of trusted CAs instead of enabling this option.
  #
  #   @return [Boolean, nil]
  optional :secure, DockerEngineRuby::Internal::Type::Boolean, api_name: :Secure

  # @!method initialize(mirrors: nil, name: nil, official: nil, secure: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineRuby::Models::Info::RegistryConfig::IndexConfig} for more details.
  #
  #   IndexInfo contains information about a registry.
  #
  #   @param mirrors [Array<String>] List of mirrors, expressed as URIs.
  #
  #   @param name [String] Name of the registry, such as "docker.io".
  #
  #   @param official [Boolean] Indicates whether this is an official registry (i.e., Docker Hub / docker.io)
  #
  #   @param secure [Boolean] Indicates if the registry is part of the list of insecure
end

Instance Attribute Details

#mirrorsArray<String>?

List of mirrors, expressed as URIs.

Returns:

  • (Array<String>, nil)


1063
# File 'lib/docker_engine_ruby/models/info.rb', line 1063

optional :mirrors, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Mirrors

#nameString?

Name of the registry, such as “docker.io”.

Returns:

  • (String, nil)


1069
# File 'lib/docker_engine_ruby/models/info.rb', line 1069

optional :name, String, api_name: :Name

#officialBoolean?

Indicates whether this is an official registry (i.e., Docker Hub / docker.io)

Returns:

  • (Boolean, nil)


1075
# File 'lib/docker_engine_ruby/models/info.rb', line 1075

optional :official, DockerEngineRuby::Internal::Type::Boolean, api_name: :Official

#secureBoolean?

Indicates if the registry is part of the list of insecure registries.

If false, the registry is insecure. Insecure registries accept un-encrypted (HTTP) and/or untrusted (HTTPS with certificates from unknown CAs) communication.

> Warning: Insecure registries can be useful when running a local registry. > However, because its use creates security vulnerabilities it should ONLY be > enabled for testing purposes. For increased security, users should add their > CA to their system’s list of trusted CAs instead of enabling this option.

Returns:

  • (Boolean, nil)


1090
# File 'lib/docker_engine_ruby/models/info.rb', line 1090

optional :secure, DockerEngineRuby::Internal::Type::Boolean, api_name: :Secure