Class: DockerEngineRuby::Models::Info::Runtime

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb,
sig/docker_engine_ruby/models/info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



850
# File 'sig/docker_engine_ruby/models/info.rbs', line 850

def initialize: (

Instance Attribute Details

#path ⇒ String?

Name and, optional, path, of the OCI executable binary.

If the path is omitted, the daemon searches the host's $PATH for the binary and uses the first result.

Parameters:

  • (String)

Returns:

  • (String, nil)


1131
# File 'lib/docker_engine_ruby/models/info.rb', line 1131

optional :path, String

#runtime_args ⇒ Array<String>?

List of command-line arguments to pass to the runtime when invoked.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


1137
1138
1139
1140
# File 'lib/docker_engine_ruby/models/info.rb', line 1137

optional :runtime_args,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :runtimeArgs,
nil?: true

#status ⇒ Hash{Symbol=>String}?

Information specific to the runtime.

While this API specification does not define data provided by runtimes, the following well-known properties may be provided by runtimes:

org.opencontainers.runtime-spec.features: features structure as defined in the OCI Runtime Specification, in a JSON string representation.


Note: The information returned in this field, including the formatting of values and labels, should not be considered stable, and may change without notice.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


1159
# File 'lib/docker_engine_ruby/models/info.rb', line 1159

optional :status, DockerEngineRuby::Internal::Type::HashOf[String], nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


856
# File 'sig/docker_engine_ruby/models/info.rbs', line 856

def to_hash: -> {