Class: DockerEngineRuby::Models::Info::Swarm::RemoteManager

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/info.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(addr: nil, node_id: nil) ⇒ Object

Represents a peer-node in the swarm

Parameters:

  • addr (String) (defaults to: nil)

    IP address and ports at which this node can be reached.

  • node_id (String) (defaults to: nil)

    Unique identifier of for this node in the swarm.



# File 'lib/docker_engine_ruby/models/info.rb', line 1457

Instance Attribute Details

#addrString?

IP address and ports at which this node can be reached.

Returns:

  • (String, nil)


1449
# File 'lib/docker_engine_ruby/models/info.rb', line 1449

optional :addr, String, api_name: :Addr

#node_idString?

Unique identifier of for this node in the swarm.

Returns:

  • (String, nil)


1455
# File 'lib/docker_engine_ruby/models/info.rb', line 1455

optional :node_id, String, api_name: :NodeID