Class: DockerEngineRuby::Models::Inspect::Platform
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Inspect::Platform
- Defined in:
- lib/docker_engine_ruby/models/inspect.rb
Instance Attribute Summary collapse
-
#architecture ⇒ String?
The CPU architecture, for example
amd64orppc64. -
#os ⇒ String?
The operating system, for example
linuxorwindows. -
#os_features ⇒ Array<String>?
Optional field specifying an array of strings, each listing a required OS feature (for example on Windows
win32k). -
#os_version ⇒ String?
Optional field specifying the operating system version, for example on Windows
10.0.19041.1165. -
#variant ⇒ String?
Optional field specifying a variant of the CPU, for example
v7to specify ARMv7 when architecture isarm.
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Platform for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Inspect::Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
|
|
# File 'lib/docker_engine_ruby/models/inspect.rb', line 199
|
Instance Attribute Details
#architecture ⇒ String?
The CPU architecture, for example amd64 or ppc64.
170 |
# File 'lib/docker_engine_ruby/models/inspect.rb', line 170 optional :architecture, String |
#os ⇒ String?
The operating system, for example linux or windows.
176 |
# File 'lib/docker_engine_ruby/models/inspect.rb', line 176 optional :os, String |
#os_features ⇒ Array<String>?
Optional field specifying an array of strings, each listing a required OS feature (for example on Windows win32k).
183 |
# File 'lib/docker_engine_ruby/models/inspect.rb', line 183 optional :os_features, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :"os.features" |
#os_version ⇒ String?
Optional field specifying the operating system version, for example on Windows 10.0.19041.1165.
190 |
# File 'lib/docker_engine_ruby/models/inspect.rb', line 190 optional :os_version, String, api_name: :"os.version" |
#variant ⇒ String?
Optional field specifying a variant of the CPU, for example v7 to specify ARMv7 when architecture is arm.
197 |
# File 'lib/docker_engine_ruby/models/inspect.rb', line 197 optional :variant, String |