Class: DockerEngineRuby::Models::ListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/list_response.rb,
sig/docker_engine_ruby/models/list_response.rbs

Overview

See Also:

  • DockerEngineRuby::Resources::Volumes#list

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(volumes: nil, warnings: nil) ⇒ Object

Volume list response

Parameters:

  • volumes (Array<DockerEngineRuby::Models::Volume>) (defaults to: nil) —

    List of volumes

  • warnings (Array<String>) (defaults to: nil) —

    Warnings that occurred when fetching the list of volumes.



# File 'lib/docker_engine_ruby/models/list_response.rb', line 21

Instance Attribute Details

#volumes ⇒ Array<DockerEngineRuby::Models::Volume>?

List of volumes

Returns:



11
12
13
# File 'lib/docker_engine_ruby/models/list_response.rb', line 11

optional :volumes,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Volume] },
api_name: :Volumes

#warnings ⇒ Array<String>?

Warnings that occurred when fetching the list of volumes.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


19
# File 'lib/docker_engine_ruby/models/list_response.rb', line 19

optional :warnings, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Warnings

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


22
# File 'sig/docker_engine_ruby/models/list_response.rbs', line 22

def to_hash: -> {