Class: DockerEngineRuby::Models::NetworkCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_ruby/models/network_create_params.rb

Overview

Defined Under Namespace

Classes: ConfigFrom, Ipam

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(network: nil) ⇒ Object

Some parameter documentations has been truncated, see ConfigFrom for more details.

The config-only network source to provide the configuration for this network.

Parameters:

  • network (String) (defaults to: nil)

    The name of the config-only network that provides the network’s



# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 117


Instance Attribute Details

#attachableBoolean?

Returns:

  • (Boolean, nil)


18
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 18

optional :attachable, DockerEngineRuby::Internal::Type::Boolean, api_name: :Attachable

#config_fromDockerEngineRuby::Models::NetworkCreateParams::ConfigFrom?

The config-only network source to provide the configuration for this network.



24
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 24

optional :config_from, -> { DockerEngineRuby::NetworkCreateParams::ConfigFrom }, api_name: :ConfigFrom

#config_onlyBoolean?

Returns:

  • (Boolean, nil)


29
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 29

optional :config_only, DockerEngineRuby::Internal::Type::Boolean, api_name: :ConfigOnly

#driverString?

Returns:

  • (String, nil)


34
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 34

optional :driver, String, api_name: :Driver

#enable_i_pv4Boolean?

Returns:

  • (Boolean, nil)


39
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 39

optional :enable_i_pv4, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv4

#enable_i_pv6Boolean?

Returns:

  • (Boolean, nil)


44
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 44

optional :enable_i_pv6, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv6

#ingressBoolean?

Returns:

  • (Boolean, nil)


49
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 49

optional :ingress, DockerEngineRuby::Internal::Type::Boolean, api_name: :Ingress

#internalBoolean?

Returns:

  • (Boolean, nil)


54
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 54

optional :internal, DockerEngineRuby::Internal::Type::Boolean, api_name: :Internal

#ipamDockerEngineRuby::Models::NetworkCreateParams::Ipam?



59
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 59

optional :ipam, -> { DockerEngineRuby::NetworkCreateParams::Ipam }, api_name: :IPAM

#labelsHash{Symbol=>String}?

Returns:

  • (Hash{Symbol=>String}, nil)


64
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 64

optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels

#nameString

Returns:

  • (String)


13
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 13

required :name, String, api_name: :Name

#optionsHash{Symbol=>String}?

Returns:

  • (Hash{Symbol=>String}, nil)


69
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 69

optional :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options

#scopeString?

Returns:

  • (String, nil)


74
# File 'lib/docker_engine_ruby/models/network_create_params.rb', line 74

optional :scope, String, api_name: :Scope