Class: DockerEngineRuby::Models::NetworkSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/network_summary.rb

Defined Under Namespace

Classes: ConfigFrom, Ipam, Peer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(auxiliary_addresses: nil, gateway: nil, ip_range: nil, subnet: nil) ⇒ Object

Parameters:

  • auxiliary_addresses (Hash{Symbol=>String}) (defaults to: nil)
  • gateway (String) (defaults to: nil)
  • ip_range (String) (defaults to: nil)
  • subnet (String) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/network_summary.rb', line 110


Instance Attribute Details

#attachableBoolean?

Whether a global / swarm scope network is manually attachable by regular containers from workers in swarm mode.

Returns:

  • (Boolean, nil)


11
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 11

optional :attachable, DockerEngineRuby::Internal::Type::Boolean, api_name: :Attachable

#config_fromDockerEngineRuby::Models::NetworkSummary::ConfigFrom?

The config-only network source to provide the configuration for this network.



17
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 17

optional :config_from, -> { DockerEngineRuby::NetworkSummary::ConfigFrom }, api_name: :ConfigFrom

#config_onlyBoolean?

Whether the network is a config-only network. Config-only networks are placeholder networks for network configurations to be used by other networks. Config-only networks cannot be used directly to run containers or services.

Returns:

  • (Boolean, nil)


25
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 25

optional :config_only, DockerEngineRuby::Internal::Type::Boolean, api_name: :ConfigOnly

#createdTime?

Date and time at which the network was created in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (Time, nil)


32
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 32

optional :created, Time, api_name: :Created

#driverString?

The name of the driver used to create the network (e.g. bridge, overlay).

Returns:

  • (String, nil)


38
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 38

optional :driver, String, api_name: :Driver

#enable_i_pv4Boolean?

Whether the network was created with IPv4 enabled.

Returns:

  • (Boolean, nil)


44
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 44

optional :enable_i_pv4, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv4

#enable_i_pv6Boolean?

Whether the network was created with IPv6 enabled.

Returns:

  • (Boolean, nil)


50
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 50

optional :enable_i_pv6, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv6

#idString?

ID that uniquely identifies a network on a single machine.

Returns:

  • (String, nil)


56
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 56

optional :id, String, api_name: :Id

#ingressBoolean?

Whether the network is providing the routing-mesh for the swarm cluster.

Returns:

  • (Boolean, nil)


62
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 62

optional :ingress, DockerEngineRuby::Internal::Type::Boolean, api_name: :Ingress

#internalBoolean?

Whether the network is created to only allow internal networking connectivity.

Returns:

  • (Boolean, nil)


68
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 68

optional :internal, DockerEngineRuby::Internal::Type::Boolean, api_name: :Internal

#ipamDockerEngineRuby::Models::NetworkSummary::Ipam?

The network’s IP Address Management.



74
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 74

optional :ipam, -> { DockerEngineRuby::NetworkSummary::Ipam }, api_name: :IPAM

#labelsHash{Symbol=>String}?

Metadata specific to the network being created.

Returns:

  • (Hash{Symbol=>String}, nil)


80
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 80

optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels

#nameString?

Name of the network.

Returns:

  • (String, nil)


86
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 86

optional :name, String, api_name: :Name

#optionsHash{Symbol=>String}?

Network-specific options uses when creating the network.

Returns:

  • (Hash{Symbol=>String}, nil)


92
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 92

optional :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options

#peersArray<DockerEngineRuby::Models::NetworkSummary::Peer>?

List of peer nodes for an overlay network. This field is only present for overlay networks, and omitted for other network types.



99
100
101
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 99

optional :peers,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::NetworkSummary::Peer] },
api_name: :Peers

#scopeString?

The level at which the network exists (e.g. swarm for cluster-wide or local for machine level)

Returns:

  • (String, nil)


108
# File 'lib/docker_engine_ruby/models/network_summary.rb', line 108

optional :scope, String, api_name: :Scope