Class: DockerEngineRuby::Models::Privilege
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Privilege
- Defined in:
- lib/docker_engine_ruby/models/privilege.rb
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(description: nil, name: nil, value: nil) ⇒ Object
constructor
Describes a permission the user has to accept upon installing the plugin.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, name: nil, value: nil) ⇒ Object
Describes a permission the user has to accept upon installing the plugin.
|
|
# File 'lib/docker_engine_ruby/models/privilege.rb', line 21
|
Instance Attribute Details
#description ⇒ String?
9 |
# File 'lib/docker_engine_ruby/models/privilege.rb', line 9 optional :description, String, api_name: :Description |
#name ⇒ String?
14 |
# File 'lib/docker_engine_ruby/models/privilege.rb', line 14 optional :name, String, api_name: :Name |
#value ⇒ Array<String>?
19 |
# File 'lib/docker_engine_ruby/models/privilege.rb', line 19 optional :value, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Value |