Class: DockerEngineRuby::Models::Secret::Version

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/secret.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index: nil) ⇒ Object

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.

Parameters:

  • index (Integer) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/secret.rb', line 62


Instance Attribute Details

#indexInteger?

Returns:

  • (Integer, nil)


60
# File 'lib/docker_engine_ruby/models/secret.rb', line 60

optional :index, Integer, api_name: :Index