Class: DockerEngineRuby::Models::Service

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/service.rb

Overview

Defined Under Namespace

Classes: Endpoint, JobStatus, ServiceStatus, UpdateStatus, Version

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_tasks: nil, desired_tasks: nil, running_tasks: nil) ⇒ Object

The status of the service’s tasks. Provided only when requested as part of a ServiceList operation.

Parameters:

  • completed_tasks (Integer) (defaults to: nil)
  • desired_tasks (Integer) (defaults to: nil)
  • running_tasks (Integer) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/service.rb', line 69

Instance Attribute Details

#created_atTime?

Returns:

  • (Time, nil)


10
# File 'lib/docker_engine_ruby/models/service.rb', line 10

optional :created_at, Time, api_name: :CreatedAt

#endpointDockerEngineRuby::Models::Service::Endpoint?



15
# File 'lib/docker_engine_ruby/models/service.rb', line 15

optional :endpoint, -> { DockerEngineRuby::Service::Endpoint }, api_name: :Endpoint

#idString?

Returns:

  • (String, nil)


20
# File 'lib/docker_engine_ruby/models/service.rb', line 20

optional :id, String, api_name: :ID

#job_statusDockerEngineRuby::Models::Service::JobStatus?

The status of the service when it is in one of ReplicatedJob or GlobalJob modes. Absent on Replicated and Global mode services. The JobIteration is an ObjectVersion, but unlike the Service’s version, does not need to be sent with an update request.



29
# File 'lib/docker_engine_ruby/models/service.rb', line 29

optional :job_status, -> { DockerEngineRuby::Service::JobStatus }, api_name: :JobStatus

#service_statusDockerEngineRuby::Models::Service::ServiceStatus?

The status of the service’s tasks. Provided only when requested as part of a ServiceList operation.



36
# File 'lib/docker_engine_ruby/models/service.rb', line 36

optional :service_status, -> { DockerEngineRuby::Service::ServiceStatus }, api_name: :ServiceStatus

#specDockerEngineRuby::Models::ServiceSpec?

User modifiable configuration for a service.



42
# File 'lib/docker_engine_ruby/models/service.rb', line 42

optional :spec, -> { DockerEngineRuby::ServiceSpec }, api_name: :Spec

#update_statusDockerEngineRuby::Models::Service::UpdateStatus?

The status of a service update.



53
# File 'lib/docker_engine_ruby/models/service.rb', line 53

optional :update_status, -> { DockerEngineRuby::Service::UpdateStatus }, api_name: :UpdateStatus

#updated_atTime?

Returns:

  • (Time, nil)


47
# File 'lib/docker_engine_ruby/models/service.rb', line 47

optional :updated_at, Time, api_name: :UpdatedAt

#versionDockerEngineRuby::Models::Service::Version?

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.



67
# File 'lib/docker_engine_ruby/models/service.rb', line 67

optional :version, -> { DockerEngineRuby::Service::Version }, api_name: :Version

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/service.rb', line 480