Class: DockerEngineRuby::Models::Service::Endpoint
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Service::Endpoint
- Defined in:
- lib/docker_engine_ruby/models/service.rb
Overview
Defined Under Namespace
Classes: Port, Spec, VirtualIP
Instance Attribute Summary collapse
- #ports ⇒ Array<DockerEngineRuby::Models::Service::Endpoint::Port>?
-
#spec ⇒ DockerEngineRuby::Models::Service::Endpoint::Spec?
Properties that can be configured to access and load balance a service.
- #virtual_ips ⇒ Array<DockerEngineRuby::Models::Service::Endpoint::VirtualIP>?
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#ports ⇒ Array<DockerEngineRuby::Models::Service::Endpoint::Port>?
96 97 98 |
# File 'lib/docker_engine_ruby/models/service.rb', line 96 optional :ports, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Service::Endpoint::Port] }, api_name: :Ports |
#spec ⇒ DockerEngineRuby::Models::Service::Endpoint::Spec?
Properties that can be configured to access and load balance a service.
104 |
# File 'lib/docker_engine_ruby/models/service.rb', line 104 optional :spec, -> { DockerEngineRuby::Service::Endpoint::Spec }, api_name: :Spec |
#virtual_ips ⇒ Array<DockerEngineRuby::Models::Service::Endpoint::VirtualIP>?
109 110 111 112 113 |
# File 'lib/docker_engine_ruby/models/service.rb', line 109 optional :virtual_ips, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Service::Endpoint::VirtualIP] }, api_name: :VirtualIPs |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/service.rb', line 206
|