Module: DockerEngineRuby::Models::Service::Endpoint::Spec::Port::PublishMode

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/service.rb,
sig/docker_engine_ruby/models/service.rbs

Overview

The mode in which port is published.


  • "ingress" makes the target port accessible on every node, regardless of whether there is a task for the service running on that node or not.
  • "host" bypasses the routing mesh and publish the port directly on the swarm node where that service is running.

See Also:

  • DockerEngineRuby::Models::Service::Endpoint::Spec::Port#publish_mode

Constant Summary collapse

INGRESS =

Returns:

  • (:ingress)
:ingress
HOST =

Returns:

  • (:host)
:host

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[DockerEngineRuby::Models::Service::Endpoint::Spec::Port::publish_mode]

Returns:

  • (::Array[DockerEngineRuby::Models::Service::Endpoint::Spec::Port::publish_mode])


311
# File 'sig/docker_engine_ruby/models/service.rbs', line 311

def self?.values: -> ::Array[DockerEngineRuby::Models::Service::Endpoint::Spec::Port::publish_mode]