Class: DockerEngineRuby::Models::StatsResponse::BlkioStats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/stats_response.rb

Overview

See Also:

Defined Under Namespace

Classes: IoMergedRecursive, IoQueueRecursive, IoServiceBytesRecursive, IoServiceTimeRecursive, IoServicedRecursive, IoTimeRecursive, IoWaitTimeRecursive, SectorsRecursive

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(major: nil, minor: nil, op: nil, value: nil) ⇒ Object

Blkio stats entry.

This type is Linux-specific and omitted for Windows containers.

Parameters:

  • major (Integer) (defaults to: nil)
  • minor (Integer) (defaults to: nil)
  • op (String) (defaults to: nil)
  • value (Integer) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/stats_response.rb', line 276


Instance Attribute Details

#io_merged_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoMergedRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



149
150
151
152
153
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 149

optional :io_merged_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoMergedRecursive]
},
nil?: true

#io_queue_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoQueueRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



160
161
162
163
164
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 160

optional :io_queue_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoQueueRecursive]
},
nil?: true

#io_service_bytes_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoServiceBytesRecursive>?



169
170
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 169

optional :io_service_bytes_recursive,
-> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoServiceBytesRecursive] }

#io_service_time_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoServiceTimeRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



177
178
179
180
181
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 177

optional :io_service_time_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoServiceTimeRecursive]
},
nil?: true

#io_serviced_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoServicedRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



188
189
190
191
192
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 188

optional :io_serviced_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoServicedRecursive]
},
nil?: true

#io_time_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoTimeRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



199
200
201
202
203
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 199

optional :io_time_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoTimeRecursive]
},
nil?: true

#io_wait_time_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::IoWaitTimeRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



210
211
212
213
214
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 210

optional :io_wait_time_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::IoWaitTimeRecursive]
},
nil?: true

#sectors_recursiveArray<DockerEngineRuby::Models::StatsResponse::BlkioStats::SectorsRecursive>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



221
222
223
224
225
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 221

optional :sectors_recursive,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::StatsResponse::BlkioStats::SectorsRecursive]
},
nil?: true