Class: DockerEngineRuby::Models::StatsResponse::BlkioStats::IoMergedRecursive

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/stats_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(io_merged_recursive: nil, io_queue_recursive: nil, io_service_bytes_recursive: nil, io_service_time_recursive: nil, io_serviced_recursive: nil, io_time_recursive: nil, io_wait_time_recursive: nil, sectors_recursive: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::StatsResponse::BlkioStats for more details.

BlkioStats stores all IO service stats for data read and write.

This type is Linux-specific and holds many fields that are specific to cgroups v1. On a cgroup v2 host, all fields other than io_service_bytes_recursive are omitted or null.

This type is only populated on Linux and omitted for Windows containers.

Parameters:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 255

class IoMergedRecursive < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute major
  #
  #   @return [Integer, nil]
  optional :major, Integer

  # @!attribute minor
  #
  #   @return [Integer, nil]
  optional :minor, Integer

  # @!attribute op
  #
  #   @return [String, nil]
  optional :op, String

  # @!attribute value
  #
  #   @return [Integer, nil]
  optional :value, Integer

  # @!method initialize(major: nil, minor: nil, op: nil, value: nil)
  #   Blkio stats entry.
  #
  #   This type is Linux-specific and omitted for Windows containers.
  #
  #   @param major [Integer]
  #   @param minor [Integer]
  #   @param op [String]
  #   @param value [Integer]
end

Instance Attribute Details

#majorInteger?

Returns:

  • (Integer, nil)


259
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 259

optional :major, Integer

#minorInteger?

Returns:

  • (Integer, nil)


264
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 264

optional :minor, Integer

#opString?

Returns:

  • (String, nil)


269
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 269

optional :op, String

#valueInteger?

Returns:

  • (Integer, nil)


274
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 274

optional :value, Integer