Class: DockerEngineRuby::Models::StatsResponse::CPUStats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/stats_response.rb,
sig/docker_engine_ruby/models/stats_response.rbs

Overview

See Also:

  • DockerEngineRuby::Models::StatsResponse#cpu_stats

Defined Under Namespace

Classes: CPUUsage, ThrottlingData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(percpu_usage: nil, total_usage: nil, usage_in_kernelmode: nil, usage_in_usermode: nil) ⇒ Object

Some parameter documentations has been truncated, see CPUUsage for more details.

All CPU stats aggregated since container inception.

Parameters:

  • percpu_usage (Array<Integer>, nil) (defaults to: nil) —

    Total CPU time (in nanoseconds) consumed per core (Linux).

  • total_usage (Integer) (defaults to: nil) —

    Total CPU time consumed in nanoseconds (Linux) or 100's of nanoseconds (Windows)

  • usage_in_kernelmode (Integer) (defaults to: nil) —

    Time (in nanoseconds) spent by tasks of the cgroup in kernel mode (Linux),

  • usage_in_usermode (Integer) (defaults to: nil) —

    Time (in nanoseconds) spent by tasks of the cgroup in user mode (Linux),



# File 'lib/docker_engine_ruby/models/stats_response.rb', line 544

Instance Attribute Details

#cpu_usage ⇒ DockerEngineRuby::Models::StatsResponse::CPUStats::CPUUsage?

All CPU stats aggregated since container inception.



518
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 518

optional :cpu_usage, -> { DockerEngineRuby::StatsResponse::CPUStats::CPUUsage }

#online_cpus ⇒ Integer?

Number of online CPUs.

This field is Linux-specific and omitted for Windows containers.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


526
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 526

optional :online_cpus, Integer, nil?: true

#system_cpu_usage ⇒ Integer?

System Usage.

This field is Linux-specific and omitted for Windows containers.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


534
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 534

optional :system_cpu_usage, Integer, nil?: true

#throttling_data ⇒ DockerEngineRuby::Models::StatsResponse::CPUStats::ThrottlingData?

CPU throttling stats of the container.

This type is Linux-specific and omitted for Windows containers.



542
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 542

optional :throttling_data, -> { DockerEngineRuby::StatsResponse::CPUStats::ThrottlingData }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


477
# File 'sig/docker_engine_ruby/models/stats_response.rbs', line 477

def to_hash: -> {