Class: DockerEngineRuby::Models::StatsResponse::CPUStats::ThrottlingData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::StatsResponse::CPUStats::ThrottlingData
- Defined in:
- lib/docker_engine_ruby/models/stats_response.rb
Overview
Instance Attribute Summary collapse
-
#periods ⇒ Integer?
Number of periods with throttling active.
-
#throttled_periods ⇒ Integer?
Number of periods when the container hit its throttling limit.
-
#throttled_time ⇒ Integer?
Aggregated time (in nanoseconds) the container was throttled for.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#periods ⇒ Integer?
Number of periods with throttling active.
617 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 617 optional :periods, Integer |
#throttled_periods ⇒ Integer?
Number of periods when the container hit its throttling limit.
623 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 623 optional :throttled_periods, Integer |
#throttled_time ⇒ Integer?
Aggregated time (in nanoseconds) the container was throttled for.
629 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 629 optional :throttled_time, Integer |