Class: DockerEngineRuby::Models::StatsResponse::PrecpuStats::CPUUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::StatsResponse::PrecpuStats::CPUUsage
- Defined in:
- lib/docker_engine_ruby/models/stats_response.rb,
sig/docker_engine_ruby/models/stats_response.rbs
Overview
Instance Attribute Summary collapse
-
#percpu_usage ⇒ Array<Integer>?
Total CPU time (in nanoseconds) consumed per core (Linux).
-
#total_usage ⇒ Integer?
Total CPU time consumed in nanoseconds (Linux) or 100's of nanoseconds (Windows).
-
#usage_in_kernelmode ⇒ Integer?
Time (in nanoseconds) spent by tasks of the cgroup in kernel mode (Linux), or time spent (in 100's of nanoseconds) by all container processes in kernel mode (Windows).
-
#usage_in_usermode ⇒ Integer?
Time (in nanoseconds) spent by tasks of the cgroup in user mode (Linux), or time spent (in 100's of nanoseconds) by all container processes in kernel mode (Windows).
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
762 |
# File 'sig/docker_engine_ruby/models/stats_response.rbs', line 762
def initialize: (
|
Instance Attribute Details
#percpu_usage ⇒ Array<Integer>?
Total CPU time (in nanoseconds) consumed per core (Linux).
This field is Linux-specific when using cgroups v1. It is omitted when using cgroups v2 and Windows containers.
917 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 917 optional :percpu_usage, DockerEngineRuby::Internal::Type::ArrayOf[Integer], nil?: true |
#total_usage ⇒ Integer?
Total CPU time consumed in nanoseconds (Linux) or 100's of nanoseconds (Windows).
924 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 924 optional :total_usage, Integer |
#usage_in_kernelmode ⇒ Integer?
Time (in nanoseconds) spent by tasks of the cgroup in kernel mode (Linux), or time spent (in 100's of nanoseconds) by all container processes in kernel mode (Windows).
Not populated for Windows containers using Hyper-V isolation.
934 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 934 optional :usage_in_kernelmode, Integer |
#usage_in_usermode ⇒ Integer?
Time (in nanoseconds) spent by tasks of the cgroup in user mode (Linux), or time spent (in 100's of nanoseconds) by all container processes in kernel mode (Windows).
Not populated for Windows containers using Hyper-V isolation.
944 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 944 optional :usage_in_usermode, Integer |
Instance Method Details
#to_hash ⇒ {
769 |
# File 'sig/docker_engine_ruby/models/stats_response.rbs', line 769
def to_hash: -> {
|