Class: DockerEngineRuby::Models::StatsResponse::PrecpuStats::ThrottlingData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::StatsResponse::PrecpuStats::ThrottlingData
- Defined in:
- lib/docker_engine_ruby/models/stats_response.rb,
sig/docker_engine_ruby/models/stats_response.rbs
Overview
Instance Attribute Summary collapse
-
#periods ⇒ Integer?
Number of periods with throttling active.
-
#throttled_periods ⇒ Integer?
Number of periods when the container hit its throttling limit.
-
#throttled_time ⇒ Integer?
Aggregated time (in nanoseconds) the container was throttled for.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
797 |
# File 'sig/docker_engine_ruby/models/stats_response.rbs', line 797 def initialize: ( |
Instance Attribute Details
#periods ⇒ Integer?
Number of periods with throttling active.
968 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 968 optional :periods, Integer |
#throttled_periods ⇒ Integer?
Number of periods when the container hit its throttling limit.
974 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 974 optional :throttled_periods, Integer |
#throttled_time ⇒ Integer?
Aggregated time (in nanoseconds) the container was throttled for.
980 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 980 optional :throttled_time, Integer |
Instance Method Details
#to_hash ⇒ {
803 |
# File 'sig/docker_engine_ruby/models/stats_response.rbs', line 803 def to_hash: -> { |