Class: DockerEngineRuby::Models::Summary::ImageManifestDescriptor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary::ImageManifestDescriptor
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Overview
Defined Under Namespace
Classes: Platform
Instance Attribute Summary collapse
-
#annotations ⇒ Hash{Symbol=>String}?
Arbitrary metadata relating to the targeted content.
-
#artifact_type ⇒ String?
ArtifactType is the IANA media type of this artifact.
-
#data ⇒ String?
Data is an embedding of the targeted content.
-
#digest ⇒ String?
The digest of the targeted content.
-
#media_type ⇒ String?
The media type of the object this schema refers to.
-
#platform ⇒ DockerEngineRuby::Models::Summary::ImageManifestDescriptor::Platform?
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
-
#size ⇒ Integer?
The size in bytes of the blob.
-
#urls ⇒ Array<String>?
List of URLs from which this object MAY be downloaded.
Instance Method Summary collapse
-
#initialize(annotations: nil, artifact_type: nil, data: nil, digest: nil, media_type: nil, platform: nil, size: nil, urls: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageManifestDescriptor for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(annotations: nil, artifact_type: nil, data: nil, digest: nil, media_type: nil, platform: nil, size: nil, urls: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Summary::ImageManifestDescriptor for more details.
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
|
|
# File 'lib/docker_engine_ruby/models/summary.rb', line 302
|
Instance Attribute Details
#annotations ⇒ Hash{Symbol=>String}?
Arbitrary metadata relating to the targeted content.
254 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 254 optional :annotations, DockerEngineRuby::Internal::Type::HashOf[String], nil?: true |
#artifact_type ⇒ String?
ArtifactType is the IANA media type of this artifact.
260 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 260 optional :artifact_type, String, api_name: :artifactType, nil?: true |
#data ⇒ String?
Data is an embedding of the targeted content. This is encoded as a base64 string when marshalled to JSON (automatically, by encoding/json). If present, Data can be used directly to avoid fetching the targeted content.
268 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 268 optional :data, String, nil?: true |
#digest ⇒ String?
The digest of the targeted content.
274 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 274 optional :digest, String |
#media_type ⇒ String?
The media type of the object this schema refers to.
280 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 280 optional :media_type, String, api_name: :mediaType |
#platform ⇒ DockerEngineRuby::Models::Summary::ImageManifestDescriptor::Platform?
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
288 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 288 optional :platform, -> { DockerEngineRuby::Summary::ImageManifestDescriptor::Platform } |
#size ⇒ Integer?
The size in bytes of the blob.
294 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 294 optional :size, Integer |
#urls ⇒ Array<String>?
List of URLs from which this object MAY be downloaded.
300 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 300 optional :urls, DockerEngineRuby::Internal::Type::ArrayOf[String], nil?: true |