Class: DockerEngineRuby::Models::Summary::ImageManifestDescriptor::Platform
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary::ImageManifestDescriptor::Platform
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Overview
Instance Attribute Summary collapse
-
#architecture ⇒ String?
The CPU architecture, for example ‘amd64` or `ppc64`.
-
#os ⇒ String?
The operating system, for example ‘linux` or `windows`.
-
#os_features ⇒ Array<String>?
Optional field specifying an array of strings, each listing a required OS feature (for example on Windows ‘win32k`).
-
#os_version ⇒ String?
Optional field specifying the operating system version, for example on Windows ‘10.0.19041.1165`.
-
#variant ⇒ String?
Optional field specifying a variant of the CPU, for example ‘v7` to specify ARMv7 when architecture is `arm`.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#architecture ⇒ String?
The CPU architecture, for example ‘amd64` or `ppc64`.
331 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 331 optional :architecture, String |
#os ⇒ String?
The operating system, for example ‘linux` or `windows`.
337 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 337 optional :os, String |
#os_features ⇒ Array<String>?
Optional field specifying an array of strings, each listing a required OS feature (for example on Windows ‘win32k`).
344 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 344 optional :os_features, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :"os.features" |
#os_version ⇒ String?
Optional field specifying the operating system version, for example on Windows ‘10.0.19041.1165`.
351 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 351 optional :os_version, String, api_name: :"os.version" |
#variant ⇒ String?
Optional field specifying a variant of the CPU, for example ‘v7` to specify ARMv7 when architecture is `arm`.
358 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 358 optional :variant, String |