Class: DockerEngineRuby::Models::Summary::Mount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary::Mount
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#destination ⇒ String?
Destination is the path relative to the container root (
/) where theSourceis mounted inside the container. -
#driver ⇒ String?
Driver is the volume driver used to create the volume (if it is a volume).
-
#mode ⇒ String?
Mode is a comma separated list of options supplied by the user when creating the bind/volume mount.
-
#name ⇒ String?
Name is the name reference to the underlying data defined by
Sourcee.g., the volume name. -
#propagation ⇒ String?
Propagation describes how mounts are propagated from the host into the mount point, and vice-versa.
-
#rw ⇒ Boolean?
Whether the mount is mounted writable (read-write).
-
#source ⇒ String?
Source location of the mount.
-
#type ⇒ Symbol, ...
The mount type.
Instance Method Summary collapse
-
#initialize(destination: nil, driver: nil, mode: nil, name: nil, propagation: nil, rw: nil, source: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Mount for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(destination: nil, driver: nil, mode: nil, name: nil, propagation: nil, rw: nil, source: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Summary::Mount for more details.
MountPoint represents a mount point configuration inside the container. This is used for reporting the mountpoints in use by a container.
|
|
# File 'lib/docker_engine_ruby/models/summary.rb', line 450
|
Instance Attribute Details
#destination ⇒ String?
Destination is the path relative to the container root (/) where the Source is mounted inside the container.
387 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 387 optional :destination, String, api_name: :Destination |
#driver ⇒ String?
Driver is the volume driver used to create the volume (if it is a volume).
393 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 393 optional :driver, String, api_name: :Driver |
#mode ⇒ String?
Mode is a comma separated list of options supplied by the user when creating the bind/volume mount.
The default is platform-specific (‘“z”` on Linux, empty on Windows).
402 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 402 optional :mode, String, api_name: :Mode |
#name ⇒ String?
Name is the name reference to the underlying data defined by Source e.g., the volume name.
409 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 409 optional :name, String, api_name: :Name |
#propagation ⇒ String?
Propagation describes how mounts are propagated from the host into the mount point, and vice-versa. Refer to the [Linux kernel documentation](www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt) for details. This field is not used on Windows.
418 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 418 optional :propagation, String, api_name: :Propagation |
#rw ⇒ Boolean?
Whether the mount is mounted writable (read-write).
424 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 424 optional :rw, DockerEngineRuby::Internal::Type::Boolean, api_name: :RW |
#source ⇒ String?
Source location of the mount.
For volumes, this contains the storage location of the volume (within /var/lib/docker/volumes/). For bind-mounts, and npipe, this contains the source (host) part of the bind-mount. For tmpfs mount points, this field is empty.
435 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 435 optional :source, String, api_name: :Source |
#type ⇒ Symbol, ...
The mount type. Available types:
-
binda mount of a file or directory from the host into the container. -
clustera Swarm cluster volume. -
imagean OCI image. -
npipea named pipe from the host into the container. -
tmpfsatmpfs. -
volumea docker volume with the givenName.
448 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 448 optional :type, enum: -> { DockerEngineRuby::Summary::Mount::Type }, api_name: :Type |