Class: DockerEngineRuby::Models::SwarmAPI

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/swarm.rb

Overview

Defined Under Namespace

Classes: JoinTokens, TlsInfo, Version

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cert_issuer_public_key: nil, cert_issuer_subject: nil, trust_root: nil) ⇒ Object

Some parameter documentations has been truncated, see TlsInfo for more details.

Information about the issuer of leaf TLS certificates and the trusted root CA certificate.

Parameters:

  • cert_issuer_public_key (String) (defaults to: nil)

    The base64-url-safe-encoded raw public key bytes of the issuer.

  • cert_issuer_subject (String) (defaults to: nil)

    The base64-url-safe-encoded raw subject bytes of the issuer.

  • trust_root (String) (defaults to: nil)

    The root CA certificate(s) that are used to validate leaf TLS



# File 'lib/docker_engine_ruby/models/swarm.rb', line 91


Instance Attribute Details

#created_atTime?

Date and time at which the swarm was initialised in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (Time, nil)


12
# File 'lib/docker_engine_ruby/models/swarm.rb', line 12

optional :created_at, Time, api_name: :CreatedAt

#data_path_portInteger?

DataPathPort specifies the data path port number for data traffic. Acceptable port range is 1024 to 49151. If no port is set or is set to 0, the default port (4789) is used.

Returns:

  • (Integer, nil)


20
# File 'lib/docker_engine_ruby/models/swarm.rb', line 20

optional :data_path_port, Integer, api_name: :DataPathPort

#default_addr_poolArray<String>?

Default Address Pool specifies default subnet pools for global scope networks.

Returns:

  • (Array<String>, nil)


26
27
28
# File 'lib/docker_engine_ruby/models/swarm.rb', line 26

optional :default_addr_pool,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :DefaultAddrPool

#idString?

The ID of the swarm.

Returns:

  • (String, nil)


34
# File 'lib/docker_engine_ruby/models/swarm.rb', line 34

optional :id, String, api_name: :ID

#join_tokensDockerEngineRuby::Models::SwarmAPI::JoinTokens?

JoinTokens contains the tokens workers and managers need to join the swarm.



40
# File 'lib/docker_engine_ruby/models/swarm.rb', line 40

optional :join_tokens, -> { DockerEngineRuby::SwarmAPI::JoinTokens }, api_name: :JoinTokens

#root_rotation_in_progressBoolean?

Whether there is currently a root CA rotation in progress for the swarm

Returns:

  • (Boolean, nil)


46
47
48
# File 'lib/docker_engine_ruby/models/swarm.rb', line 46

optional :root_rotation_in_progress,
DockerEngineRuby::Internal::Type::Boolean,
api_name: :RootRotationInProgress

#specDockerEngineRuby::Models::SwarmSpec?

User modifiable swarm configuration.



54
# File 'lib/docker_engine_ruby/models/swarm.rb', line 54

optional :spec, -> { DockerEngineRuby::SwarmSpec }, api_name: :Spec

#subnet_sizeInteger?

SubnetSize specifies the subnet size of the networks created from the default subnet pool.

Returns:

  • (Integer, nil)


61
# File 'lib/docker_engine_ruby/models/swarm.rb', line 61

optional :subnet_size, Integer, api_name: :SubnetSize

#tls_infoDockerEngineRuby::Models::SwarmAPI::TlsInfo?

Information about the issuer of leaf TLS certificates and the trusted root CA certificate.



68
# File 'lib/docker_engine_ruby/models/swarm.rb', line 68

optional :tls_info, -> { DockerEngineRuby::SwarmAPI::TlsInfo }, api_name: :TLSInfo

#updated_atTime?

Date and time at which the swarm was last updated in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (Time, nil)


75
# File 'lib/docker_engine_ruby/models/swarm.rb', line 75

optional :updated_at, Time, api_name: :UpdatedAt

#versionDockerEngineRuby::Models::SwarmAPI::Version?

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.



89
# File 'lib/docker_engine_ruby/models/swarm.rb', line 89

optional :version, -> { DockerEngineRuby::SwarmAPI::Version }, api_name: :Version