Class: DockerEngineRuby::Models::SwarmAPI::JoinTokens

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/swarm.rb,
sig/docker_engine_ruby/models/swarm.rbs

Overview

See Also:

  • DockerEngineRuby::Models::SwarmAPI#join_tokens

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ JoinTokens

Returns a new instance of JoinTokens.

Parameters:

  • manager: (String)
  • worker: (String)


108
# File 'sig/docker_engine_ruby/models/swarm.rbs', line 108

def initialize: (?manager: String, ?worker: String) -> void

Instance Attribute Details

#manager ⇒ String?

The token managers can use to join the swarm.

Parameters:

  • (String)

Returns:

  • (String, nil)


123
# File 'lib/docker_engine_ruby/models/swarm.rb', line 123

optional :manager, String, api_name: :Manager

#worker ⇒ String?

The token workers can use to join the swarm.

Parameters:

  • (String)

Returns:

  • (String, nil)


129
# File 'lib/docker_engine_ruby/models/swarm.rb', line 129

optional :worker, String, api_name: :Worker

Instance Method Details

#to_hash ⇒ { manager: String, worker: String }

Returns:

  • ({ manager: String, worker: String })


110
# File 'sig/docker_engine_ruby/models/swarm.rbs', line 110

def to_hash: -> { manager: String, worker: String }