Class: DockerEngineRuby::Models::SystemDataUsageResponse::ContainersDiskUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::SystemDataUsageResponse::ContainersDiskUsage
- Defined in:
- lib/docker_engine_ruby/models/system_data_usage_response.rb
Overview
Instance Attribute Summary collapse
-
#active_count ⇒ Integer?
Count of active containers.
-
#items ⇒ Array<Object>?
List of container summaries.
-
#reclaimable ⇒ Integer?
Disk space that can be reclaimed by removing inactive containers.
-
#total_count ⇒ Integer?
Count of all containers.
-
#total_size ⇒ Integer?
Disk space in use by containers.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#active_count ⇒ Integer?
Count of active containers.
102 |
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 102 optional :active_count, Integer, api_name: :ActiveCount |
#items ⇒ Array<Object>?
List of container summaries.
108 109 110 |
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 108 optional :items, DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::Unknown], api_name: :Items |
#reclaimable ⇒ Integer?
Disk space that can be reclaimed by removing inactive containers.
116 |
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 116 optional :reclaimable, Integer, api_name: :Reclaimable |
#total_count ⇒ Integer?
Count of all containers.
122 |
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 122 optional :total_count, Integer, api_name: :TotalCount |
#total_size ⇒ Integer?
Disk space in use by containers.
128 |
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 128 optional :total_size, Integer, api_name: :TotalSize |