Class: DockerEngineRuby::Models::SystemDataUsageResponse::VolumesDiskUsage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/system_data_usage_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active_count: nil, items: nil, reclaimable: nil, total_count: nil, total_size: nil) ⇒ Object

represents system data usage for volume resources.

Parameters:

  • active_count (Integer) (defaults to: nil)

    Count of active volumes.

  • items (Array<Object>) (defaults to: nil)

    List of volumes.

  • reclaimable (Integer) (defaults to: nil)

    Disk space that can be reclaimed by removing inactive volumes.

  • total_count (Integer) (defaults to: nil)

    Count of all volumes.

  • total_size (Integer) (defaults to: nil)

    Disk space in use by volumes.



# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 226


Instance Attribute Details

#active_countInteger?

Count of active volumes.

Returns:

  • (Integer, nil)


198
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 198

optional :active_count, Integer, api_name: :ActiveCount

#itemsArray<Object>?

List of volumes.

Returns:

  • (Array<Object>, nil)


204
205
206
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 204

optional :items,
DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::Unknown],
api_name: :Items

#reclaimableInteger?

Disk space that can be reclaimed by removing inactive volumes.

Returns:

  • (Integer, nil)


212
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 212

optional :reclaimable, Integer, api_name: :Reclaimable

#total_countInteger?

Count of all volumes.

Returns:

  • (Integer, nil)


218
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 218

optional :total_count, Integer, api_name: :TotalCount

#total_sizeInteger?

Disk space in use by volumes.

Returns:

  • (Integer, nil)


224
# File 'lib/docker_engine_ruby/models/system_data_usage_response.rb', line 224

optional :total_size, Integer, api_name: :TotalSize