Class: DockerEngineRuby::Models::SystemEventsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/system_events_response.rb,
sig/docker_engine_ruby/models/system_events_response.rbs

Overview

See Also:

  • DockerEngineRuby::Resources::System#events

Defined Under Namespace

Modules: Scope, Type Classes: Actor

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attributes: nil, id: nil) ⇒ Object

Actor describes something that generates events, like a container, network, or a volume.

Parameters:

  • attributes (Hash{Symbol=>String}) (defaults to: nil) —

    Various key/value attributes of the object, depending on its type.

  • id (String) (defaults to: nil) —

    The ID of the object emitting the event



# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 45

Instance Attribute Details

#action ⇒ String?

The type of event

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 11

optional :action, String, api_name: :Action

#actor ⇒ DockerEngineRuby::Models::SystemEventsResponse::Actor?

Actor describes something that generates events, like a container, network, or a volume.



18
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 18

optional :actor, -> { DockerEngineRuby::Models::SystemEventsResponse::Actor }, api_name: :Actor

#scope ⇒ Symbol, ...

Scope of the event. Engine events are local scope. Cluster (Swarm) events are swarm scope.



25
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 25

optional :scope, enum: -> { DockerEngineRuby::Models::SystemEventsResponse::Scope }

#time ⇒ Integer?

Timestamp of event

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


31
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 31

optional :time, Integer

#time_nano ⇒ Integer?

Timestamp of event, with nanosecond accuracy

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


37
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 37

optional :time_nano, Integer, api_name: :timeNano

#type ⇒ Symbol, ...

The type of object emitting the event



43
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 43

optional :type, enum: -> { DockerEngineRuby::Models::SystemEventsResponse::Type }, api_name: :Type

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 96

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


53
# File 'sig/docker_engine_ruby/models/system_events_response.rbs', line 53

def to_hash: -> {