Class: DockerEngineRuby::Models::SystemEventsResponse::Actor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::SystemEventsResponse::Actor
- Defined in:
- lib/docker_engine_ruby/models/system_events_response.rb
Overview
Instance Attribute Summary collapse
-
#attributes ⇒ Hash{Symbol=>String}?
Various key/value attributes of the object, depending on its type.
-
#id ⇒ String?
The ID of the object emitting the event.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#attributes ⇒ Hash{Symbol=>String}?
Various key/value attributes of the object, depending on its type.
69 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 69 optional :attributes, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Attributes |
#id ⇒ String?
The ID of the object emitting the event
75 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 75 optional :id, String, api_name: :ID |