Class: DockerEngineRuby::Models::Task::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Task::Status
- Defined in:
- lib/docker_engine_ruby/models/task.rb
Overview
Defined Under Namespace
Modules: State Classes: ContainerStatus, PortStatus
Instance Attribute Summary collapse
-
#container_status ⇒ DockerEngineRuby::Models::Task::Status::ContainerStatus?
represents the status of a container.
- #err ⇒ String?
- #message ⇒ String?
-
#port_status ⇒ DockerEngineRuby::Models::Task::Status::PortStatus?
represents the port status of a task’s host ports whose service has published host ports.
- #state ⇒ Symbol, ...
- #timestamp ⇒ Time?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(container_id: nil, exit_code: nil, pid: nil) ⇒ Object
constructor
represents the status of a container.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(container_id: nil, exit_code: nil, pid: nil) ⇒ Object
represents the status of a container.
|
|
# File 'lib/docker_engine_ruby/models/task.rb', line 274
|
Instance Attribute Details
#container_status ⇒ DockerEngineRuby::Models::Task::Status::ContainerStatus?
represents the status of a container.
243 244 245 |
# File 'lib/docker_engine_ruby/models/task.rb', line 243 optional :container_status, -> { DockerEngineRuby::Task::Status::ContainerStatus }, api_name: :ContainerStatus |
#err ⇒ String?
250 |
# File 'lib/docker_engine_ruby/models/task.rb', line 250 optional :err, String, api_name: :Err |
#message ⇒ String?
255 |
# File 'lib/docker_engine_ruby/models/task.rb', line 255 optional :message, String, api_name: :Message |
#port_status ⇒ DockerEngineRuby::Models::Task::Status::PortStatus?
represents the port status of a task’s host ports whose service has published host ports
262 |
# File 'lib/docker_engine_ruby/models/task.rb', line 262 optional :port_status, -> { DockerEngineRuby::Task::Status::PortStatus }, api_name: :PortStatus |
#state ⇒ Symbol, ...
267 |
# File 'lib/docker_engine_ruby/models/task.rb', line 267 optional :state, enum: -> { DockerEngineRuby::Task::Status::State }, api_name: :State |
#timestamp ⇒ Time?
272 |
# File 'lib/docker_engine_ruby/models/task.rb', line 272 optional :timestamp, Time, api_name: :Timestamp |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/task.rb', line 416
|