Class: DockerEngineRuby::Models::TaskSpec::ContainerSpec::Mount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/task_spec.rb

Defined Under Namespace

Modules: Type Classes: BindOptions, ImageOptions, TmpfsOptions, VolumeOptions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mode: nil, options: nil, size_bytes: nil) ⇒ Object

Optional configuration for the tmpfs type.

Parameters:

  • mode (Integer) (defaults to: nil)
  • options (Array<Array<String>>) (defaults to: nil)
  • size_bytes (Integer) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/task_spec.rb', line 612


Instance Attribute Details

#bind_optionsDockerEngineRuby::Models::TaskSpec::ContainerSpec::Mount::BindOptions?

Optional configuration for the bind type.



541
542
543
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 541

optional :bind_options,
-> { DockerEngineRuby::TaskSpec::ContainerSpec::Mount::BindOptions },
api_name: :BindOptions

#consistencyString?

The consistency requirement for the mount: default, consistent, cached, or delegated.

Returns:

  • (String, nil)


550
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 550

optional :consistency, String, api_name: :Consistency

#image_optionsDockerEngineRuby::Models::TaskSpec::ContainerSpec::Mount::ImageOptions?

Optional configuration for the image type.



556
557
558
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 556

optional :image_options,
-> { DockerEngineRuby::TaskSpec::ContainerSpec::Mount::ImageOptions },
api_name: :ImageOptions

#read_onlyBoolean?

Whether the mount should be read-only.

Returns:

  • (Boolean, nil)


564
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 564

optional :read_only, DockerEngineRuby::Internal::Type::Boolean, api_name: :ReadOnly

#sourceString?

Mount source (e.g. a volume name, a host path). The source cannot be specified when using ‘Type=tmpfs`. For `Type=bind`, the source path must either exist, or the CreateMountpoint must be set to true to create the source path on the host if missing.

For ‘Type=npipe`, the pipe must exist prior to creating the container.

Returns:

  • (String, nil)


575
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 575

optional :source, String, api_name: :Source

#targetString?

Container path.

Returns:

  • (String, nil)


581
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 581

optional :target, String, api_name: :Target

#tmpfs_optionsDockerEngineRuby::Models::TaskSpec::ContainerSpec::Mount::TmpfsOptions?

Optional configuration for the tmpfs type.



587
588
589
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 587

optional :tmpfs_options,
-> { DockerEngineRuby::TaskSpec::ContainerSpec::Mount::TmpfsOptions },
api_name: :TmpfsOptions

#typeSymbol, ...

The mount type. Available types:

  • bind a mount of a file or directory from the host into the container.

  • cluster a Swarm cluster volume.

  • image an OCI image.

  • npipe a named pipe from the host into the container.

  • tmpfs a tmpfs.

  • volume a docker volume with the given Name.



602
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 602

optional :type, enum: -> { DockerEngineRuby::TaskSpec::ContainerSpec::Mount::Type }, api_name: :Type

#volume_optionsDockerEngineRuby::Models::TaskSpec::ContainerSpec::Mount::VolumeOptions?

Optional configuration for the volume type.



608
609
610
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 608

optional :volume_options,
-> { DockerEngineRuby::TaskSpec::ContainerSpec::Mount::VolumeOptions },
api_name: :VolumeOptions

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/task_spec.rb', line 689