Class: DockerEngineRuby::Models::TaskSpec::Network
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::TaskSpec::Network
- Defined in:
- lib/docker_engine_ruby/models/task_spec.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>?
Discoverable alternate names for the service on this network.
-
#driver_opts ⇒ Hash{Symbol=>String}?
Driver attachment options for the network target.
-
#target ⇒ String?
The target network for attachment.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#aliases ⇒ Array<String>?
Discoverable alternate names for the service on this network.
1084 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1084 optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases |
#driver_opts ⇒ Hash{Symbol=>String}?
Driver attachment options for the network target.
1090 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1090 optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts |
#target ⇒ String?
The target network for attachment. Must be a network name or ID.
1096 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1096 optional :target, String, api_name: :Target |