Class: DockerEngineRuby::Models::TaskSpec::RestartPolicy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::TaskSpec::RestartPolicy
- Defined in:
- lib/docker_engine_ruby/models/task_spec.rb
Overview
Defined Under Namespace
Modules: Condition
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(condition: nil, delay: nil, max_attempts: nil, window: nil) ⇒ Object
constructor
Specification for the restart policy which applies to containers created as part of this service.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(condition: nil, delay: nil, max_attempts: nil, window: nil) ⇒ Object
Specification for the restart policy which applies to containers created as part of this service.
|
|
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1416
|
Instance Attribute Details
#condition ⇒ Symbol, ...
1397 1398 1399 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1397 optional :condition, enum: -> { DockerEngineRuby::TaskSpec::RestartPolicy::Condition }, api_name: :Condition |
#delay ⇒ Integer?
1404 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1404 optional :delay, Integer, api_name: :Delay |
#max_attempts ⇒ Integer?
1409 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1409 optional :max_attempts, Integer, api_name: :MaxAttempts |
#window ⇒ Integer?
1414 |
# File 'lib/docker_engine_ruby/models/task_spec.rb', line 1414 optional :window, Integer, api_name: :Window |