Class: DockerEngineRuby::Models::TopResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/top_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(processes: nil, titles: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::TopResponse for more details.

Container “top” response.



# File 'lib/docker_engine_ruby/models/top_response.rb', line 22


Instance Attribute Details

#processesArray<Array<String>>?

Each process running in the container, where each process is an array of values corresponding to the titles.



12
13
14
# File 'lib/docker_engine_ruby/models/top_response.rb', line 12

optional :processes,
DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::ArrayOf[String]],
api_name: :Processes

#titlesArray<String>?

The ps column titles



20
# File 'lib/docker_engine_ruby/models/top_response.rb', line 20

optional :titles, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Titles