Class: DockerEngineRuby::Models::Version::Component

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/version.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_version: nil, arch: nil, build_time: nil, components: nil, experimental: nil, git_commit: nil, go_version: nil, kernel_version: nil, min_api_version: nil, os: nil, platform: nil, version: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Version for more details.

Response of Engine API: GET “/version”

Parameters:

  • api_version (String) (defaults to: nil)

    The default (and highest) API version that is supported by the daemon

  • arch (String) (defaults to: nil)

    Architecture of the daemon, as returned by the Go runtime (GOARCH).

  • build_time (String) (defaults to: nil)

    The date and time that the daemon was compiled.

  • components (Array<DockerEngineRuby::Models::Version::Component>) (defaults to: nil)

    Information about system components

  • experimental (Boolean) (defaults to: nil)

    Indicates if the daemon is started with experimental features enabled.

  • git_commit (String) (defaults to: nil)

    The Git commit of the source code that was used to build the daemon

  • go_version (String) (defaults to: nil)

    The version Go used to compile the daemon, and the version of the Go

  • kernel_version (String) (defaults to: nil)

    The kernel version (‘uname -r`) that the daemon is running on.

  • min_api_version (String) (defaults to: nil)

    The minimum API version that is supported by the daemon

  • os (String) (defaults to: nil)

    The operating system that the daemon is running on (“linux” or “windows”)

  • platform (DockerEngineRuby::Models::Version::Platform) (defaults to: nil)
  • version (String) (defaults to: nil)

    The version of the daemon



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/docker_engine_ruby/models/version.rb', line 118

class Component < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute name
  #
  #   @return [String]
  required :name, String, api_name: :Name

  # @!attribute version
  #
  #   @return [String]
  required :version, String, api_name: :Version

  # @!attribute details
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :details,
           DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown],
           api_name: :Details,
           nil?: true

  # @!method initialize(name:, version:, details: nil)
  #   @param name [String]
  #   @param version [String]
  #   @param details [Hash{Symbol=>Object}, nil]
end

Instance Attribute Details

#detailsHash{Symbol=>Object}?

Returns:

  • (Hash{Symbol=>Object}, nil)


132
133
134
135
# File 'lib/docker_engine_ruby/models/version.rb', line 132

optional :details,
DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown],
api_name: :Details,
nil?: true

#nameString

Returns:

  • (String)


122
# File 'lib/docker_engine_ruby/models/version.rb', line 122

required :name, String, api_name: :Name

#versionString

Returns:

  • (String)


127
# File 'lib/docker_engine_ruby/models/version.rb', line 127

required :version, String, api_name: :Version