Class: DockerEngineRuby::Models::Volume

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/volume.rb

Overview

Defined Under Namespace

Modules: Scope Classes: ClusterVolume, UsageData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index: nil) ⇒ Object

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.

Parameters:

  • index (Integer) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/volume.rb', line 76


Instance Attribute Details

#cluster_volumeDockerEngineRuby::Models::Volume::ClusterVolume?

Options and information specific to, and only present on, Swarm CSI cluster volumes.



49
# File 'lib/docker_engine_ruby/models/volume.rb', line 49

optional :cluster_volume, -> { DockerEngineRuby::Volume::ClusterVolume }, api_name: :ClusterVolume

#created_atTime?

Date/Time the volume was created.

Returns:

  • (Time, nil)


55
# File 'lib/docker_engine_ruby/models/volume.rb', line 55

optional :created_at, Time, api_name: :CreatedAt

#driverString

Name of the volume driver used by the volume.

Returns:

  • (String)


11
# File 'lib/docker_engine_ruby/models/volume.rb', line 11

required :driver, String, api_name: :Driver

#labelsHash{Symbol=>String}

User-defined key/value metadata.

Returns:

  • (Hash{Symbol=>String})


17
# File 'lib/docker_engine_ruby/models/volume.rb', line 17

required :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels

#mountpointString

Mount path of the volume on the host.

Returns:

  • (String)


23
# File 'lib/docker_engine_ruby/models/volume.rb', line 23

required :mountpoint, String, api_name: :Mountpoint

#nameString

Name of the volume.

Returns:

  • (String)


29
# File 'lib/docker_engine_ruby/models/volume.rb', line 29

required :name, String, api_name: :Name

#optionsHash{Symbol=>String}

The driver specific options used when creating the volume.

Returns:

  • (Hash{Symbol=>String})


35
# File 'lib/docker_engine_ruby/models/volume.rb', line 35

required :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options

#scopeSymbol, DockerEngineRuby::Models::Volume::Scope

The level at which the volume exists. Either global for cluster-wide, or local for machine level.



42
# File 'lib/docker_engine_ruby/models/volume.rb', line 42

required :scope, enum: -> { DockerEngineRuby::Volume::Scope }, api_name: :Scope

#statusHash{Symbol=>Hash{Symbol=>Object}}?

Low-level details about the volume, provided by the volume driver. Details are returned as a map with key/value pairs: ‘“key”:“value”,“key2”:“value2”`.

The Status field is optional, and is omitted if the volume driver does not support this feature.

Returns:

  • (Hash{Symbol=>Hash{Symbol=>Object}}, nil)


65
66
67
# File 'lib/docker_engine_ruby/models/volume.rb', line 65

optional :status,
DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]],
api_name: :Status

#usage_dataDockerEngineRuby::Models::Volume::UsageData?

Usage details about the volume. This information is used by the ‘GET /system/df` endpoint, and omitted in other endpoints.



74
# File 'lib/docker_engine_ruby/models/volume.rb', line 74

optional :usage_data, -> { DockerEngineRuby::Volume::UsageData }, api_name: :UsageData, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_ruby/models/volume.rb', line 110