Class: DockerEngineRuby::Models::Volume::ClusterVolume::Spec

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/volume.rb

Overview

See Also:

Defined Under Namespace

Classes: AccessMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_mode: nil, group: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::Volume::ClusterVolume::Spec for more details.

Cluster-specific options used to create the volume.

Parameters:



# File 'lib/docker_engine_ruby/models/volume.rb', line 284

Instance Attribute Details

#access_modeDockerEngineRuby::Models::Volume::ClusterVolume::Spec::AccessMode?

Defines how the volume is used by tasks.



270
271
272
# File 'lib/docker_engine_ruby/models/volume.rb', line 270

optional :access_mode,
-> { DockerEngineRuby::Volume::ClusterVolume::Spec::AccessMode },
api_name: :AccessMode

#groupString?

Group defines the volume group of this volume. Volumes belonging to the same group can be referred to by group name when creating Services. Referring to a volume by group instructs Swarm to treat volumes in that group interchangeably for the purpose of scheduling. Volumes with an empty string for a group technically all belong to the same, emptystring group.

Returns:

  • (String, nil)


282
# File 'lib/docker_engine_ruby/models/volume.rb', line 282

optional :group, String, api_name: :Group