Class: DockerEngineRuby::Models::VolumeUpdateParams::Spec

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/volume_update_params.rb

Defined Under Namespace

Classes: AccessMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_mode: nil, group: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineRuby::Models::VolumeUpdateParams::Spec for more details.

Cluster-specific options used to create the volume.

Parameters:



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/docker_engine_ruby/models/volume_update_params.rb', line 28

class Spec < DockerEngineRuby::Internal::Type::BaseModel
  # @!attribute access_mode
  #   Defines how the volume is used by tasks.
  #
  #   @return [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode, nil]
  optional :access_mode,
           -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode },
           api_name: :AccessMode

  # @!attribute group
  #   Group defines the volume group of this volume. Volumes belonging to the same
  #   group can be referred to by group name when creating Services. Referring to a
  #   volume by group instructs Swarm to treat volumes in that group interchangeably
  #   for the purpose of scheduling. Volumes with an empty string for a group
  #   technically all belong to the same, emptystring group.
  #
  #   @return [String, nil]
  optional :group, String, api_name: :Group

  # @!method initialize(access_mode: nil, group: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineRuby::Models::VolumeUpdateParams::Spec} for more details.
  #
  #   Cluster-specific options used to create the volume.
  #
  #   @param access_mode [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode] Defines how the volume is used by tasks.
  #
  #   @param group [String] Group defines the volume group of this volume. Volumes belonging to

  # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec#access_mode
  class AccessMode < DockerEngineRuby::Internal::Type::BaseModel
    # @!attribute accessibility_requirements
    #
    #   @return [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::AccessibilityRequirements, nil]
    optional :accessibility_requirements,
             -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::AccessibilityRequirements },
             api_name: :AccessibilityRequirements

    # @!attribute availability
    #
    #   @return [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Availability, nil]
    optional :availability,
             enum: -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::Availability },
             api_name: :Availability

    # @!attribute capacity_range
    #
    #   @return [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::CapacityRange, nil]
    optional :capacity_range,
             -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::CapacityRange },
             api_name: :CapacityRange

    # @!attribute mount_volume
    #
    #   @return [Hash{Symbol=>Object}, nil]
    optional :mount_volume,
             DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown],
             api_name: :MountVolume

    # @!attribute scope
    #
    #   @return [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Scope, nil]
    optional :scope,
             enum: -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::Scope },
             api_name: :Scope

    # @!attribute secrets
    #
    #   @return [Array<DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Secret>, nil]
    optional :secrets,
             -> {
               DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::Secret]
             },
             api_name: :Secrets

    # @!attribute sharing
    #
    #   @return [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Sharing, nil]
    optional :sharing,
             enum: -> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode::Sharing },
             api_name: :Sharing

    # @!method initialize(accessibility_requirements: nil, availability: nil, capacity_range: nil, mount_volume: nil, scope: nil, secrets: nil, sharing: nil)
    #   Defines how the volume is used by tasks.
    #
    #   @param accessibility_requirements [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::AccessibilityRequirements]
    #   @param availability [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Availability]
    #   @param capacity_range [DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::CapacityRange]
    #   @param mount_volume [Hash{Symbol=>Object}]
    #   @param scope [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Scope]
    #   @param secrets [Array<DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Secret>]
    #   @param sharing [Symbol, DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode::Sharing]

    # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode#accessibility_requirements
    class AccessibilityRequirements < DockerEngineRuby::Internal::Type::BaseModel
      # @!attribute preferred
      #
      #   @return [Array<Hash{Symbol=>String}>, nil]
      optional :preferred,
               DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::HashOf[String]],
               api_name: :Preferred

      # @!attribute requisite
      #
      #   @return [Array<Hash{Symbol=>String}>, nil]
      optional :requisite,
               DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::HashOf[String]],
               api_name: :Requisite

      # @!method initialize(preferred: nil, requisite: nil)
      #   @param preferred [Array<Hash{Symbol=>String}>]
      #   @param requisite [Array<Hash{Symbol=>String}>]
    end

    # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode#availability
    module Availability
      extend DockerEngineRuby::Internal::Type::Enum

      ACTIVE = :active
      PAUSE = :pause
      DRAIN = :drain

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode#capacity_range
    class CapacityRange < DockerEngineRuby::Internal::Type::BaseModel
      # @!attribute limit_bytes
      #
      #   @return [Integer, nil]
      optional :limit_bytes, Integer, api_name: :LimitBytes

      # @!attribute required_bytes
      #
      #   @return [Integer, nil]
      optional :required_bytes, Integer, api_name: :RequiredBytes

      # @!method initialize(limit_bytes: nil, required_bytes: nil)
      #   @param limit_bytes [Integer]
      #   @param required_bytes [Integer]
    end

    # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode#scope
    module Scope
      extend DockerEngineRuby::Internal::Type::Enum

      SINGLE = :single
      MULTI = :multi

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    class Secret < DockerEngineRuby::Internal::Type::BaseModel
      # @!attribute key
      #
      #   @return [String, nil]
      optional :key, String, api_name: :Key

      # @!attribute secret
      #
      #   @return [String, nil]
      optional :secret, String, api_name: :Secret

      # @!method initialize(key: nil, secret: nil)
      #   @param key [String]
      #   @param secret [String]
    end

    # @see DockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode#sharing
    module Sharing
      extend DockerEngineRuby::Internal::Type::Enum

      NONE = :none
      READONLY = :readonly
      ONEWRITER = :onewriter
      ALL = :all

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end
end

Instance Attribute Details

#access_modeDockerEngineRuby::Models::VolumeUpdateParams::Spec::AccessMode?

Defines how the volume is used by tasks.



33
34
35
# File 'lib/docker_engine_ruby/models/volume_update_params.rb', line 33

optional :access_mode,
-> { DockerEngineRuby::VolumeUpdateParams::Spec::AccessMode },
api_name: :AccessMode

#groupString?

Group defines the volume group of this volume. Volumes belonging to the same group can be referred to by group name when creating Services. Referring to a volume by group instructs Swarm to treat volumes in that group interchangeably for the purpose of scheduling. Volumes with an empty string for a group technically all belong to the same, emptystring group.

Returns:

  • (String, nil)


45
# File 'lib/docker_engine_ruby/models/volume_update_params.rb', line 45

optional :group, String, api_name: :Group