Class: DockerEngineRuby::Models::Config::Healthcheck
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Config::Healthcheck
- Defined in:
- lib/docker_engine_ruby/models/config.rb
Overview
Instance Attribute Summary collapse
-
#interval ⇒ Integer?
The time to wait between checks in nanoseconds.
-
#retries ⇒ Integer?
The number of consecutive failures needed to consider a container as unhealthy.
-
#start_interval ⇒ Integer?
The time to wait between checks in nanoseconds during the start period.
-
#start_period ⇒ Integer?
Start period for the container to initialize before starting health-retries countdown in nanoseconds.
-
#test_ ⇒ Array<String>?
The test to perform.
-
#timeout ⇒ Integer?
The time to wait before considering the check to have hung.
Instance Method Summary collapse
-
#initialize(interval: nil, retries: nil, start_interval: nil, start_period: nil, test_: nil, timeout: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Healthcheck for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(interval: nil, retries: nil, start_interval: nil, start_period: nil, test_: nil, timeout: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Config::Healthcheck for more details.
A test to perform to check that the container is healthy. Healthcheck commands should be side-effect free.
|
|
# File 'lib/docker_engine_ruby/models/config.rb', line 286
|
Instance Attribute Details
#interval ⇒ Integer?
The time to wait between checks in nanoseconds. It should be 0 or at least 1000000 (1 ms). 0 means inherit.
233 |
# File 'lib/docker_engine_ruby/models/config.rb', line 233 optional :interval, Integer, api_name: :Interval |
#retries ⇒ Integer?
The number of consecutive failures needed to consider a container as unhealthy. 0 means inherit.
240 |
# File 'lib/docker_engine_ruby/models/config.rb', line 240 optional :retries, Integer, api_name: :Retries |
#start_interval ⇒ Integer?
The time to wait between checks in nanoseconds during the start period. It should be 0 or at least 1000000 (1 ms). 0 means inherit.
247 |
# File 'lib/docker_engine_ruby/models/config.rb', line 247 optional :start_interval, Integer, api_name: :StartInterval |
#start_period ⇒ Integer?
Start period for the container to initialize before starting health-retries countdown in nanoseconds. It should be 0 or at least 1000000 (1 ms). 0 means inherit.
255 |
# File 'lib/docker_engine_ruby/models/config.rb', line 255 optional :start_period, Integer, api_name: :StartPeriod |
#test_ ⇒ Array<String>?
The test to perform. Possible values are:
-
[]inherit healthcheck from image or parent image -
‘[“NONE”]` disable healthcheck
-
‘[“CMD”, args…]` exec arguments directly
-
‘[“CMD-SHELL”, command]` run command with system’s default shell
A non-zero exit code indicates a failed healthcheck:
-
0healthy -
1unhealthy -
2reserved (treated as unhealthy) -
other values: error running probe
273 |
# File 'lib/docker_engine_ruby/models/config.rb', line 273 optional :test_, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Test |
#timeout ⇒ Integer?
The time to wait before considering the check to have hung. It should be 0 or at least 1000000 (1 ms). 0 means inherit.
If the health check command does not complete within this timeout, the check is considered failed and the health check process is forcibly terminated without a graceful shutdown.
284 |
# File 'lib/docker_engine_ruby/models/config.rb', line 284 optional :timeout, Integer, api_name: :Timeout |