Class: DockerEngineRuby::Models::ConnectRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ConnectRequest
- Defined in:
- lib/docker_engine_ruby/models/connect_request.rb
Direct Known Subclasses
Defined Under Namespace
Classes: EndpointConfig
Instance Attribute Summary collapse
-
#container ⇒ String
The ID or name of the container to connect to the network.
-
#endpoint_config ⇒ DockerEngineRuby::Models::ConnectRequest::EndpointConfig?
Configuration for a network endpoint.
Instance Method Summary collapse
-
#initialize(container:, endpoint_config: nil) ⇒ Object
constructor
NetworkConnectRequest represents the data to be used to connect a container to a network.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(container:, endpoint_config: nil) ⇒ Object
NetworkConnectRequest represents the data to be used to connect a container to a network.
|
|
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 21
|
Instance Attribute Details
#container ⇒ String
The ID or name of the container to connect to the network.
10 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 10 required :container, String, api_name: :Container |
#endpoint_config ⇒ DockerEngineRuby::Models::ConnectRequest::EndpointConfig?
Configuration for a network endpoint.
16 17 18 19 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 16 optional :endpoint_config, -> { DockerEngineRuby::ConnectRequest::EndpointConfig }, api_name: :EndpointConfig, nil?: true |