Class: DockerEngineRuby::Models::ConnectRequest::EndpointConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ConnectRequest::EndpointConfig
- Defined in:
- lib/docker_engine_ruby/models/connect_request.rb
Overview
Defined Under Namespace
Classes: IpamConfig
Instance Attribute Summary collapse
- #aliases ⇒ Array<String>?
-
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network.
-
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values.
-
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
-
#gateway ⇒ String?
Gateway address for this network.
-
#global_i_pv6_address ⇒ String?
Global IPv6 address.
-
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
-
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container.
-
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
-
#ip_address ⇒ String?
IPv4 address.
-
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
-
#ipam_config ⇒ DockerEngineRuby::Models::ConnectRequest::EndpointConfig::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
- #links ⇒ Array<String>?
-
#mac_address ⇒ String?
MAC address for the endpoint on this network.
-
#network_id ⇒ String?
Unique ID of the network.
Instance Method Summary collapse
-
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EndpointConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::ConnectRequest::EndpointConfig for more details.
Configuration for a network endpoint.
|
|
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 135
|
Instance Attribute Details
#aliases ⇒ Array<String>?
34 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 34 optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases |
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.
These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending ‘.<network-name>`. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.
46 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 46 optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames |
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.
53 54 55 56 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 53 optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true |
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
62 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 62 optional :endpoint_id, String, api_name: :EndpointID |
#gateway ⇒ String?
Gateway address for this network.
68 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 68 optional :gateway, String, api_name: :Gateway |
#global_i_pv6_address ⇒ String?
Global IPv6 address.
74 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 74 optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address |
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
80 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 80 optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen |
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.
89 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 89 optional :gw_priority, Integer, api_name: :GwPriority |
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
115 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 115 optional :i_pv6_gateway, String, api_name: :IPv6Gateway |
#ip_address ⇒ String?
IPv4 address.
95 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 95 optional :ip_address, String, api_name: :IPAddress |
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
109 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 109 optional :ip_prefix_len, Integer, api_name: :IPPrefixLen |
#ipam_config ⇒ DockerEngineRuby::Models::ConnectRequest::EndpointConfig::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
101 102 103 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 101 optional :ipam_config, -> { DockerEngineRuby::ConnectRequest::EndpointConfig::IpamConfig }, api_name: :IPAMConfig |
#links ⇒ Array<String>?
120 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 120 optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links |
#mac_address ⇒ String?
MAC address for the endpoint on this network. The network driver might ignore this parameter.
127 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 127 optional :mac_address, String, api_name: :MacAddress |
#network_id ⇒ String?
Unique ID of the network.
133 |
# File 'lib/docker_engine_ruby/models/connect_request.rb', line 133 optional :network_id, String, api_name: :NetworkID |