Class: DockerEngineRuby::Models::Container
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Container
- Defined in:
- lib/docker_engine_ruby/models/container.rb
Overview
Defined Under Namespace
Classes: GraphDriver, HostConfig, ImageManifestDescriptor, Mount, NetworkSettings, State, Storage
Instance Attribute Summary collapse
-
#app_armor_profile ⇒ String?
The AppArmor profile set for the container.
-
#args ⇒ Array<String>?
The arguments to the command being run.
-
#config ⇒ DockerEngineRuby::Models::Config?
Configuration for a container that is portable between hosts.
-
#created ⇒ Time?
Date and time at which the container was created, formatted in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
-
#driver ⇒ String?
The storage-driver used for the container’s filesystem (graph-driver or snapshotter).
-
#exec_ids ⇒ Array<String>?
IDs of exec instances that are running in the container.
-
#graph_driver ⇒ DockerEngineRuby::Models::Container::GraphDriver?
Information about the storage driver used to store the container’s and image’s filesystem.
-
#host_config ⇒ DockerEngineRuby::Models::Container::HostConfig?
Container configuration that depends on the host we are running on.
-
#hostname_path ⇒ String?
Location of the
/etc/hostnamegenerated for the container on the host. -
#hosts_path ⇒ String?
Location of the
/etc/hostsgenerated for the container on the host. -
#id ⇒ String?
The ID of this container as a 128-bit (64-character) hexadecimal string (32 bytes).
-
#image ⇒ String?
The ID (digest) of the image that this container was created from.
-
#image_manifest_descriptor ⇒ DockerEngineRuby::Models::Container::ImageManifestDescriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
-
#log_path ⇒ String?
Location of the file used to buffer the container’s logs.
-
#mount_label ⇒ String?
SELinux mount label set for the container.
-
#mounts ⇒ Array<DockerEngineRuby::Models::Container::Mount>?
List of mounts used by the container.
-
#name ⇒ String?
The name associated with this container.
-
#network_settings ⇒ DockerEngineRuby::Models::Container::NetworkSettings?
NetworkSettings exposes the network settings in the API.
-
#path ⇒ String?
The path to the command being run.
-
#platform ⇒ String?
The platform (operating system) for which the container was created.
-
#process_label ⇒ String?
SELinux process label set for the container.
-
#resolv_conf_path ⇒ String?
Location of the
/etc/resolv.confgenerated for the container on the host. -
#restart_count ⇒ Integer?
Number of times the container was restarted since it was created, or since daemon was started.
-
#size_root_fs ⇒ Integer?
The total size of all files in the read-only layers from the image that the container uses.
-
#size_rw ⇒ Integer?
The size of files that have been created or changed by this container.
-
#state ⇒ DockerEngineRuby::Models::Container::State?
ContainerState stores container’s running state.
-
#storage ⇒ DockerEngineRuby::Models::Container::Storage?
Information about the storage used by the container.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(host_ip: nil, host_port: nil) ⇒ Object
constructor
PortBinding represents a binding between a host IP address and a host port.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(host_ip: nil, host_port: nil) ⇒ Object
PortBinding represents a binding between a host IP address and a host port.
|
|
# File 'lib/docker_engine_ruby/models/container.rb', line 211
|
Instance Attribute Details
#app_armor_profile ⇒ String?
The AppArmor profile set for the container.
11 |
# File 'lib/docker_engine_ruby/models/container.rb', line 11 optional :app_armor_profile, String, api_name: :AppArmorProfile |
#args ⇒ Array<String>?
The arguments to the command being run
17 |
# File 'lib/docker_engine_ruby/models/container.rb', line 17 optional :args, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Args |
#config ⇒ DockerEngineRuby::Models::Config?
Configuration for a container that is portable between hosts.
23 |
# File 'lib/docker_engine_ruby/models/container.rb', line 23 optional :config, -> { DockerEngineRuby::Config }, api_name: :Config |
#created ⇒ Time?
Date and time at which the container was created, formatted in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
30 |
# File 'lib/docker_engine_ruby/models/container.rb', line 30 optional :created, Time, api_name: :Created, nil?: true |
#driver ⇒ String?
The storage-driver used for the container’s filesystem (graph-driver or snapshotter).
37 |
# File 'lib/docker_engine_ruby/models/container.rb', line 37 optional :driver, String, api_name: :Driver |
#exec_ids ⇒ Array<String>?
IDs of exec instances that are running in the container.
43 |
# File 'lib/docker_engine_ruby/models/container.rb', line 43 optional :exec_ids, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :ExecIDs, nil?: true |
#graph_driver ⇒ DockerEngineRuby::Models::Container::GraphDriver?
Information about the storage driver used to store the container’s and image’s filesystem.
50 51 52 53 |
# File 'lib/docker_engine_ruby/models/container.rb', line 50 optional :graph_driver, -> { DockerEngineRuby::Container::GraphDriver }, api_name: :GraphDriver, nil?: true |
#host_config ⇒ DockerEngineRuby::Models::Container::HostConfig?
Container configuration that depends on the host we are running on
59 |
# File 'lib/docker_engine_ruby/models/container.rb', line 59 optional :host_config, -> { DockerEngineRuby::Container::HostConfig }, api_name: :HostConfig |
#hostname_path ⇒ String?
Location of the /etc/hostname generated for the container on the host.
This file is managed through the docker daemon, and should not be accessed or modified by other tools.
68 |
# File 'lib/docker_engine_ruby/models/container.rb', line 68 optional :hostname_path, String, api_name: :HostnamePath |
#hosts_path ⇒ String?
Location of the /etc/hosts generated for the container on the host.
This file is managed through the docker daemon, and should not be accessed or modified by other tools.
77 |
# File 'lib/docker_engine_ruby/models/container.rb', line 77 optional :hosts_path, String, api_name: :HostsPath |
#id ⇒ String?
The ID of this container as a 128-bit (64-character) hexadecimal string (32 bytes).
84 |
# File 'lib/docker_engine_ruby/models/container.rb', line 84 optional :id, String, api_name: :Id |
#image ⇒ String?
The ID (digest) of the image that this container was created from.
90 |
# File 'lib/docker_engine_ruby/models/container.rb', line 90 optional :image, String, api_name: :Image |
#image_manifest_descriptor ⇒ DockerEngineRuby::Models::Container::ImageManifestDescriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
97 98 99 |
# File 'lib/docker_engine_ruby/models/container.rb', line 97 optional :image_manifest_descriptor, -> { DockerEngineRuby::Container::ImageManifestDescriptor }, api_name: :ImageManifestDescriptor |
#log_path ⇒ String?
Location of the file used to buffer the container’s logs. Depending on the logging-driver used for the container, this field may be omitted.
This file is managed through the docker daemon, and should not be accessed or modified by other tools.
109 |
# File 'lib/docker_engine_ruby/models/container.rb', line 109 optional :log_path, String, api_name: :LogPath, nil?: true |
#mount_label ⇒ String?
SELinux mount label set for the container.
115 |
# File 'lib/docker_engine_ruby/models/container.rb', line 115 optional :mount_label, String, api_name: :MountLabel |
#mounts ⇒ Array<DockerEngineRuby::Models::Container::Mount>?
List of mounts used by the container.
121 122 123 |
# File 'lib/docker_engine_ruby/models/container.rb', line 121 optional :mounts, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Container::Mount] }, api_name: :Mounts |
#name ⇒ String?
The name associated with this container.
For historic reasons, the name may be prefixed with a forward-slash (/).
131 |
# File 'lib/docker_engine_ruby/models/container.rb', line 131 optional :name, String, api_name: :Name |
#network_settings ⇒ DockerEngineRuby::Models::Container::NetworkSettings?
NetworkSettings exposes the network settings in the API
137 138 139 |
# File 'lib/docker_engine_ruby/models/container.rb', line 137 optional :network_settings, -> { DockerEngineRuby::Container::NetworkSettings }, api_name: :NetworkSettings |
#path ⇒ String?
The path to the command being run
145 |
# File 'lib/docker_engine_ruby/models/container.rb', line 145 optional :path, String, api_name: :Path |
#platform ⇒ String?
The platform (operating system) for which the container was created.
This field was introduced for the experimental “LCOW” (Linux Containers On Windows) features, which has been removed. In most cases, this field is equal to the host’s operating system (linux or windows).
155 |
# File 'lib/docker_engine_ruby/models/container.rb', line 155 optional :platform, String, api_name: :Platform |
#process_label ⇒ String?
SELinux process label set for the container.
161 |
# File 'lib/docker_engine_ruby/models/container.rb', line 161 optional :process_label, String, api_name: :ProcessLabel |
#resolv_conf_path ⇒ String?
Location of the /etc/resolv.conf generated for the container on the host.
This file is managed through the docker daemon, and should not be accessed or modified by other tools.
170 |
# File 'lib/docker_engine_ruby/models/container.rb', line 170 optional :resolv_conf_path, String, api_name: :ResolvConfPath |
#restart_count ⇒ Integer?
Number of times the container was restarted since it was created, or since daemon was started.
177 |
# File 'lib/docker_engine_ruby/models/container.rb', line 177 optional :restart_count, Integer, api_name: :RestartCount |
#size_root_fs ⇒ Integer?
The total size of all files in the read-only layers from the image that the container uses. These layers can be shared between containers.
This field is omitted by default, and only set when size is requested in the API request.
187 |
# File 'lib/docker_engine_ruby/models/container.rb', line 187 optional :size_root_fs, Integer, api_name: :SizeRootFs, nil?: true |
#size_rw ⇒ Integer?
The size of files that have been created or changed by this container.
This field is omitted by default, and only set when size is requested in the API request.
196 |
# File 'lib/docker_engine_ruby/models/container.rb', line 196 optional :size_rw, Integer, api_name: :SizeRw, nil?: true |
#state ⇒ DockerEngineRuby::Models::Container::State?
ContainerState stores container’s running state. It’s part of ContainerJSONBase and will be returned by the “inspect” command.
203 |
# File 'lib/docker_engine_ruby/models/container.rb', line 203 optional :state, -> { DockerEngineRuby::Container::State }, api_name: :State |
#storage ⇒ DockerEngineRuby::Models::Container::Storage?
Information about the storage used by the container.
209 |
# File 'lib/docker_engine_ruby/models/container.rb', line 209 optional :storage, -> { DockerEngineRuby::Container::Storage }, api_name: :Storage, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/container.rb', line 1904
|