Module: DockerEngineRuby::Models::Container::HostConfig::RestartPolicy::Name

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/container.rb

Overview

  • Empty string means not to restart

  • no Do not automatically restart

  • always Always restart

  • unless-stopped Restart always except when the user has manually stopped the container

  • on-failure Restart only when the container exit code is non-zero

See Also:

Constant Summary collapse

EMPTY =
:""
NO =
:no
ALWAYS =
:always
UNLESS_STOPPED =
:"unless-stopped"
ON_FAILURE =
:"on-failure"

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info