Class: DockerEngineRuby::Models::Container::NetworkSettings::Network
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Container::NetworkSettings::Network
- Defined in:
- lib/docker_engine_ruby/models/container.rb
Defined Under Namespace
Classes: IpamConfig
Instance Attribute Summary collapse
- #aliases ⇒ Array<String>?
-
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network.
-
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values.
-
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
-
#gateway ⇒ String?
Gateway address for this network.
-
#global_i_pv6_address ⇒ String?
Global IPv6 address.
-
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
-
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container.
-
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
-
#ip_address ⇒ String?
IPv4 address.
-
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
-
#ipam_config ⇒ DockerEngineRuby::Models::Container::NetworkSettings::Network::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
- #links ⇒ Array<String>?
-
#mac_address ⇒ String?
MAC address for the endpoint on this network.
-
#network_id ⇒ String?
Unique ID of the network.
Instance Method Summary collapse
-
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Network for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Container::NetworkSettings::Network for more details.
Configuration for a network endpoint.
1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1953 class Network < DockerEngineRuby::Internal::Type::BaseModel # @!attribute aliases # # @return [Array<String>, nil] optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases # @!attribute dns_names # List of all DNS names an endpoint has on a specific network. This list is based # on the container name, network aliases, container short ID, and hostname. # # These DNS names are non-fully qualified but can contain several dots. You can # get fully qualified DNS names by appending `.<network-name>`. For instance, if # container name is `my.ctr` and the network is named `testnet`, `DNSNames` will # contain `my.ctr` and the FQDN will be `my.ctr.testnet`. # # @return [Array<String>, nil] optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames # @!attribute driver_opts # DriverOpts is a mapping of driver options and values. These options are passed # directly to the driver and are driver specific. # # @return [Hash{Symbol=>String}, nil] optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true # @!attribute endpoint_id # Unique ID for the service endpoint in a Sandbox. # # @return [String, nil] optional :endpoint_id, String, api_name: :EndpointID # @!attribute gateway # Gateway address for this network. # # @return [String, nil] optional :gateway, String, api_name: :Gateway # @!attribute global_i_pv6_address # Global IPv6 address. # # @return [String, nil] optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address # @!attribute global_i_pv6_prefix_len # Mask length of the global IPv6 address. # # @return [Integer, nil] optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen # @!attribute gw_priority # This property determines which endpoint will provide the default gateway for a # container. The endpoint with the highest priority will be used. If multiple # endpoints have the same priority, endpoints are lexicographically sorted based # on their network name, and the one that sorts first is picked. # # @return [Integer, nil] optional :gw_priority, Integer, api_name: :GwPriority # @!attribute ip_address # IPv4 address. # # @return [String, nil] optional :ip_address, String, api_name: :IPAddress # @!attribute ipam_config # EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @return [DockerEngineRuby::Models::Container::NetworkSettings::Network::IpamConfig, nil] optional :ipam_config, -> { DockerEngineRuby::Container::NetworkSettings::Network::IpamConfig }, api_name: :IPAMConfig # @!attribute ip_prefix_len # Mask length of the IPv4 address. # # @return [Integer, nil] optional :ip_prefix_len, Integer, api_name: :IPPrefixLen # @!attribute i_pv6_gateway # IPv6 gateway address. # # @return [String, nil] optional :i_pv6_gateway, String, api_name: :IPv6Gateway # @!attribute links # # @return [Array<String>, nil] optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links # @!attribute mac_address # MAC address for the endpoint on this network. The network driver might ignore # this parameter. # # @return [String, nil] optional :mac_address, String, api_name: :MacAddress # @!attribute network_id # Unique ID of the network. # # @return [String, nil] optional :network_id, String, api_name: :NetworkID # @!method initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) # Some parameter documentations has been truncated, see # {DockerEngineRuby::Models::Container::NetworkSettings::Network} for more # details. # # Configuration for a network endpoint. # # @param aliases [Array<String>] # # @param dns_names [Array<String>] List of all DNS names an endpoint has on a specific network. This # # @param driver_opts [Hash{Symbol=>String}, nil] DriverOpts is a mapping of driver options and values. These options # # @param endpoint_id [String] Unique ID for the service endpoint in a Sandbox. # # @param gateway [String] Gateway address for this network. # # @param global_i_pv6_address [String] Global IPv6 address. # # @param global_i_pv6_prefix_len [Integer] Mask length of the global IPv6 address. # # @param gw_priority [Integer] This property determines which endpoint will provide the default # # @param ip_address [String] IPv4 address. # # @param ipam_config [DockerEngineRuby::Models::Container::NetworkSettings::Network::IpamConfig] EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @param ip_prefix_len [Integer] Mask length of the IPv4 address. # # @param i_pv6_gateway [String] IPv6 gateway address. # # @param links [Array<String>] # # @param mac_address [String] MAC address for the endpoint on this network. The network driver might ignore th # # @param network_id [String] Unique ID of the network. # @see DockerEngineRuby::Models::Container::NetworkSettings::Network#ipam_config class IpamConfig < DockerEngineRuby::Internal::Type::BaseModel # @!attribute i_pv4_address # # @return [String, nil] optional :i_pv4_address, String, api_name: :IPv4Address # @!attribute i_pv6_address # # @return [String, nil] optional :i_pv6_address, String, api_name: :IPv6Address # @!attribute link_local_ips # # @return [Array<String>, nil] optional :link_local_ips, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :LinkLocalIPs # @!method initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) # EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @param i_pv4_address [String] # @param i_pv6_address [String] # @param link_local_ips [Array<String>] end end |
Instance Attribute Details
#aliases ⇒ Array<String>?
1957 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1957 optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases |
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.
These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending ‘.<network-name>`. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.
1969 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1969 optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames |
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.
1976 1977 1978 1979 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1976 optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true |
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
1985 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1985 optional :endpoint_id, String, api_name: :EndpointID |
#gateway ⇒ String?
Gateway address for this network.
1991 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1991 optional :gateway, String, api_name: :Gateway |
#global_i_pv6_address ⇒ String?
Global IPv6 address.
1997 |
# File 'lib/docker_engine_ruby/models/container.rb', line 1997 optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address |
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
2003 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2003 optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen |
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.
2012 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2012 optional :gw_priority, Integer, api_name: :GwPriority |
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
2038 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2038 optional :i_pv6_gateway, String, api_name: :IPv6Gateway |
#ip_address ⇒ String?
IPv4 address.
2018 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2018 optional :ip_address, String, api_name: :IPAddress |
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
2032 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2032 optional :ip_prefix_len, Integer, api_name: :IPPrefixLen |
#ipam_config ⇒ DockerEngineRuby::Models::Container::NetworkSettings::Network::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
2024 2025 2026 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2024 optional :ipam_config, -> { DockerEngineRuby::Container::NetworkSettings::Network::IpamConfig }, api_name: :IPAMConfig |
#links ⇒ Array<String>?
2043 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2043 optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links |
#mac_address ⇒ String?
MAC address for the endpoint on this network. The network driver might ignore this parameter.
2050 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2050 optional :mac_address, String, api_name: :MacAddress |
#network_id ⇒ String?
Unique ID of the network.
2056 |
# File 'lib/docker_engine_ruby/models/container.rb', line 2056 optional :network_id, String, api_name: :NetworkID |