Module: DockerEngineRuby::Models::Container::State::Health::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/container.rb

Overview

Status is one of none, starting, healthy or unhealthy

  • “none” Indicates there is no healthcheck

  • “starting” Starting indicates that the container is not yet ready

  • “healthy” Healthy indicates that the container is running correctly

  • “unhealthy” Unhealthy indicates that the container has a problem

See Also:

Constant Summary collapse

NONE =
:none
STARTING =
:starting
HEALTHY =
:healthy
UNHEALTHY =
:unhealthy

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info