Class: DockerEngineRuby::Models::ContainerUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ContainerUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_ruby/models/container_update_params.rb
Overview
Defined Under Namespace
Classes: BlkioDeviceReadBp, BlkioDeviceReadIOp, BlkioDeviceWriteBp, BlkioDeviceWriteIOp, BlkioWeightDevice, Device, DeviceRequest, Ulimit
Instance Attribute Summary collapse
-
#blkio_device_read_bps ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadBp>?
Limit read rate (bytes per second) from a device, in the form:.
-
#blkio_device_read_i_ops ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadIOp>?
Limit read rate (IO per second) from a device, in the form:.
-
#blkio_device_write_bps ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteBp>?
Limit write rate (bytes per second) to a device, in the form:.
-
#blkio_device_write_i_ops ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteIOp>?
Limit write rate (IO per second) to a device, in the form:.
-
#blkio_weight ⇒ Integer?
Block IO weight (relative weight).
-
#blkio_weight_device ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioWeightDevice>?
Block IO weight (relative device weight) in the form:.
-
#cgroup_parent ⇒ String?
Path to ‘cgroups` under which the container’s ‘cgroup` is created.
-
#cpu_count ⇒ Integer?
The number of usable CPUs (Windows only).
-
#cpu_percent ⇒ Integer?
The usable percentage of the available CPUs (Windows only).
-
#cpu_period ⇒ Integer?
The length of a CPU period in microseconds.
-
#cpu_quota ⇒ Integer?
Microseconds of CPU time that the container can get in a CPU period.
-
#cpu_realtime_period ⇒ Integer?
The length of a CPU real-time period in microseconds.
-
#cpu_realtime_runtime ⇒ Integer?
The length of a CPU real-time runtime in microseconds.
-
#cpu_shares ⇒ Integer?
An integer value representing this container’s relative CPU weight versus other containers.
-
#cpuset_cpus ⇒ String?
CPUs in which to allow execution (e.g., ‘0-3`, `0,1`).
-
#cpuset_mems ⇒ String?
Memory nodes (MEMs) in which to allow execution (0-3, 0,1).
-
#device_cgroup_rules ⇒ Array<String>?
a list of cgroup rules to apply to the container.
-
#device_requests ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest>?
A list of requests for devices to be sent to device drivers.
-
#devices ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::Device>?
A list of devices to add to the container.
- #id ⇒ String
-
#init ⇒ Boolean?
Run an init inside the container that forwards signals and reaps processes.
-
#io_maximum_bandwidth ⇒ Integer?
Maximum IO in bytes per second for the container system drive (Windows only).
-
#io_maximum_i_ops ⇒ Integer?
Maximum IOps for the container system drive (Windows only).
-
#memory ⇒ Integer?
Memory limit in bytes.
-
#memory_reservation ⇒ Integer?
Memory soft limit in bytes.
-
#memory_swap ⇒ Integer?
Total memory limit (memory + swap).
-
#memory_swappiness ⇒ Integer?
Tune a container’s memory swappiness behavior.
-
#nano_cpus ⇒ Integer?
CPU quota in units of 10<sup>-9</sup> CPUs.
-
#oom_kill_disable ⇒ Boolean?
Disable OOM Killer for the container.
-
#pids_limit ⇒ Integer?
Tune a container’s PIDs limit.
-
#ulimits ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::Ulimit>?
A list of resource limits to set in the container.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(cgroup_permissions: nil, path_in_container: nil, path_on_host: nil) ⇒ Object
constructor
A device mapping between the host and container.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cgroup_permissions: nil, path_in_container: nil, path_on_host: nil) ⇒ Object
A device mapping between the host and container
|
|
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 352
|
Instance Attribute Details
#blkio_device_read_bps ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadBp>?
Limit read rate (bytes per second) from a device, in the form:
“‘
- “device_path”, “Rate”: rate
-
“‘
23 24 25 26 27 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 23 optional :blkio_device_read_bps, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceReadBp] }, api_name: :BlkioDeviceReadBps |
#blkio_device_read_i_ops ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadIOp>?
Limit read rate (IO per second) from a device, in the form:
“‘
- “device_path”, “Rate”: rate
-
“‘
37 38 39 40 41 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 37 optional :blkio_device_read_i_ops, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceReadIOp] }, api_name: :BlkioDeviceReadIOps |
#blkio_device_write_bps ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteBp>?
Limit write rate (bytes per second) to a device, in the form:
“‘
- “device_path”, “Rate”: rate
-
“‘
51 52 53 54 55 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 51 optional :blkio_device_write_bps, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceWriteBp] }, api_name: :BlkioDeviceWriteBps |
#blkio_device_write_i_ops ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteIOp>?
Limit write rate (IO per second) to a device, in the form:
“‘
- “device_path”, “Rate”: rate
-
“‘
65 66 67 68 69 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 65 optional :blkio_device_write_i_ops, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceWriteIOp] }, api_name: :BlkioDeviceWriteIOps |
#blkio_weight ⇒ Integer?
Block IO weight (relative weight).
75 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 75 optional :blkio_weight, Integer, api_name: :BlkioWeight |
#blkio_weight_device ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::BlkioWeightDevice>?
Block IO weight (relative device weight) in the form:
“‘
- “device_path”, “Weight”: weight
-
“‘
85 86 87 88 89 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 85 optional :blkio_weight_device, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioWeightDevice] }, api_name: :BlkioWeightDevice |
#cgroup_parent ⇒ String?
Path to ‘cgroups` under which the container’s ‘cgroup` is created. If the path is not absolute, the path is considered to be relative to the `cgroups` path of the init process. Cgroups are created if they do not already exist.
97 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 97 optional :cgroup_parent, String, api_name: :CgroupParent |
#cpu_count ⇒ Integer?
The number of usable CPUs (Windows only).
On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is ‘CPUCount` first, then `CPUShares`, and `CPUPercent` last.
107 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 107 optional :cpu_count, Integer, api_name: :CpuCount |
#cpu_percent ⇒ Integer?
The usable percentage of the available CPUs (Windows only).
On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is ‘CPUCount` first, then `CPUShares`, and `CPUPercent` last.
117 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 117 optional :cpu_percent, Integer, api_name: :CpuPercent |
#cpu_period ⇒ Integer?
The length of a CPU period in microseconds.
123 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 123 optional :cpu_period, Integer, api_name: :CpuPeriod |
#cpu_quota ⇒ Integer?
Microseconds of CPU time that the container can get in a CPU period.
129 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 129 optional :cpu_quota, Integer, api_name: :CpuQuota |
#cpu_realtime_period ⇒ Integer?
The length of a CPU real-time period in microseconds. Set to 0 to allocate no time allocated to real-time tasks.
136 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 136 optional :cpu_realtime_period, Integer, api_name: :CpuRealtimePeriod |
#cpu_realtime_runtime ⇒ Integer?
The length of a CPU real-time runtime in microseconds. Set to 0 to allocate no time allocated to real-time tasks.
143 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 143 optional :cpu_realtime_runtime, Integer, api_name: :CpuRealtimeRuntime |
#cpu_shares ⇒ Integer?
An integer value representing this container’s relative CPU weight versus other containers.
163 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 163 optional :cpu_shares, Integer, api_name: :CpuShares |
#cpuset_cpus ⇒ String?
CPUs in which to allow execution (e.g., ‘0-3`, `0,1`).
149 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 149 optional :cpuset_cpus, String, api_name: :CpusetCpus |
#cpuset_mems ⇒ String?
Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only effective on NUMA systems.
156 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 156 optional :cpuset_mems, String, api_name: :CpusetMems |
#device_cgroup_rules ⇒ Array<String>?
a list of cgroup rules to apply to the container
169 170 171 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 169 optional :device_cgroup_rules, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DeviceCgroupRules |
#device_requests ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest>?
A list of requests for devices to be sent to device drivers.
177 178 179 180 181 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 177 optional :device_requests, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::DeviceRequest] }, api_name: :DeviceRequests |
#devices ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::Device>?
A list of devices to add to the container.
187 188 189 190 191 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 187 optional :devices, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::Device] }, api_name: :Devices |
#id ⇒ String
13 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 13 required :id, String |
#init ⇒ Boolean?
Run an init inside the container that forwards signals and reaps processes. This field is omitted if empty, and the default (as configured on the daemon) is used.
199 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 199 optional :init, DockerEngineRuby::Internal::Type::Boolean, api_name: :Init, nil?: true |
#io_maximum_bandwidth ⇒ Integer?
Maximum IO in bytes per second for the container system drive (Windows only).
205 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 205 optional :io_maximum_bandwidth, Integer, api_name: :IOMaximumBandwidth |
#io_maximum_i_ops ⇒ Integer?
Maximum IOps for the container system drive (Windows only)
211 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 211 optional :io_maximum_i_ops, Integer, api_name: :IOMaximumIOps |
#memory ⇒ Integer?
Memory limit in bytes.
217 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 217 optional :memory, Integer, api_name: :Memory |
#memory_reservation ⇒ Integer?
Memory soft limit in bytes.
223 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 223 optional :memory_reservation, Integer, api_name: :MemoryReservation |
#memory_swap ⇒ Integer?
Total memory limit (memory + swap). Set as ‘-1` to enable unlimited swap.
229 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 229 optional :memory_swap, Integer, api_name: :MemorySwap |
#memory_swappiness ⇒ Integer?
Tune a container’s memory swappiness behavior. Accepts an integer between 0 and 100.
236 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 236 optional :memory_swappiness, Integer, api_name: :MemorySwappiness |
#nano_cpus ⇒ Integer?
CPU quota in units of 10<sup>-9</sup> CPUs.
242 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 242 optional :nano_cpus, Integer, api_name: :NanoCpus |
#oom_kill_disable ⇒ Boolean?
Disable OOM Killer for the container.
248 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 248 optional :oom_kill_disable, DockerEngineRuby::Internal::Type::Boolean, api_name: :OomKillDisable |
#pids_limit ⇒ Integer?
Tune a container’s PIDs limit. Set ‘0` or `-1` for unlimited, or `null` to not change.
255 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 255 optional :pids_limit, Integer, api_name: :PidsLimit, nil?: true |
#ulimits ⇒ Array<DockerEngineRuby::Models::ContainerUpdateParams::Ulimit>?
A list of resource limits to set in the container. For example:
“‘ “nofile”, “Soft”: 1024, “Hard”: 2048 “`
265 266 267 268 269 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 265 optional :ulimits, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::Ulimit] }, api_name: :Ulimits |