Class: DockerEngineRuby::Models::ContainerUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_ruby/models/container_update_params.rb

Overview

Defined Under Namespace

Classes: BlkioDeviceReadBp, BlkioDeviceReadIOp, BlkioDeviceWriteBp, BlkioDeviceWriteIOp, BlkioWeightDevice, Device, DeviceRequest, Ulimit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cgroup_permissions: nil, path_in_container: nil, path_on_host: nil) ⇒ Object

A device mapping between the host and container

Parameters:

  • cgroup_permissions (String) (defaults to: nil)
  • path_in_container (String) (defaults to: nil)
  • path_on_host (String) (defaults to: nil)


# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 345


Instance Attribute Details

#blkio_device_read_bpsArray<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadBp>?

Limit read rate (bytes per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



18
19
20
21
22
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 18

optional :blkio_device_read_bps,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceReadBp]
},
api_name: :BlkioDeviceReadBps

#blkio_device_read_i_opsArray<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceReadIOp>?

Limit read rate (IO per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



32
33
34
35
36
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 32

optional :blkio_device_read_i_ops,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceReadIOp]
},
api_name: :BlkioDeviceReadIOps

#blkio_device_write_bpsArray<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteBp>?

Limit write rate (bytes per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



46
47
48
49
50
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 46

optional :blkio_device_write_bps,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceWriteBp]
},
api_name: :BlkioDeviceWriteBps

#blkio_device_write_i_opsArray<DockerEngineRuby::Models::ContainerUpdateParams::BlkioDeviceWriteIOp>?

Limit write rate (IO per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



60
61
62
63
64
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 60

optional :blkio_device_write_i_ops,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioDeviceWriteIOp]
},
api_name: :BlkioDeviceWriteIOps

#blkio_weightInteger?

Block IO weight (relative weight).

Returns:

  • (Integer, nil)


70
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 70

optional :blkio_weight, Integer, api_name: :BlkioWeight

#blkio_weight_deviceArray<DockerEngineRuby::Models::ContainerUpdateParams::BlkioWeightDevice>?

Block IO weight (relative device weight) in the form:

“‘

“device_path”, “Weight”: weight

“‘



80
81
82
83
84
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 80

optional :blkio_weight_device,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::BlkioWeightDevice]
},
api_name: :BlkioWeightDevice

#cgroup_parentString?

Path to cgroups under which the container’s cgroup is created. If the path is not absolute, the path is considered to be relative to the cgroups path of the init process. Cgroups are created if they do not already exist.

Returns:

  • (String, nil)


92
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 92

optional :cgroup_parent, String, api_name: :CgroupParent

#cpu_countInteger?

The number of usable CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


102
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 102

optional :cpu_count, Integer, api_name: :CpuCount

#cpu_percentInteger?

The usable percentage of the available CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


112
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 112

optional :cpu_percent, Integer, api_name: :CpuPercent

#cpu_periodInteger?

The length of a CPU period in microseconds.

Returns:

  • (Integer, nil)


118
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 118

optional :cpu_period, Integer, api_name: :CpuPeriod

#cpu_quotaInteger?

Microseconds of CPU time that the container can get in a CPU period.

Returns:

  • (Integer, nil)


124
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 124

optional :cpu_quota, Integer, api_name: :CpuQuota

#cpu_realtime_periodInteger?

The length of a CPU real-time period in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


131
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 131

optional :cpu_realtime_period, Integer, api_name: :CpuRealtimePeriod

#cpu_realtime_runtimeInteger?

The length of a CPU real-time runtime in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


138
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 138

optional :cpu_realtime_runtime, Integer, api_name: :CpuRealtimeRuntime

#cpu_sharesInteger?

An integer value representing this container’s relative CPU weight versus other containers.

Returns:

  • (Integer, nil)


158
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 158

optional :cpu_shares, Integer, api_name: :CpuShares

#cpuset_cpusString?

CPUs in which to allow execution (e.g., 0-3, ‘0,1`).

Returns:

  • (String, nil)


144
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 144

optional :cpuset_cpus, String, api_name: :CpusetCpus

#cpuset_memsString?

Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only effective on NUMA systems.

Returns:

  • (String, nil)


151
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 151

optional :cpuset_mems, String, api_name: :CpusetMems

#device_cgroup_rulesArray<String>?

a list of cgroup rules to apply to the container

Returns:

  • (Array<String>, nil)


164
165
166
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 164

optional :device_cgroup_rules,
DockerEngineRuby::Internal::Type::ArrayOf[String],
api_name: :DeviceCgroupRules

#device_requestsArray<DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest>?

A list of requests for devices to be sent to device drivers.



172
173
174
175
176
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 172

optional :device_requests,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::DeviceRequest]
},
api_name: :DeviceRequests

#devicesArray<DockerEngineRuby::Models::ContainerUpdateParams::Device>?

A list of devices to add to the container.



182
183
184
185
186
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 182

optional :devices,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::Device]
},
api_name: :Devices

#initBoolean?

Run an init inside the container that forwards signals and reaps processes. This field is omitted if empty, and the default (as configured on the daemon) is used.

Returns:

  • (Boolean, nil)


194
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 194

optional :init, DockerEngineRuby::Internal::Type::Boolean, api_name: :Init, nil?: true

#io_maximum_bandwidthInteger?

Maximum IO in bytes per second for the container system drive (Windows only).

Returns:

  • (Integer, nil)


200
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 200

optional :io_maximum_bandwidth, Integer, api_name: :IOMaximumBandwidth

#io_maximum_i_opsInteger?

Maximum IOps for the container system drive (Windows only)

Returns:

  • (Integer, nil)


206
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 206

optional :io_maximum_i_ops, Integer, api_name: :IOMaximumIOps

#memoryInteger?

Memory limit in bytes.

Returns:

  • (Integer, nil)


212
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 212

optional :memory, Integer, api_name: :Memory

#memory_reservationInteger?

Memory soft limit in bytes.

Returns:

  • (Integer, nil)


218
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 218

optional :memory_reservation, Integer, api_name: :MemoryReservation

#memory_swapInteger?

Total memory limit (memory + swap). Set as -1 to enable unlimited swap.

Returns:

  • (Integer, nil)


224
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 224

optional :memory_swap, Integer, api_name: :MemorySwap

#memory_swappinessInteger?

Tune a container’s memory swappiness behavior. Accepts an integer between 0 and 100.

Returns:

  • (Integer, nil)


231
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 231

optional :memory_swappiness, Integer, api_name: :MemorySwappiness

#nano_cpusInteger?

CPU quota in units of 10<sup>-9</sup> CPUs.

Returns:

  • (Integer, nil)


237
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 237

optional :nano_cpus, Integer, api_name: :NanoCpus

#oom_kill_disableBoolean?

Disable OOM Killer for the container.

Returns:

  • (Boolean, nil)


243
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 243

optional :oom_kill_disable, DockerEngineRuby::Internal::Type::Boolean, api_name: :OomKillDisable

#pids_limitInteger?

Tune a container’s PIDs limit. Set 0 or -1 for unlimited, or null to not change.

Returns:

  • (Integer, nil)


250
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 250

optional :pids_limit, Integer, api_name: :PidsLimit, nil?: true

#ulimitsArray<DockerEngineRuby::Models::ContainerUpdateParams::Ulimit>?

A list of resource limits to set in the container. For example:

“‘ “nofile”, “Soft”: 1024, “Hard”: 2048 “`



260
261
262
263
264
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 260

optional :ulimits,
-> {
  DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ContainerUpdateParams::Ulimit]
},
api_name: :Ulimits