Class: DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ContainerUpdateParams::DeviceRequest
- Defined in:
- lib/docker_engine_ruby/models/container_update_params.rb
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<Array<String>>?
A list of capabilities; an OR list of AND lists of capabilities.
- #count ⇒ Integer?
- #device_ids ⇒ Array<String>?
-
#driver ⇒ String?
The name of the device driver to use for this request.
-
#options ⇒ Hash{Symbol=>String}?
Driver-specific options, specified as a key/value pairs.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#capabilities ⇒ Array<Array<String>>?
A list of capabilities; an OR list of AND lists of capabilities.
Note that if a driver is specified the capabilities have no effect on selecting a driver as the driver name is used directly.
Note that if no driver is specified the capabilities are used to select a driver with the required capabilities.
435 436 437 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 435 optional :capabilities, DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::ArrayOf[String]], api_name: :Capabilities |
#count ⇒ Integer?
442 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 442 optional :count, Integer, api_name: :Count |
#device_ids ⇒ Array<String>?
447 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 447 optional :device_ids, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DeviceIDs |
#driver ⇒ String?
The name of the device driver to use for this request.
Note that if this is specified the capabilities are ignored when selecting a device driver.
456 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 456 optional :driver, String, api_name: :Driver |
#options ⇒ Hash{Symbol=>String}?
Driver-specific options, specified as a key/value pairs. These options are passed directly to the driver.
463 |
# File 'lib/docker_engine_ruby/models/container_update_params.rb', line 463 optional :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options |