Class: DockerEngineRuby::Models::Image
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Overview
Defined Under Namespace
Classes: Config, Descriptor, GraphDriver, Identity, Manifest, Metadata, RootFs
Instance Attribute Summary collapse
-
#architecture ⇒ String?
Hardware CPU architecture that the image runs on.
-
#author ⇒ String?
Name of the author that was specified when committing the image, or as specified through MAINTAINER (deprecated) in the Dockerfile.
-
#comment ⇒ String?
Optional message that was set when committing or importing the image.
-
#config ⇒ DockerEngineRuby::Models::Image::Config?
Configuration of the image.
-
#created ⇒ Time?
Date and time at which the image was created, formatted in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
-
#descriptor ⇒ DockerEngineRuby::Models::Image::Descriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
-
#graph_driver ⇒ DockerEngineRuby::Models::Image::GraphDriver?
Information about the storage driver used to store the container’s and image’s filesystem.
-
#id ⇒ String?
ID is the content-addressable ID of an image.
-
#identity ⇒ DockerEngineRuby::Models::Image::Identity?
Identity holds information about the identity and origin of the image.
-
#manifests ⇒ Array<DockerEngineRuby::Models::Image::Manifest>?
Manifests is a list of image manifests available in this image.
-
#metadata ⇒ DockerEngineRuby::Models::Image::Metadata?
Additional metadata of the image in the local cache.
-
#os ⇒ String?
Operating System the image is built to run on.
-
#os_version ⇒ String?
Operating System version the image is built to run on (especially for Windows).
-
#repo_digests ⇒ Array<String>?
List of content-addressable digests of locally available image manifests that the image is referenced from.
-
#repo_tags ⇒ Array<String>?
List of image names/tags in the local image cache that reference this image.
-
#root_fs ⇒ DockerEngineRuby::Models::Image::RootFs?
Information about the image’s RootFS, including the layer IDs.
-
#size ⇒ Integer?
Total size of the image including all layers it is composed of.
-
#variant ⇒ String?
CPU architecture variant (presently ARM-only).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(last_tag_time: nil) ⇒ Object
constructor
Additional metadata of the image in the local cache.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_tag_time: nil) ⇒ Object
Additional metadata of the image in the local cache. This information is local to the daemon, and not part of the image itself.
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 152
|
Instance Attribute Details
#architecture ⇒ String?
Hardware CPU architecture that the image runs on.
11 |
# File 'lib/docker_engine_ruby/models/image.rb', line 11 optional :architecture, String, api_name: :Architecture |
#author ⇒ String?
Name of the author that was specified when committing the image, or as specified through MAINTAINER (deprecated) in the Dockerfile.
18 |
# File 'lib/docker_engine_ruby/models/image.rb', line 18 optional :author, String, api_name: :Author, nil?: true |
#comment ⇒ String?
Optional message that was set when committing or importing the image.
24 |
# File 'lib/docker_engine_ruby/models/image.rb', line 24 optional :comment, String, api_name: :Comment, nil?: true |
#config ⇒ DockerEngineRuby::Models::Image::Config?
Configuration of the image. These fields are used as defaults when starting a container from the image.
31 |
# File 'lib/docker_engine_ruby/models/image.rb', line 31 optional :config, -> { DockerEngineRuby::Image::Config }, api_name: :Config |
#created ⇒ Time?
Date and time at which the image was created, formatted in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
This information is only available if present in the image, and omitted otherwise.
41 |
# File 'lib/docker_engine_ruby/models/image.rb', line 41 optional :created, Time, api_name: :Created, nil?: true |
#descriptor ⇒ DockerEngineRuby::Models::Image::Descriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
48 |
# File 'lib/docker_engine_ruby/models/image.rb', line 48 optional :descriptor, -> { DockerEngineRuby::Image::Descriptor }, api_name: :Descriptor, nil?: true |
#graph_driver ⇒ DockerEngineRuby::Models::Image::GraphDriver?
Information about the storage driver used to store the container’s and image’s filesystem.
55 |
# File 'lib/docker_engine_ruby/models/image.rb', line 55 optional :graph_driver, -> { DockerEngineRuby::Image::GraphDriver }, api_name: :GraphDriver, nil?: true |
#id ⇒ String?
ID is the content-addressable ID of an image.
This identifier is a content-addressable digest calculated from the image’s configuration (which includes the digests of layers used by the image).
Note that this digest differs from the RepoDigests below, which holds digests of image manifests that reference the image.
67 |
# File 'lib/docker_engine_ruby/models/image.rb', line 67 optional :id, String, api_name: :Id |
#identity ⇒ DockerEngineRuby::Models::Image::Identity?
Identity holds information about the identity and origin of the image. This is trusted information verified by the daemon and cannot be modified by tagging an image to a different name.
75 |
# File 'lib/docker_engine_ruby/models/image.rb', line 75 optional :identity, -> { DockerEngineRuby::Image::Identity }, api_name: :Identity, nil?: true |
#manifests ⇒ Array<DockerEngineRuby::Models::Image::Manifest>?
Manifests is a list of image manifests available in this image. It provides a more detailed view of the platform-specific image manifests or other image-attached data like build attestations.
Only available if the daemon provides a multi-platform image store and the manifests option is set in the inspect request.
WARNING: This is experimental and may change at any time without any backward compatibility.
89 90 91 92 |
# File 'lib/docker_engine_ruby/models/image.rb', line 89 optional :manifests, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Manifest] }, api_name: :Manifests, nil?: true |
#metadata ⇒ DockerEngineRuby::Models::Image::Metadata?
Additional metadata of the image in the local cache. This information is local to the daemon, and not part of the image itself.
99 |
# File 'lib/docker_engine_ruby/models/image.rb', line 99 optional :metadata, -> { DockerEngineRuby::Image::Metadata }, api_name: :Metadata |
#os ⇒ String?
Operating System the image is built to run on.
105 |
# File 'lib/docker_engine_ruby/models/image.rb', line 105 optional :os, String, api_name: :Os |
#os_version ⇒ String?
Operating System version the image is built to run on (especially for Windows).
111 |
# File 'lib/docker_engine_ruby/models/image.rb', line 111 optional :os_version, String, api_name: :OsVersion, nil?: true |
#repo_digests ⇒ Array<String>?
List of content-addressable digests of locally available image manifests that the image is referenced from. Multiple manifests can refer to the same image.
These digests are usually only available if the image was either pulled from a registry, or if the image was pushed to a registry, which is when the manifest is generated and its digest calculated.
122 |
# File 'lib/docker_engine_ruby/models/image.rb', line 122 optional :repo_digests, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :RepoDigests |
#repo_tags ⇒ Array<String>?
List of image names/tags in the local image cache that reference this image.
Multiple image tags can refer to the same image, and this list may be empty if no tags reference the image, in which case the image is “untagged”, in which case it can still be referenced by its ID.
132 |
# File 'lib/docker_engine_ruby/models/image.rb', line 132 optional :repo_tags, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :RepoTags |
#root_fs ⇒ DockerEngineRuby::Models::Image::RootFs?
Information about the image’s RootFS, including the layer IDs.
138 |
# File 'lib/docker_engine_ruby/models/image.rb', line 138 optional :root_fs, -> { DockerEngineRuby::Image::RootFs }, api_name: :RootFS |
#size ⇒ Integer?
Total size of the image including all layers it is composed of.
144 |
# File 'lib/docker_engine_ruby/models/image.rb', line 144 optional :size, Integer, api_name: :Size |
#variant ⇒ String?
CPU architecture variant (presently ARM-only).
150 |
# File 'lib/docker_engine_ruby/models/image.rb', line 150 optional :variant, String, api_name: :Variant, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 953
|