Class: DockerEngineRuby::Models::Image::Config
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Config
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Overview
Defined Under Namespace
Classes: Healthcheck
Instance Attribute Summary collapse
-
#args_escaped ⇒ Boolean?
Command is already escaped (Windows only).
-
#cmd ⇒ Array<String>?
Command to run specified as a string or an array of strings.
-
#entrypoint ⇒ Array<String>?
The entry point for the container as a string or an array of strings.
-
#env ⇒ Array<String>?
A list of environment variables to set inside the container in the form ‘[“VAR=value”, …]`.
-
#exposed_ports ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
An object mapping ports to an empty object in the form:.
-
#healthcheck ⇒ DockerEngineRuby::Models::Image::Config::Healthcheck?
A test to perform to check that the container is healthy.
-
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
-
#on_build ⇒ Array<String>?
ONBUILDmetadata that were defined in the image’sDockerfile. -
#shell ⇒ Array<String>?
Shell for when
RUN,CMD, andENTRYPOINTuses a shell. -
#stop_signal ⇒ String?
Signal to stop a container as a string or unsigned integer.
-
#user ⇒ String?
The user that commands are run as inside the container.
-
#volumes ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
An object mapping mount point paths inside the container to empty objects.
-
#working_dir ⇒ String?
The working directory for commands to run in.
Instance Method Summary collapse
-
#initialize(args_escaped: nil, cmd: nil, entrypoint: nil, env: nil, exposed_ports: nil, healthcheck: nil, labels: nil, on_build: nil, shell: nil, stop_signal: nil, user: nil, volumes: nil, working_dir: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Config for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(args_escaped: nil, cmd: nil, entrypoint: nil, env: nil, exposed_ports: nil, healthcheck: nil, labels: nil, on_build: nil, shell: nil, stop_signal: nil, user: nil, volumes: nil, working_dir: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Image::Config for more details.
Configuration of the image. These fields are used as defaults when starting a container from the image.
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 288
|
Instance Attribute Details
#args_escaped ⇒ Boolean?
Command is already escaped (Windows only)
200 |
# File 'lib/docker_engine_ruby/models/image.rb', line 200 optional :args_escaped, DockerEngineRuby::Internal::Type::Boolean, api_name: :ArgsEscaped, nil?: true |
#cmd ⇒ Array<String>?
Command to run specified as a string or an array of strings.
206 |
# File 'lib/docker_engine_ruby/models/image.rb', line 206 optional :cmd, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Cmd |
#entrypoint ⇒ Array<String>?
The entry point for the container as a string or an array of strings.
If the array consists of exactly one empty string (‘[“”]`) then the entry point is reset to system default (i.e., the entry point used by docker when there is no ENTRYPOINT instruction in the Dockerfile).
216 |
# File 'lib/docker_engine_ruby/models/image.rb', line 216 optional :entrypoint, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Entrypoint |
#env ⇒ Array<String>?
A list of environment variables to set inside the container in the form ‘[“VAR=value”, …]`. A variable without `=` is removed from the environment, rather than to have an empty value.
224 |
# File 'lib/docker_engine_ruby/models/image.rb', line 224 optional :env, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Env |
#exposed_ports ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
An object mapping ports to an empty object in the form:
‘{}`
232 233 234 235 |
# File 'lib/docker_engine_ruby/models/image.rb', line 232 optional :exposed_ports, DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]], api_name: :ExposedPorts, nil?: true |
#healthcheck ⇒ DockerEngineRuby::Models::Image::Config::Healthcheck?
A test to perform to check that the container is healthy. Healthcheck commands should be side-effect free.
242 |
# File 'lib/docker_engine_ruby/models/image.rb', line 242 optional :healthcheck, -> { DockerEngineRuby::Image::Config::Healthcheck }, api_name: :Healthcheck |
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
248 |
# File 'lib/docker_engine_ruby/models/image.rb', line 248 optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels |
#on_build ⇒ Array<String>?
ONBUILD metadata that were defined in the image’s Dockerfile.
254 |
# File 'lib/docker_engine_ruby/models/image.rb', line 254 optional :on_build, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :OnBuild, nil?: true |
#shell ⇒ Array<String>?
Shell for when RUN, CMD, and ENTRYPOINT uses a shell.
260 |
# File 'lib/docker_engine_ruby/models/image.rb', line 260 optional :shell, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Shell, nil?: true |
#stop_signal ⇒ String?
Signal to stop a container as a string or unsigned integer.
266 |
# File 'lib/docker_engine_ruby/models/image.rb', line 266 optional :stop_signal, String, api_name: :StopSignal, nil?: true |
#user ⇒ String?
The user that commands are run as inside the container.
272 |
# File 'lib/docker_engine_ruby/models/image.rb', line 272 optional :user, String, api_name: :User |
#volumes ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
An object mapping mount point paths inside the container to empty objects.
278 279 280 |
# File 'lib/docker_engine_ruby/models/image.rb', line 278 optional :volumes, DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]], api_name: :Volumes |
#working_dir ⇒ String?
The working directory for commands to run in.
286 |
# File 'lib/docker_engine_ruby/models/image.rb', line 286 optional :working_dir, String, api_name: :WorkingDir |