Class: DockerEngineRuby::Models::Image::Identity::Signature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Identity::Signature
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Defined Under Namespace
Modules: KnownSigner, SignatureType Classes: Signer, Timestamp
Instance Attribute Summary collapse
-
#docker_reference ⇒ String?
DockerReference is the Docker image reference associated with the signature.
-
#error ⇒ String?
Error contains error information if signature verification failed.
-
#known_signer ⇒ Symbol, ...
KnownSignerIdentity is an identifier for a special signer identity that is known to the implementation.
-
#name ⇒ String?
Name is a textual description summarizing the type of signature.
-
#signature_type ⇒ Symbol, ...
SignatureType is the type of signature format.
-
#signer ⇒ DockerEngineRuby::Models::Image::Identity::Signature::Signer?
SignerIdentity contains information about the signer certificate used to sign the image.
-
#timestamps ⇒ Array<DockerEngineRuby::Models::Image::Identity::Signature::Timestamp>?
Timestamps contains a list of verified signed timestamps for the signature.
-
#warnings ⇒ Array<String>?
Warnings contains any warnings that occurred during signature verification.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(build_config_digest: nil, build_config_uri: nil, build_signer_digest: nil, build_signer_uri: nil, build_trigger: nil, certificate_issuer: nil, issuer: nil, run_invocation_uri: nil, runner_environment: nil, source_repository_digest: nil, source_repository_identifier: nil, source_repository_owner_identifier: nil, source_repository_owner_uri: nil, source_repository_ref: nil, source_repository_uri: nil, source_repository_visibility_at_signing: nil, subject_alternative_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Signer for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(build_config_digest: nil, build_config_uri: nil, build_signer_digest: nil, build_signer_uri: nil, build_trigger: nil, certificate_issuer: nil, issuer: nil, run_invocation_uri: nil, runner_environment: nil, source_repository_digest: nil, source_repository_identifier: nil, source_repository_owner_identifier: nil, source_repository_owner_uri: nil, source_repository_ref: nil, source_repository_uri: nil, source_repository_visibility_at_signing: nil, subject_alternative_name: nil) ⇒ Object
Some parameter documentations has been truncated, see Signer for more details.
SignerIdentity contains information about the signer certificate used to sign the image.
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 711
|
Instance Attribute Details
#docker_reference ⇒ String?
DockerReference is the Docker image reference associated with the signature. This is an optional field only present in older hashedrecord signatures.
653 |
# File 'lib/docker_engine_ruby/models/image.rb', line 653 optional :docker_reference, String, api_name: :DockerReference |
#error ⇒ String?
Error contains error information if signature verification failed. Other fields will be empty in this case.
660 |
# File 'lib/docker_engine_ruby/models/image.rb', line 660 optional :error, String, api_name: :Error |
#known_signer ⇒ Symbol, ...
KnownSignerIdentity is an identifier for a special signer identity that is known to the implementation.
667 668 669 |
# File 'lib/docker_engine_ruby/models/image.rb', line 667 optional :known_signer, enum: -> { DockerEngineRuby::Image::Identity::Signature::KnownSigner }, api_name: :KnownSigner |
#name ⇒ String?
Name is a textual description summarizing the type of signature.
675 |
# File 'lib/docker_engine_ruby/models/image.rb', line 675 optional :name, String, api_name: :Name |
#signature_type ⇒ Symbol, ...
SignatureType is the type of signature format.
681 682 683 |
# File 'lib/docker_engine_ruby/models/image.rb', line 681 optional :signature_type, enum: -> { DockerEngineRuby::Image::Identity::Signature::SignatureType }, api_name: :SignatureType |
#signer ⇒ DockerEngineRuby::Models::Image::Identity::Signature::Signer?
SignerIdentity contains information about the signer certificate used to sign the image.
690 |
# File 'lib/docker_engine_ruby/models/image.rb', line 690 optional :signer, -> { DockerEngineRuby::Image::Identity::Signature::Signer }, api_name: :Signer |
#timestamps ⇒ Array<DockerEngineRuby::Models::Image::Identity::Signature::Timestamp>?
Timestamps contains a list of verified signed timestamps for the signature.
696 697 698 699 700 |
# File 'lib/docker_engine_ruby/models/image.rb', line 696 optional :timestamps, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Image::Identity::Signature::Timestamp] }, api_name: :Timestamps |
#warnings ⇒ Array<String>?
Warnings contains any warnings that occurred during signature verification. For example, if there was no internet connectivity and cached trust roots were used. Warning does not indicate a failed verification but may point to configuration issues.
709 |
# File 'lib/docker_engine_ruby/models/image.rb', line 709 optional :warnings, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Warnings |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 742
|