Class: DockerEngineRuby::Models::Image::Identity::Signature::Timestamp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Identity::Signature::Timestamp
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #timestamp ⇒ Time?
-
#type ⇒ Symbol, ...
SignatureTimestampType is the type of timestamp used in the signature.
- #uri ⇒ String?
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil, uri: nil) ⇒ Object
constructor
SignatureTimestamp contains information about a verified signed timestamp for an image signature.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(timestamp: nil, type: nil, uri: nil) ⇒ Object
SignatureTimestamp contains information about a verified signed timestamp for an image signature.
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 934
|
Instance Attribute Details
#timestamp ⇒ Time?
919 |
# File 'lib/docker_engine_ruby/models/image.rb', line 919 optional :timestamp, Time, api_name: :Timestamp |
#type ⇒ Symbol, ...
SignatureTimestampType is the type of timestamp used in the signature.
925 926 927 |
# File 'lib/docker_engine_ruby/models/image.rb', line 925 optional :type, enum: -> { DockerEngineRuby::Image::Identity::Signature::Timestamp::Type }, api_name: :Type |
#uri ⇒ String?
932 |
# File 'lib/docker_engine_ruby/models/image.rb', line 932 optional :uri, String, api_name: :URI |