Class: DockerEngineRuby::Models::Image::Manifest::ImageData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Image::Manifest::ImageData
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #containers ⇒ Array<String>
-
#platform ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData::Platform
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
- #size ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData::Size
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Platform for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
|
|
# File 'lib/docker_engine_ruby/models/image.rb', line 1245
|
Instance Attribute Details
#containers ⇒ Array<String>
1226 |
# File 'lib/docker_engine_ruby/models/image.rb', line 1226 required :containers, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Containers |
#platform ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData::Platform
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
1234 1235 1236 1237 1238 |
# File 'lib/docker_engine_ruby/models/image.rb', line 1234 required :platform, -> { DockerEngineRuby::Image::Manifest::ImageData::Platform }, api_name: :Platform |
#size ⇒ DockerEngineRuby::Models::Image::Manifest::ImageData::Size
1243 |
# File 'lib/docker_engine_ruby/models/image.rb', line 1243 required :size, -> { DockerEngineRuby::Image::Manifest::ImageData::Size }, api_name: :Size |