Module: DockerEngineRuby::Models::Image::Manifest::Kind
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine_ruby/models/image.rb
Overview
The kind of the manifest.
| kind | description | | ———– | ———————————————————————————— | | image | Image manifest that can be used to start a container. | | attestation | Attestation manifest produced by the Buildkit builder for a specific image manifest. |
Constant Summary collapse
- IMAGE =
:image- ATTESTATION =
:attestation- UNKNOWN =
:unknown
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info