Class: DockerEngineRuby::Models::ImageSummary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ImageSummary
- Defined in:
- lib/docker_engine_ruby/models/image_summary.rb
Defined Under Namespace
Classes: Descriptor, Manifest
Instance Attribute Summary collapse
-
#containers ⇒ Integer
Number of containers using this image.
-
#created ⇒ Integer
Date and time at which the image was created as a Unix timestamp (number of seconds since EPOCH).
-
#descriptor ⇒ DockerEngineRuby::Models::ImageSummary::Descriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
-
#id ⇒ String
ID is the content-addressable ID of an image.
-
#labels ⇒ Hash{Symbol=>String}
User-defined key/value metadata.
-
#manifests ⇒ Array<DockerEngineRuby::Models::ImageSummary::Manifest>?
Manifests is a list of manifests available in this image.
-
#parent_id ⇒ String
ID of the parent image.
-
#repo_digests ⇒ Array<String>
List of content-addressable digests of locally available image manifests that the image is referenced from.
-
#repo_tags ⇒ Array<String>
List of image names/tags in the local image cache that reference this image.
-
#shared_size ⇒ Integer
Total size of image layers that are shared between this image and other images.
-
#size ⇒ Integer
Total size of the image including all layers it is composed of.
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Descriptor::Platform for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::ImageSummary::Descriptor::Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
|
|
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 111
|
Instance Attribute Details
#containers ⇒ Integer
Number of containers using this image. Includes both stopped and running containers.
-1 indicates that the value has not been set / calculated.
13 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 13 required :containers, Integer, api_name: :Containers |
#created ⇒ Integer
Date and time at which the image was created as a Unix timestamp (number of seconds since EPOCH).
20 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 20 required :created, Integer, api_name: :Created |
#descriptor ⇒ DockerEngineRuby::Models::ImageSummary::Descriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
91 92 93 94 95 96 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 91 optional :descriptor, -> { DockerEngineRuby::ImageSummary::Descriptor }, api_name: :Descriptor, nil?: true |
#id ⇒ String
ID is the content-addressable ID of an image.
This identifier is a content-addressable digest calculated from the image’s configuration (which includes the digests of layers used by the image).
Note that this digest differs from the RepoDigests below, which holds digests of image manifests that reference the image.
32 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 32 required :id, String, api_name: :Id |
#labels ⇒ Hash{Symbol=>String}
User-defined key/value metadata.
38 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 38 required :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels |
#manifests ⇒ Array<DockerEngineRuby::Models::ImageSummary::Manifest>?
Manifests is a list of manifests available in this image. It provides a more detailed view of the platform-specific image manifests or other image-attached data like build attestations.
WARNING: This is experimental and may change at any time without any backward compatibility.
107 108 109 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 107 optional :manifests, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::ImageSummary::Manifest] }, api_name: :Manifests |
#parent_id ⇒ String
ID of the parent image.
Depending on how the image was created, this field may be empty and is only set for images that were built/created locally. This field is empty if the image was pulled from an image registry.
48 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 48 required :parent_id, String, api_name: :ParentId |
#repo_digests ⇒ Array<String>
List of content-addressable digests of locally available image manifests that the image is referenced from. Multiple manifests can refer to the same image.
These digests are usually only available if the image was either pulled from a registry, or if the image was pushed to a registry, which is when the manifest is generated and its digest calculated.
59 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 59 required :repo_digests, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :RepoDigests |
#repo_tags ⇒ Array<String>
List of image names/tags in the local image cache that reference this image.
Multiple image tags can refer to the same image, and this list may be empty if no tags reference the image, in which case the image is “untagged”, in which case it can still be referenced by its ID.
69 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 69 required :repo_tags, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :RepoTags |
#shared_size ⇒ Integer
Total size of image layers that are shared between this image and other images.
This size is not calculated by default. -1 indicates that the value has not been set / calculated.
78 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 78 required :shared_size, Integer, api_name: :SharedSize |
#size ⇒ Integer
Total size of the image including all layers it is composed of.
84 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 84 required :size, Integer, api_name: :Size |