Class: DockerEngineRuby::Models::ImageSummary::Manifest::ImageData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ImageSummary::Manifest::ImageData
- Defined in:
- lib/docker_engine_ruby/models/image_summary.rb,
sig/docker_engine_ruby/models/image_summary.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #containers ⇒ Array<String>
-
#platform ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Platform
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
- #size ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Size
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Platform for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
|
|
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 556
|
Instance Attribute Details
#containers ⇒ Array<String>
539 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 539 required :containers, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Containers |
#platform ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Platform
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
547 548 549 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 547 required :platform, -> { DockerEngineRuby::ImageSummary::Manifest::ImageData::Platform }, api_name: :Platform |
#size ⇒ DockerEngineRuby::Models::ImageSummary::Manifest::ImageData::Size
554 |
# File 'lib/docker_engine_ruby/models/image_summary.rb', line 554 required :size, -> { DockerEngineRuby::ImageSummary::Manifest::ImageData::Size }, api_name: :Size |
Instance Method Details
#to_hash ⇒ {
391 |
# File 'sig/docker_engine_ruby/models/image_summary.rbs', line 391
def to_hash: -> {
|