Module: DockerEngineRuby::Models::Info::Isolation

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/info.rb

Overview

Represents the isolation technology to use as a default for containers. The supported values are platform-specific.

If no isolation value is specified on daemon start, on Windows client, the default is hyperv, and on Windows server, the default is process.

This option is currently not used on other platforms.

See Also:

Constant Summary collapse

DEFAULT =
:default
HYPERV =
:hyperv
PROCESS =
:process
EMPTY =
:""

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info