Class: DockerEngineRuby::Models::Info::Nri
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Info::Nri
- Defined in:
- lib/docker_engine_ruby/models/info.rb
Overview
Instance Attribute Summary collapse
-
#info ⇒ Array<Array<String>>?
Information about NRI, provided as “label” / “value” pairs.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#info ⇒ Array<Array<String>>?
Information about NRI, provided as “label” / “value” pairs.
<p><br /></p>
> Note: The information returned in this field, including the formatting of > values and labels, should not be considered stable, and may change without > notice.
942 943 944 |
# File 'lib/docker_engine_ruby/models/info.rb', line 942 optional :info, DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Internal::Type::ArrayOf[String]], api_name: :Info |