Class: DockerEngineRuby::Models::Info::Swarm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Info::Swarm
- Defined in:
- lib/docker_engine_ruby/models/info.rb
Overview
Defined Under Namespace
Modules: LocalNodeState Classes: Cluster, RemoteManager
Instance Attribute Summary collapse
-
#cluster ⇒ DockerEngineRuby::Models::Info::Swarm::Cluster?
ClusterInfo represents information about the swarm as is returned by the “/info” endpoint.
- #control_available ⇒ Boolean?
- #error ⇒ String?
-
#local_node_state ⇒ Symbol, ...
Current local status of this node.
-
#managers ⇒ Integer?
Total number of managers in the swarm.
-
#node_addr ⇒ String?
IP address at which this node can be reached by other nodes in the swarm.
-
#node_id ⇒ String?
Unique identifier of for this node in the swarm.
-
#nodes ⇒ Integer?
Total number of nodes in the swarm.
-
#remote_managers ⇒ Array<DockerEngineRuby::Models::Info::Swarm::RemoteManager>?
List of ID’s and addresses of other managers in the swarm.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ Object
constructor
The version number of the object such as node, service, etc.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index: nil) ⇒ Object
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
|
|
# File 'lib/docker_engine_ruby/models/info.rb', line 1240
|
Instance Attribute Details
#cluster ⇒ DockerEngineRuby::Models::Info::Swarm::Cluster?
ClusterInfo represents information about the swarm as is returned by the “/info” endpoint. Join-tokens are not included.
1185 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1185 optional :cluster, -> { DockerEngineRuby::Info::Swarm::Cluster }, api_name: :Cluster |
#control_available ⇒ Boolean?
1190 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1190 optional :control_available, DockerEngineRuby::Internal::Type::Boolean, api_name: :ControlAvailable |
#error ⇒ String?
1195 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1195 optional :error, String, api_name: :Error |
#local_node_state ⇒ Symbol, ...
Current local status of this node.
1201 1202 1203 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1201 optional :local_node_state, enum: -> { DockerEngineRuby::Info::Swarm::LocalNodeState }, api_name: :LocalNodeState |
#managers ⇒ Integer?
Total number of managers in the swarm.
1209 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1209 optional :managers, Integer, api_name: :Managers, nil?: true |
#node_addr ⇒ String?
IP address at which this node can be reached by other nodes in the swarm.
1215 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1215 optional :node_addr, String, api_name: :NodeAddr |
#node_id ⇒ String?
Unique identifier of for this node in the swarm.
1221 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1221 optional :node_id, String, api_name: :NodeID |
#nodes ⇒ Integer?
Total number of nodes in the swarm.
1227 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1227 optional :nodes, Integer, api_name: :Nodes, nil?: true |
#remote_managers ⇒ Array<DockerEngineRuby::Models::Info::Swarm::RemoteManager>?
List of ID’s and addresses of other managers in the swarm.
1233 1234 1235 1236 1237 1238 |
# File 'lib/docker_engine_ruby/models/info.rb', line 1233 optional :remote_managers, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Info::Swarm::RemoteManager] }, api_name: :RemoteManagers, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/info.rb', line 1440
|