Class: DockerEngineRuby::Models::ListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::ListResponse
- Defined in:
- lib/docker_engine_ruby/models/list_response.rb
Overview
Instance Attribute Summary collapse
-
#volumes ⇒ Array<DockerEngineRuby::Models::Volume>?
List of volumes.
-
#warnings ⇒ Array<String>?
Warnings that occurred when fetching the list of volumes.
Instance Method Summary collapse
-
#initialize(volumes: nil, warnings: nil) ⇒ Object
constructor
Volume list response.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(volumes: nil, warnings: nil) ⇒ Object
Volume list response
|
|
# File 'lib/docker_engine_ruby/models/list_response.rb', line 21
|
Instance Attribute Details
#volumes ⇒ Array<DockerEngineRuby::Models::Volume>?
List of volumes
11 12 13 |
# File 'lib/docker_engine_ruby/models/list_response.rb', line 11 optional :volumes, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Volume] }, api_name: :Volumes |
#warnings ⇒ Array<String>?
Warnings that occurred when fetching the list of volumes.
19 |
# File 'lib/docker_engine_ruby/models/list_response.rb', line 19 optional :warnings, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Warnings |