Class: DockerEngineRuby::Models::NetworkInspectResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::NetworkInspectResponse
- Defined in:
- lib/docker_engine_ruby/models/network_inspect_response.rb
Overview
Defined Under Namespace
Classes: ConfigFrom, Ipam, Peer
Instance Attribute Summary collapse
-
#attachable ⇒ Boolean?
Whether a global / swarm scope network is manually attachable by regular containers from workers in swarm mode.
-
#config_from ⇒ DockerEngineRuby::Models::NetworkInspectResponse::ConfigFrom?
The config-only network source to provide the configuration for this network.
-
#config_only ⇒ Boolean?
Whether the network is a config-only network.
-
#created ⇒ Time?
Date and time at which the network was created in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
-
#driver ⇒ String?
The name of the driver used to create the network (e.g.
bridge,overlay). -
#enable_i_pv4 ⇒ Boolean?
Whether the network was created with IPv4 enabled.
-
#enable_i_pv6 ⇒ Boolean?
Whether the network was created with IPv6 enabled.
-
#id ⇒ String?
ID that uniquely identifies a network on a single machine.
-
#ingress ⇒ Boolean?
Whether the network is providing the routing-mesh for the swarm cluster.
-
#internal ⇒ Boolean?
Whether the network is created to only allow internal networking connectivity.
-
#ipam ⇒ DockerEngineRuby::Models::NetworkInspectResponse::Ipam?
The network’s IP Address Management.
-
#labels ⇒ Hash{Symbol=>String}?
Metadata specific to the network being created.
-
#name ⇒ String?
Name of the network.
-
#options ⇒ Hash{Symbol=>String}?
Network-specific options uses when creating the network.
-
#peers ⇒ Array<DockerEngineRuby::Models::NetworkInspectResponse::Peer>?
List of peer nodes for an overlay network.
-
#scope ⇒ String?
The level at which the network exists (e.g.
swarmfor cluster-wide orlocalfor machine level).
Instance Method Summary collapse
- #initialize(auxiliary_addresses: nil, gateway: nil, ip_range: nil, subnet: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auxiliary_addresses: nil, gateway: nil, ip_range: nil, subnet: nil) ⇒ Object
|
|
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 113
|
Instance Attribute Details
#attachable ⇒ Boolean?
Whether a global / swarm scope network is manually attachable by regular containers from workers in swarm mode.
12 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 12 optional :attachable, DockerEngineRuby::Internal::Type::Boolean, api_name: :Attachable |
#config_from ⇒ DockerEngineRuby::Models::NetworkInspectResponse::ConfigFrom?
The config-only network source to provide the configuration for this network.
18 19 20 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 18 optional :config_from, -> { DockerEngineRuby::Models::NetworkInspectResponse::ConfigFrom }, api_name: :ConfigFrom |
#config_only ⇒ Boolean?
Whether the network is a config-only network. Config-only networks are placeholder networks for network configurations to be used by other networks. Config-only networks cannot be used directly to run containers or services.
28 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 28 optional :config_only, DockerEngineRuby::Internal::Type::Boolean, api_name: :ConfigOnly |
#created ⇒ Time?
Date and time at which the network was created in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
35 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 35 optional :created, Time, api_name: :Created |
#driver ⇒ String?
The name of the driver used to create the network (e.g. bridge, overlay).
41 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 41 optional :driver, String, api_name: :Driver |
#enable_i_pv4 ⇒ Boolean?
Whether the network was created with IPv4 enabled.
47 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 47 optional :enable_i_pv4, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv4 |
#enable_i_pv6 ⇒ Boolean?
Whether the network was created with IPv6 enabled.
53 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 53 optional :enable_i_pv6, DockerEngineRuby::Internal::Type::Boolean, api_name: :EnableIPv6 |
#id ⇒ String?
ID that uniquely identifies a network on a single machine.
59 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 59 optional :id, String, api_name: :Id |
#ingress ⇒ Boolean?
Whether the network is providing the routing-mesh for the swarm cluster.
65 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 65 optional :ingress, DockerEngineRuby::Internal::Type::Boolean, api_name: :Ingress |
#internal ⇒ Boolean?
Whether the network is created to only allow internal networking connectivity.
71 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 71 optional :internal, DockerEngineRuby::Internal::Type::Boolean, api_name: :Internal |
#ipam ⇒ DockerEngineRuby::Models::NetworkInspectResponse::Ipam?
The network’s IP Address Management.
77 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 77 optional :ipam, -> { DockerEngineRuby::Models::NetworkInspectResponse::Ipam }, api_name: :IPAM |
#labels ⇒ Hash{Symbol=>String}?
Metadata specific to the network being created.
83 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 83 optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels |
#name ⇒ String?
Name of the network.
89 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 89 optional :name, String, api_name: :Name |
#options ⇒ Hash{Symbol=>String}?
Network-specific options uses when creating the network.
95 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 95 optional :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options |
#peers ⇒ Array<DockerEngineRuby::Models::NetworkInspectResponse::Peer>?
List of peer nodes for an overlay network. This field is only present for overlay networks, and omitted for other network types.
102 103 104 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 102 optional :peers, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Models::NetworkInspectResponse::Peer] }, api_name: :Peers |
#scope ⇒ String?
The level at which the network exists (e.g. swarm for cluster-wide or local for machine level)
111 |
# File 'lib/docker_engine_ruby/models/network_inspect_response.rb', line 111 optional :scope, String, api_name: :Scope |