Class: DockerEngineRuby::Models::Node
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Node
- Defined in:
- lib/docker_engine_ruby/models/node.rb
Overview
Defined Under Namespace
Classes: Description, ManagerStatus, Status, Version
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
Date and time at which the node was added to the swarm in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
-
#description ⇒ DockerEngineRuby::Models::Node::Description?
NodeDescription encapsulates the properties of the Node as reported by the agent.
- #id ⇒ String?
-
#manager_status ⇒ DockerEngineRuby::Models::Node::ManagerStatus?
ManagerStatus represents the status of a manager.
- #spec ⇒ DockerEngineRuby::Models::NodeSpec?
-
#status ⇒ DockerEngineRuby::Models::Node::Status?
NodeStatus represents the status of a node.
-
#updated_at ⇒ Time?
Date and time at which the node was last updated in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
-
#version ⇒ DockerEngineRuby::Models::Node::Version?
The version number of the object such as node, service, etc.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cert_issuer_public_key: nil, cert_issuer_subject: nil, trust_root: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Description::TlsInfo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cert_issuer_public_key: nil, cert_issuer_subject: nil, trust_root: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Node::Description::TlsInfo for more details.
Information about the issuer of leaf TLS certificates and the trusted root CA certificate.
|
|
# File 'lib/docker_engine_ruby/models/node.rb', line 69
|
Instance Attribute Details
#created_at ⇒ Time?
Date and time at which the node was added to the swarm in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
12 |
# File 'lib/docker_engine_ruby/models/node.rb', line 12 optional :created_at, Time, api_name: :CreatedAt |
#description ⇒ DockerEngineRuby::Models::Node::Description?
NodeDescription encapsulates the properties of the Node as reported by the agent.
19 |
# File 'lib/docker_engine_ruby/models/node.rb', line 19 optional :description, -> { DockerEngineRuby::Node::Description }, api_name: :Description |
#id ⇒ String?
24 |
# File 'lib/docker_engine_ruby/models/node.rb', line 24 optional :id, String, api_name: :ID |
#manager_status ⇒ DockerEngineRuby::Models::Node::ManagerStatus?
ManagerStatus represents the status of a manager.
It provides the current status of a node’s manager component, if the node is a manager.
33 |
# File 'lib/docker_engine_ruby/models/node.rb', line 33 optional :manager_status, -> { DockerEngineRuby::Node::ManagerStatus }, api_name: :ManagerStatus |
#spec ⇒ DockerEngineRuby::Models::NodeSpec?
38 |
# File 'lib/docker_engine_ruby/models/node.rb', line 38 optional :spec, -> { DockerEngineRuby::NodeSpec }, api_name: :Spec |
#status ⇒ DockerEngineRuby::Models::Node::Status?
NodeStatus represents the status of a node.
It provides the current status of the node, as seen by the manager.
46 |
# File 'lib/docker_engine_ruby/models/node.rb', line 46 optional :status, -> { DockerEngineRuby::Node::Status }, api_name: :Status |
#updated_at ⇒ Time?
Date and time at which the node was last updated in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
53 |
# File 'lib/docker_engine_ruby/models/node.rb', line 53 optional :updated_at, Time, api_name: :UpdatedAt |
#version ⇒ DockerEngineRuby::Models::Node::Version?
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
67 |
# File 'lib/docker_engine_ruby/models/node.rb', line 67 optional :version, -> { DockerEngineRuby::Node::Version }, api_name: :Version |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/node.rb', line 375
|