Class: DockerEngineRuby::Models::Node::Description
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Node::Description
- Defined in:
- lib/docker_engine_ruby/models/node.rb
Overview
Defined Under Namespace
Classes: Engine, Platform, Resources, TlsInfo
Instance Attribute Summary collapse
-
#engine ⇒ DockerEngineRuby::Models::Node::Description::Engine?
EngineDescription provides information about an engine.
- #hostname ⇒ String?
-
#platform ⇒ DockerEngineRuby::Models::Node::Description::Platform?
Platform represents the platform (Arch/OS).
-
#resources ⇒ DockerEngineRuby::Models::Node::Description::Resources?
An object describing the resources which can be advertised by a node and requested by a task.
-
#tls_info ⇒ DockerEngineRuby::Models::Node::Description::TlsInfo?
Information about the issuer of leaf TLS certificates and the trusted root CA certificate.
Instance Method Summary collapse
- #initialize(kind: nil, value: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(kind: nil, value: nil) ⇒ Object
|
|
# File 'lib/docker_engine_ruby/models/node.rb', line 122
|
Instance Attribute Details
#engine ⇒ DockerEngineRuby::Models::Node::Description::Engine?
EngineDescription provides information about an engine.
95 |
# File 'lib/docker_engine_ruby/models/node.rb', line 95 optional :engine, -> { DockerEngineRuby::Node::Description::Engine }, api_name: :Engine |
#hostname ⇒ String?
100 |
# File 'lib/docker_engine_ruby/models/node.rb', line 100 optional :hostname, String, api_name: :Hostname |
#platform ⇒ DockerEngineRuby::Models::Node::Description::Platform?
Platform represents the platform (Arch/OS).
106 |
# File 'lib/docker_engine_ruby/models/node.rb', line 106 optional :platform, -> { DockerEngineRuby::Node::Description::Platform }, api_name: :Platform |
#resources ⇒ DockerEngineRuby::Models::Node::Description::Resources?
An object describing the resources which can be advertised by a node and requested by a task.
113 |
# File 'lib/docker_engine_ruby/models/node.rb', line 113 optional :resources, -> { DockerEngineRuby::Node::Description::Resources }, api_name: :Resources |
#tls_info ⇒ DockerEngineRuby::Models::Node::Description::TlsInfo?
Information about the issuer of leaf TLS certificates and the trusted root CA certificate.
120 |
# File 'lib/docker_engine_ruby/models/node.rb', line 120 optional :tls_info, -> { DockerEngineRuby::Node::Description::TlsInfo }, api_name: :TLSInfo |