Class: DockerEngineRuby::Models::Node::ManagerStatus

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_ruby/models/node.rb

Overview

See Also:

Defined Under Namespace

Modules: Reachability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(addr: nil, leader: nil, reachability: nil) ⇒ Object

ManagerStatus represents the status of a manager.

It provides the current status of a node’s manager component, if the node is a manager.

Parameters:



# File 'lib/docker_engine_ruby/models/node.rb', line 353

Instance Attribute Details

#addrString?

The IP address and port at which the manager is reachable.

Returns:

  • (String, nil)


338
# File 'lib/docker_engine_ruby/models/node.rb', line 338

optional :addr, String, api_name: :Addr

#leaderBoolean?

Returns:

  • (Boolean, nil)


343
# File 'lib/docker_engine_ruby/models/node.rb', line 343

optional :leader, DockerEngineRuby::Internal::Type::Boolean, api_name: :Leader

#reachabilitySymbol, ...

Reachability represents the reachability of a node.



349
350
351
# File 'lib/docker_engine_ruby/models/node.rb', line 349

optional :reachability,
enum: -> { DockerEngineRuby::Node::ManagerStatus::Reachability },
api_name: :Reachability