Module: DockerEngineRuby::Models::Service::Endpoint::Spec::Port::PublishMode

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/service.rb

Overview

The mode in which port is published.

<p><br /></p>

  • “ingress” makes the target port accessible on every node, regardless of whether there is a task for the service running on that node or not.

  • “host” bypasses the routing mesh and publish the port directly on the swarm node where that service is running.

See Also:

Constant Summary collapse

INGRESS =
:ingress
HOST =
:host

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info