Class: DockerEngineRuby::Models::Service::JobStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Service::JobStatus
- Defined in:
- lib/docker_engine_ruby/models/service.rb
Overview
Defined Under Namespace
Classes: JobIteration
Instance Attribute Summary collapse
-
#job_iteration ⇒ DockerEngineRuby::Models::Service::JobStatus::JobIteration?
The version number of the object such as node, service, etc.
- #last_execution ⇒ Time?
Instance Method Summary collapse
-
#initialize(job_iteration: nil, last_execution: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see JobStatus for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(job_iteration: nil, last_execution: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Service::JobStatus for more details.
The status of the service when it is in one of ReplicatedJob or GlobalJob modes. Absent on Replicated and Global mode services. The JobIteration is an ObjectVersion, but unlike the Service’s version, does not need to be sent with an update request.
|
|
# File 'lib/docker_engine_ruby/models/service.rb', line 381
|
Instance Attribute Details
#job_iteration ⇒ DockerEngineRuby::Models::Service::JobStatus::JobIteration?
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
372 373 374 |
# File 'lib/docker_engine_ruby/models/service.rb', line 372 optional :job_iteration, -> { DockerEngineRuby::Service::JobStatus::JobIteration }, api_name: :JobIteration |
#last_execution ⇒ Time?
379 |
# File 'lib/docker_engine_ruby/models/service.rb', line 379 optional :last_execution, Time, api_name: :LastExecution |