Class: DockerEngineRuby::Models::StatsResponse::PidsStats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::StatsResponse::PidsStats
- Defined in:
- lib/docker_engine_ruby/models/stats_response.rb
Overview
Instance Attribute Summary collapse
-
#current ⇒ Integer?
Current is the number of PIDs in the cgroup.
-
#limit ⇒ Integer?
Limit is the hard limit on the number of pids in the cgroup.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineRuby::Internal::Type::BaseModel
Instance Attribute Details
#current ⇒ Integer?
Current is the number of PIDs in the cgroup.
840 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 840 optional :current, Integer, nil?: true |
#limit ⇒ Integer?
Limit is the hard limit on the number of pids in the cgroup. A “Limit” of 0 means that there is no limit.
847 |
# File 'lib/docker_engine_ruby/models/stats_response.rb', line 847 optional :limit, Integer, nil?: true |