Class: DockerEngineRuby::Models::Summary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Defined Under Namespace
Modules: State Classes: Health, HostConfig, ImageManifestDescriptor, Mount, NetworkSettings, Port
Instance Attribute Summary collapse
-
#command ⇒ String?
Command to run when starting the container.
-
#created ⇒ Integer?
Date and time at which the container was created as a Unix timestamp (number of seconds since EPOCH).
-
#health ⇒ DockerEngineRuby::Models::Summary::Health?
Summary of health status.
-
#host_config ⇒ DockerEngineRuby::Models::Summary::HostConfig?
Summary of host-specific runtime information of the container.
-
#id ⇒ String?
The ID of this container as a 128-bit (64-character) hexadecimal string (32 bytes).
-
#image ⇒ String?
The name or ID of the image used to create the container.
-
#image_id ⇒ String?
The ID (digest) of the image that this container was created from.
-
#image_manifest_descriptor ⇒ DockerEngineRuby::Models::Summary::ImageManifestDescriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
-
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
-
#mounts ⇒ Array<DockerEngineRuby::Models::Summary::Mount>?
List of mounts used by the container.
-
#names ⇒ Array<String>?
The names associated with this container.
-
#network_settings ⇒ DockerEngineRuby::Models::Summary::NetworkSettings?
Summary of the container’s network settings.
-
#ports ⇒ Array<DockerEngineRuby::Models::Summary::Port>?
Port-mappings for the container.
-
#size_root_fs ⇒ Integer?
The total size of all files in the read-only layers from the image that the container uses.
-
#size_rw ⇒ Integer?
The size of files that have been created or changed by this container.
-
#state ⇒ Symbol, ...
The state of this container.
-
#status ⇒ String?
Additional human-readable status of this container (e.g. ‘Exit 0`).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
constructor
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
|
|
# File 'lib/docker_engine_ruby/models/summary.rb', line 150
|
Instance Attribute Details
#command ⇒ String?
Command to run when starting the container
10 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 10 optional :command, String, api_name: :Command |
#created ⇒ Integer?
Date and time at which the container was created as a Unix timestamp (number of seconds since EPOCH).
17 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 17 optional :created, Integer, api_name: :Created |
#health ⇒ DockerEngineRuby::Models::Summary::Health?
Summary of health status
Added in v1.52, before that version all container summary not include Health. After this attribute introduced, it includes containers with no health checks configured, or containers that are not running with none
27 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 27 optional :health, -> { DockerEngineRuby::Summary::Health }, api_name: :Health |
#host_config ⇒ DockerEngineRuby::Models::Summary::HostConfig?
Summary of host-specific runtime information of the container. This is a reduced set of information in the container’s “HostConfig” as available in the container “inspect” response.
35 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 35 optional :host_config, -> { DockerEngineRuby::Summary::HostConfig }, api_name: :HostConfig |
#id ⇒ String?
The ID of this container as a 128-bit (64-character) hexadecimal string (32 bytes).
42 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 42 optional :id, String, api_name: :Id |
#image ⇒ String?
The name or ID of the image used to create the container.
This field shows the image reference as was specified when creating the container, which can be in its canonical form (e.g., docker.io/library/ubuntu:latest or ‘docker.io/library/ubuntu@sha256:72297848456d5d37d1262630108ab308d3e9ec7ed1c3286a32fe09856619a782`), short form (e.g., ubuntu:latest)), or the ID(-prefix) of the image (e.g., 72297848456d).
The content of this field can be updated at runtime if the image used to create the container is untagged, in which case the field is updated to contain the the image ID (digest) it was resolved to in its canonical, non-truncated form (e.g., sha256:72297848456d5d37d1262630108ab308d3e9ec7ed1c3286a32fe09856619a782).
60 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 60 optional :image, String, api_name: :Image |
#image_id ⇒ String?
The ID (digest) of the image that this container was created from.
66 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 66 optional :image_id, String, api_name: :ImageID |
#image_manifest_descriptor ⇒ DockerEngineRuby::Models::Summary::ImageManifestDescriptor?
A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
73 74 75 76 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 73 optional :image_manifest_descriptor, -> { DockerEngineRuby::Summary::ImageManifestDescriptor }, api_name: :ImageManifestDescriptor, nil?: true |
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
82 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 82 optional :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels |
#mounts ⇒ Array<DockerEngineRuby::Models::Summary::Mount>?
List of mounts used by the container.
88 89 90 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 88 optional :mounts, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Summary::Mount] }, api_name: :Mounts |
#names ⇒ Array<String>?
The names associated with this container. Most containers have a single name, but when using legacy “links”, the container can have multiple names.
For historic reasons, names are prefixed with a forward-slash (/).
99 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 99 optional :names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Names |
#network_settings ⇒ DockerEngineRuby::Models::Summary::NetworkSettings?
Summary of the container’s network settings
105 106 107 108 109 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 105 optional :network_settings, -> { DockerEngineRuby::Summary::NetworkSettings }, api_name: :NetworkSettings |
#ports ⇒ Array<DockerEngineRuby::Models::Summary::Port>?
Port-mappings for the container.
115 116 117 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 115 optional :ports, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Summary::Port] }, api_name: :Ports |
#size_root_fs ⇒ Integer?
The total size of all files in the read-only layers from the image that the container uses. These layers can be shared between containers.
This field is omitted by default, and only set when size is requested in the API request.
127 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 127 optional :size_root_fs, Integer, api_name: :SizeRootFs, nil?: true |
#size_rw ⇒ Integer?
The size of files that have been created or changed by this container.
This field is omitted by default, and only set when size is requested in the API request.
136 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 136 optional :size_rw, Integer, api_name: :SizeRw, nil?: true |
#state ⇒ Symbol, ...
The state of this container.
142 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 142 optional :state, enum: -> { DockerEngineRuby::Summary::State }, api_name: :State |
#status ⇒ String?
Additional human-readable status of this container (e.g. ‘Exit 0`)
148 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 148 optional :status, String, api_name: :Status |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/summary.rb', line 219
|