Class: DockerEngineRuby::Models::Summary::Health
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary::Health
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(failing_streak: nil, status: nil) ⇒ Object
constructor
Summary of health status.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(failing_streak: nil, status: nil) ⇒ Object
Summary of health status
Added in v1.52, before that version all container summary not include Health. After this attribute introduced, it includes containers with no health checks configured, or containers that are not running with none
|
|
# File 'lib/docker_engine_ruby/models/summary.rb', line 200
|
Instance Attribute Details
#failing_streak ⇒ Integer?
193 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 193 optional :failing_streak, Integer, api_name: :FailingStreak |
#status ⇒ Symbol, ...
198 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 198 optional :status, enum: -> { DockerEngineRuby::Summary::Health::Status }, api_name: :Status |