Module: DockerEngineRuby::Models::Summary::Mount::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_ruby/models/summary.rb

Overview

The mount type. Available types:

  • ‘bind` a mount of a file or directory from the host into the container.

  • ‘cluster` a Swarm cluster volume.

  • ‘image` an OCI image.

  • ‘npipe` a named pipe from the host into the container.

  • ‘tmpfs` a `tmpfs`.

  • ‘volume` a docker volume with the given `Name`.

See Also:

Constant Summary collapse

BIND =
:bind
CLUSTER =
:cluster
IMAGE =
:image
NPIPE =
:npipe
TMPFS =
:tmpfs
VOLUME =
:volume

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info