Class: DockerEngineRuby::Models::Summary::NetworkSettings::Network
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Summary::NetworkSettings::Network
- Defined in:
- lib/docker_engine_ruby/models/summary.rb
Defined Under Namespace
Classes: IpamConfig
Instance Attribute Summary collapse
- #aliases ⇒ Array<String>?
-
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network.
-
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values.
-
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
-
#gateway ⇒ String?
Gateway address for this network.
-
#global_i_pv6_address ⇒ String?
Global IPv6 address.
-
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
-
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container.
-
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
-
#ip_address ⇒ String?
IPv4 address.
-
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
-
#ipam_config ⇒ DockerEngineRuby::Models::Summary::NetworkSettings::Network::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
- #links ⇒ Array<String>?
-
#mac_address ⇒ String?
MAC address for the endpoint on this network.
-
#network_id ⇒ String?
Unique ID of the network.
Instance Method Summary collapse
-
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Network for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineRuby::Models::Summary::NetworkSettings::Network for more details.
Configuration for a network endpoint.
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 514 class Network < DockerEngineRuby::Internal::Type::BaseModel # @!attribute aliases # # @return [Array<String>, nil] optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases # @!attribute dns_names # List of all DNS names an endpoint has on a specific network. This list is based # on the container name, network aliases, container short ID, and hostname. # # These DNS names are non-fully qualified but can contain several dots. You can # get fully qualified DNS names by appending `.<network-name>`. For instance, if # container name is `my.ctr` and the network is named `testnet`, `DNSNames` will # contain `my.ctr` and the FQDN will be `my.ctr.testnet`. # # @return [Array<String>, nil] optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames # @!attribute driver_opts # DriverOpts is a mapping of driver options and values. These options are passed # directly to the driver and are driver specific. # # @return [Hash{Symbol=>String}, nil] optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true # @!attribute endpoint_id # Unique ID for the service endpoint in a Sandbox. # # @return [String, nil] optional :endpoint_id, String, api_name: :EndpointID # @!attribute gateway # Gateway address for this network. # # @return [String, nil] optional :gateway, String, api_name: :Gateway # @!attribute global_i_pv6_address # Global IPv6 address. # # @return [String, nil] optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address # @!attribute global_i_pv6_prefix_len # Mask length of the global IPv6 address. # # @return [Integer, nil] optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen # @!attribute gw_priority # This property determines which endpoint will provide the default gateway for a # container. The endpoint with the highest priority will be used. If multiple # endpoints have the same priority, endpoints are lexicographically sorted based # on their network name, and the one that sorts first is picked. # # @return [Integer, nil] optional :gw_priority, Integer, api_name: :GwPriority # @!attribute ip_address # IPv4 address. # # @return [String, nil] optional :ip_address, String, api_name: :IPAddress # @!attribute ipam_config # EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @return [DockerEngineRuby::Models::Summary::NetworkSettings::Network::IpamConfig, nil] optional :ipam_config, -> { DockerEngineRuby::Summary::NetworkSettings::Network::IpamConfig }, api_name: :IPAMConfig # @!attribute ip_prefix_len # Mask length of the IPv4 address. # # @return [Integer, nil] optional :ip_prefix_len, Integer, api_name: :IPPrefixLen # @!attribute i_pv6_gateway # IPv6 gateway address. # # @return [String, nil] optional :i_pv6_gateway, String, api_name: :IPv6Gateway # @!attribute links # # @return [Array<String>, nil] optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links # @!attribute mac_address # MAC address for the endpoint on this network. The network driver might ignore # this parameter. # # @return [String, nil] optional :mac_address, String, api_name: :MacAddress # @!attribute network_id # Unique ID of the network. # # @return [String, nil] optional :network_id, String, api_name: :NetworkID # @!method initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) # Some parameter documentations has been truncated, see # {DockerEngineRuby::Models::Summary::NetworkSettings::Network} for more details. # # Configuration for a network endpoint. # # @param aliases [Array<String>] # # @param dns_names [Array<String>] List of all DNS names an endpoint has on a specific network. This # # @param driver_opts [Hash{Symbol=>String}, nil] DriverOpts is a mapping of driver options and values. These options # # @param endpoint_id [String] Unique ID for the service endpoint in a Sandbox. # # @param gateway [String] Gateway address for this network. # # @param global_i_pv6_address [String] Global IPv6 address. # # @param global_i_pv6_prefix_len [Integer] Mask length of the global IPv6 address. # # @param gw_priority [Integer] This property determines which endpoint will provide the default # # @param ip_address [String] IPv4 address. # # @param ipam_config [DockerEngineRuby::Models::Summary::NetworkSettings::Network::IpamConfig] EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @param ip_prefix_len [Integer] Mask length of the IPv4 address. # # @param i_pv6_gateway [String] IPv6 gateway address. # # @param links [Array<String>] # # @param mac_address [String] MAC address for the endpoint on this network. The network driver might ignore th # # @param network_id [String] Unique ID of the network. # @see DockerEngineRuby::Models::Summary::NetworkSettings::Network#ipam_config class IpamConfig < DockerEngineRuby::Internal::Type::BaseModel # @!attribute i_pv4_address # # @return [String, nil] optional :i_pv4_address, String, api_name: :IPv4Address # @!attribute i_pv6_address # # @return [String, nil] optional :i_pv6_address, String, api_name: :IPv6Address # @!attribute link_local_ips # # @return [Array<String>, nil] optional :link_local_ips, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :LinkLocalIPs # @!method initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) # EndpointIPAMConfig represents an endpoint's IPAM configuration. # # @param i_pv4_address [String] # @param i_pv6_address [String] # @param link_local_ips [Array<String>] end end |
Instance Attribute Details
#aliases ⇒ Array<String>?
518 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 518 optional :aliases, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Aliases |
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.
These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending ‘.<network-name>`. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.
530 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 530 optional :dns_names, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :DNSNames |
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.
537 538 539 540 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 537 optional :driver_opts, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true |
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
546 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 546 optional :endpoint_id, String, api_name: :EndpointID |
#gateway ⇒ String?
Gateway address for this network.
552 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 552 optional :gateway, String, api_name: :Gateway |
#global_i_pv6_address ⇒ String?
Global IPv6 address.
558 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 558 optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address |
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
564 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 564 optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen |
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.
573 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 573 optional :gw_priority, Integer, api_name: :GwPriority |
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
599 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 599 optional :i_pv6_gateway, String, api_name: :IPv6Gateway |
#ip_address ⇒ String?
IPv4 address.
579 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 579 optional :ip_address, String, api_name: :IPAddress |
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
593 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 593 optional :ip_prefix_len, Integer, api_name: :IPPrefixLen |
#ipam_config ⇒ DockerEngineRuby::Models::Summary::NetworkSettings::Network::IpamConfig?
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
585 586 587 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 585 optional :ipam_config, -> { DockerEngineRuby::Summary::NetworkSettings::Network::IpamConfig }, api_name: :IPAMConfig |
#links ⇒ Array<String>?
604 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 604 optional :links, DockerEngineRuby::Internal::Type::ArrayOf[String], api_name: :Links |
#mac_address ⇒ String?
MAC address for the endpoint on this network. The network driver might ignore this parameter.
611 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 611 optional :mac_address, String, api_name: :MacAddress |
#network_id ⇒ String?
Unique ID of the network.
617 |
# File 'lib/docker_engine_ruby/models/summary.rb', line 617 optional :network_id, String, api_name: :NetworkID |