Class: DockerEngineRuby::Models::SystemEventsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::SystemEventsResponse
- Defined in:
- lib/docker_engine_ruby/models/system_events_response.rb
Overview
Defined Under Namespace
Modules: Scope, Type Classes: Actor
Instance Attribute Summary collapse
-
#action ⇒ String?
The type of event.
-
#actor ⇒ DockerEngineRuby::Models::SystemEventsResponse::Actor?
Actor describes something that generates events, like a container, network, or a volume.
-
#scope ⇒ Symbol, ...
Scope of the event.
-
#time ⇒ Integer?
Timestamp of event.
-
#time_nano ⇒ Integer?
Timestamp of event, with nanosecond accuracy.
-
#type ⇒ Symbol, ...
The type of object emitting the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes: nil, id: nil) ⇒ Object
constructor
Actor describes something that generates events, like a container, network, or a volume.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attributes: nil, id: nil) ⇒ Object
Actor describes something that generates events, like a container, network, or a volume.
|
|
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 45
|
Instance Attribute Details
#action ⇒ String?
The type of event
11 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 11 optional :action, String, api_name: :Action |
#actor ⇒ DockerEngineRuby::Models::SystemEventsResponse::Actor?
Actor describes something that generates events, like a container, network, or a volume.
18 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 18 optional :actor, -> { DockerEngineRuby::Models::SystemEventsResponse::Actor }, api_name: :Actor |
#scope ⇒ Symbol, ...
Scope of the event. Engine events are local scope. Cluster (Swarm) events are swarm scope.
25 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 25 optional :scope, enum: -> { DockerEngineRuby::Models::SystemEventsResponse::Scope } |
#time ⇒ Integer?
Timestamp of event
31 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 31 optional :time, Integer |
#time_nano ⇒ Integer?
Timestamp of event, with nanosecond accuracy
37 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 37 optional :time_nano, Integer, api_name: :timeNano |
#type ⇒ Symbol, ...
The type of object emitting the event
43 |
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 43 optional :type, enum: -> { DockerEngineRuby::Models::SystemEventsResponse::Type }, api_name: :Type |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/system_events_response.rb', line 96
|