Class: DockerEngineRuby::Models::Version
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Version
- Defined in:
- lib/docker_engine_ruby/models/version.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#api_version ⇒ String?
The default (and highest) API version that is supported by the daemon.
-
#arch ⇒ String?
Architecture of the daemon, as returned by the Go runtime (
GOARCH). -
#build_time ⇒ String?
The date and time that the daemon was compiled.
-
#components ⇒ Array<DockerEngineRuby::Models::Version::Component>?
Information about system components.
-
#experimental ⇒ Boolean?
Indicates if the daemon is started with experimental features enabled.
-
#git_commit ⇒ String?
The Git commit of the source code that was used to build the daemon.
-
#go_version ⇒ String?
The version Go used to compile the daemon, and the version of the Go runtime in use.
-
#kernel_version ⇒ String?
The kernel version (‘uname -r`) that the daemon is running on.
-
#min_api_version ⇒ String?
The minimum API version that is supported by the daemon.
-
#os ⇒ String?
The operating system that the daemon is running on (“linux” or “windows”).
- #platform ⇒ DockerEngineRuby::Models::Version::Platform?
-
#version ⇒ String?
The version of the daemon.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, version:, details: nil) ⇒ Object
|
|
# File 'lib/docker_engine_ruby/models/version.rb', line 137
|
Instance Attribute Details
#api_version ⇒ String?
The default (and highest) API version that is supported by the daemon
11 |
# File 'lib/docker_engine_ruby/models/version.rb', line 11 optional :api_version, String, api_name: :ApiVersion |
#arch ⇒ String?
Architecture of the daemon, as returned by the Go runtime (GOARCH).
A full list of possible values can be found in the [Go documentation](go.dev/doc/install/source#environment).
20 |
# File 'lib/docker_engine_ruby/models/version.rb', line 20 optional :arch, String, api_name: :Arch |
#build_time ⇒ String?
The date and time that the daemon was compiled.
26 |
# File 'lib/docker_engine_ruby/models/version.rb', line 26 optional :build_time, String, api_name: :BuildTime |
#components ⇒ Array<DockerEngineRuby::Models::Version::Component>?
Information about system components
32 33 34 |
# File 'lib/docker_engine_ruby/models/version.rb', line 32 optional :components, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Version::Component] }, api_name: :Components |
#experimental ⇒ Boolean?
Indicates if the daemon is started with experimental features enabled.
This field is omitted when empty / false.
42 |
# File 'lib/docker_engine_ruby/models/version.rb', line 42 optional :experimental, DockerEngineRuby::Internal::Type::Boolean, api_name: :Experimental |
#git_commit ⇒ String?
The Git commit of the source code that was used to build the daemon
48 |
# File 'lib/docker_engine_ruby/models/version.rb', line 48 optional :git_commit, String, api_name: :GitCommit |
#go_version ⇒ String?
The version Go used to compile the daemon, and the version of the Go runtime in use.
55 |
# File 'lib/docker_engine_ruby/models/version.rb', line 55 optional :go_version, String, api_name: :GoVersion |
#kernel_version ⇒ String?
The kernel version (‘uname -r`) that the daemon is running on.
This field is omitted when empty.
63 |
# File 'lib/docker_engine_ruby/models/version.rb', line 63 optional :kernel_version, String, api_name: :KernelVersion |
#min_api_version ⇒ String?
The minimum API version that is supported by the daemon
69 |
# File 'lib/docker_engine_ruby/models/version.rb', line 69 optional :min_api_version, String, api_name: :MinAPIVersion |
#os ⇒ String?
The operating system that the daemon is running on (“linux” or “windows”)
75 |
# File 'lib/docker_engine_ruby/models/version.rb', line 75 optional :os, String, api_name: :Os |
#platform ⇒ DockerEngineRuby::Models::Version::Platform?
80 |
# File 'lib/docker_engine_ruby/models/version.rb', line 80 optional :platform, -> { DockerEngineRuby::Version::Platform }, api_name: :Platform |
#version ⇒ String?
The version of the daemon
86 |
# File 'lib/docker_engine_ruby/models/version.rb', line 86 optional :version, String, api_name: :Version |