Class: DockerEngineRuby::Models::Volume
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Volume
- Defined in:
- lib/docker_engine_ruby/models/volume.rb
Overview
Defined Under Namespace
Modules: Scope Classes: ClusterVolume, UsageData
Instance Attribute Summary collapse
-
#cluster_volume ⇒ DockerEngineRuby::Models::Volume::ClusterVolume?
Options and information specific to, and only present on, Swarm CSI cluster volumes.
-
#created_at ⇒ Time?
Date/Time the volume was created.
-
#driver ⇒ String
Name of the volume driver used by the volume.
-
#labels ⇒ Hash{Symbol=>String}
User-defined key/value metadata.
-
#mountpoint ⇒ String
Mount path of the volume on the host.
-
#name ⇒ String
Name of the volume.
-
#options ⇒ Hash{Symbol=>String}
The driver specific options used when creating the volume.
-
#scope ⇒ Symbol, DockerEngineRuby::Models::Volume::Scope
The level at which the volume exists.
-
#status ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
Low-level details about the volume, provided by the volume driver.
-
#usage_data ⇒ DockerEngineRuby::Models::Volume::UsageData?
Usage details about the volume.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ Object
constructor
The version number of the object such as node, service, etc.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index: nil) ⇒ Object
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
|
|
# File 'lib/docker_engine_ruby/models/volume.rb', line 76
|
Instance Attribute Details
#cluster_volume ⇒ DockerEngineRuby::Models::Volume::ClusterVolume?
Options and information specific to, and only present on, Swarm CSI cluster volumes.
49 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 49 optional :cluster_volume, -> { DockerEngineRuby::Volume::ClusterVolume }, api_name: :ClusterVolume |
#created_at ⇒ Time?
Date/Time the volume was created.
55 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 55 optional :created_at, Time, api_name: :CreatedAt |
#driver ⇒ String
Name of the volume driver used by the volume.
11 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 11 required :driver, String, api_name: :Driver |
#labels ⇒ Hash{Symbol=>String}
User-defined key/value metadata.
17 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 17 required :labels, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Labels |
#mountpoint ⇒ String
Mount path of the volume on the host.
23 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 23 required :mountpoint, String, api_name: :Mountpoint |
#name ⇒ String
Name of the volume.
29 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 29 required :name, String, api_name: :Name |
#options ⇒ Hash{Symbol=>String}
The driver specific options used when creating the volume.
35 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 35 required :options, DockerEngineRuby::Internal::Type::HashOf[String], api_name: :Options |
#scope ⇒ Symbol, DockerEngineRuby::Models::Volume::Scope
The level at which the volume exists. Either global for cluster-wide, or local for machine level.
42 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 42 required :scope, enum: -> { DockerEngineRuby::Volume::Scope }, api_name: :Scope |
#status ⇒ Hash{Symbol=>Hash{Symbol=>Object}}?
Low-level details about the volume, provided by the volume driver. Details are returned as a map with key/value pairs: ‘“key”:“value”,“key2”:“value2”`.
The Status field is optional, and is omitted if the volume driver does not support this feature.
65 66 67 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 65 optional :status, DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::HashOf[DockerEngineRuby::Internal::Type::Unknown]], api_name: :Status |
#usage_data ⇒ DockerEngineRuby::Models::Volume::UsageData?
Usage details about the volume. This information is used by the ‘GET /system/df` endpoint, and omitted in other endpoints.
74 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 74 optional :usage_data, -> { DockerEngineRuby::Volume::UsageData }, api_name: :UsageData, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/volume.rb', line 110
|