Class: DockerEngineRuby::Models::Volume::ClusterVolume
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineRuby::Models::Volume::ClusterVolume
- Defined in:
- lib/docker_engine_ruby/models/volume.rb
Overview
Defined Under Namespace
Classes: Info, PublishStatus, Spec, Version
Instance Attribute Summary collapse
- #created_at ⇒ Time?
-
#id ⇒ String?
The Swarm ID of this volume.
-
#info ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Info?
Information about the global status of the volume.
-
#publish_status ⇒ Array<DockerEngineRuby::Models::Volume::ClusterVolume::PublishStatus>?
The status of the volume as it pertains to its publishing and use on specific nodes.
-
#spec ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Spec?
Cluster-specific options used to create the volume.
- #updated_at ⇒ Time?
-
#version ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Version?
The version number of the object such as node, service, etc.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(accessible_topology: nil, capacity_bytes: nil, volume_context: nil, volume_id: nil) ⇒ Object
constructor
Information about the global status of the volume.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accessible_topology: nil, capacity_bytes: nil, volume_context: nil, volume_id: nil) ⇒ Object
Information about the global status of the volume.
|
|
# File 'lib/docker_engine_ruby/models/volume.rb', line 171
|
Instance Attribute Details
#created_at ⇒ Time?
119 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 119 optional :created_at, Time, api_name: :CreatedAt |
#id ⇒ String?
The Swarm ID of this volume. Because cluster volumes are Swarm objects, they have an ID, unlike non-cluster volumes. This ID can be used to refer to the Volume instead of the name.
127 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 127 optional :id, String, api_name: :ID |
#info ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Info?
Information about the global status of the volume.
133 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 133 optional :info, -> { DockerEngineRuby::Volume::ClusterVolume::Info }, api_name: :Info |
#publish_status ⇒ Array<DockerEngineRuby::Models::Volume::ClusterVolume::PublishStatus>?
The status of the volume as it pertains to its publishing and use on specific nodes
140 141 142 143 144 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 140 optional :publish_status, -> { DockerEngineRuby::Internal::Type::ArrayOf[DockerEngineRuby::Volume::ClusterVolume::PublishStatus] }, api_name: :PublishStatus |
#spec ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Spec?
Cluster-specific options used to create the volume.
150 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 150 optional :spec, -> { DockerEngineRuby::Volume::ClusterVolume::Spec }, api_name: :Spec |
#updated_at ⇒ Time?
155 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 155 optional :updated_at, Time, api_name: :UpdatedAt |
#version ⇒ DockerEngineRuby::Models::Volume::ClusterVolume::Version?
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
169 |
# File 'lib/docker_engine_ruby/models/volume.rb', line 169 optional :version, -> { DockerEngineRuby::Volume::ClusterVolume::Version }, api_name: :Version |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_ruby/models/volume.rb', line 259
|